<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:util="in.co.sahi.util.XSLUtils"
	version="1.0">

	<xsl:output method="html" indent="yes" />
	<xsl:param name="useDBURL" select="false" />
	<xsl:param name="scriptName" select="/result/summary/SCRIPTNAME" />
	<xsl:param name="suiteInfo" select="/result/suiteInfo" />
	<xsl:param name="gitScriptPath" select="util:fetchInfo($suiteInfo, 'gitScriptPath')" />
	<xsl:param name="commitId" select="util:fetchInfo($suiteInfo, 'commitId')"/>
	<xsl:variable name="lowercase" select='"abcdefghijklmnopqrstuvwxyz "' />
	<xsl:variable name="uppercase" select='"ABCDEFGHIJKLMNOPQRSTUVWXYZ_"' />
	<xsl:variable name="commitIdURI">
		<xsl:choose>
			<xsl:when test="$commitId !=''">
            <xsl:value-of select="concat('&amp;commitId=',$commitId)"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="''"/>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:template match="/">
	<xsl:text disable-output-escaping='yes'>&lt;!DOCTYPE html></xsl:text>
		<html>
			<head>
				<link rel="shortcut icon" href="/_s_/spr/images/favicon.ico" type="image/png"/>
				<link rel="stylesheet" href="/_s_/spr/css/reports_styles.css" type="text/css" />
				
				<meta http-equiv="content-type" content="text/html; charset=UTF-8" />
				<style><![CDATA[
					body{display:table;width: fit-content;}
					body *{font-family: Arial, Helvetica, sans-serif;font-size:10pt;}
					body {
					  margin:0;
					  background-color:white;
					}
					#sahi-logo {
					  display: inline-block;
					  width: 110px;
					  height: 50px;
					  margin: 0;
					  padding: 0;
					}
					#sahi-logo img {
					  width: 95px;
					  height: 50px;
					  margin-left: 80px;
					  margin-top: -2px;
					}
					.flex-row {
					  display: flex;
					  flex-direction: row;
					  gap: 10px;align-items: center;
					}

					.flex-column {
					  display: flex;flex-direction: column;
					  gap: 10px;align-items: center;
					}
					.flex-row.arg-expanded {align-items: flex-start;}
					.navbar-container {
						position: sticky;
						top: 0;
						width: 100%;
						min-width: 100vw;
						margin: 0;
						padding: 0;
						z-index: 2;
						background-color: #253F89;
					}
					#navbar {
						height:50px;
						margin-bottom: 25px;
						margin-left: 0;
						padding: 0;
						padding-left: 35px;
						gap: 20px;
						align-items: flex-end;
						position: sticky;
						left: 0;
						z-index: 2;
						
						width: 100%;
						max-width: calc(40vw - 60px);
						min-width: 800px;
						background-color: #253F89;
					}
					#navbar a:not(.nav-sahi-logo) {
						color: #D3D3D3;
						text-decoration: none;
						font-size: 14px;
						white-space: nowrap;
						font-weight: 700;
					}
					
					#navbar a:not(.selected, .nav-sahi-logo) {
						padding: 11px 24px 11px 24px;
					    margin-bottom: 3px;
					    border-radius: 5px;
				    }
					
					#navbar a:not(.selected, .nav-sahi-logo):hover {
						background-color: #E2EAFF;
						color: #253F89;
					}
					
					#compareScreenshots {
					    font-weight: bold;
						background-color: white;
						padding: 13px 25px 0 25px;
						border-bottom: none;
						margin-bottom: -1px;
						height: 65%;
						color: #253F89;
						border-radius: 5px 5px 0px 0px;
					}
					div{padding:3px;}
					.summary {
					    background-color: white;
					    border-collapse: collapse;
					    margin-left: 60px;
					}
					
					.summary th {
					   background-color: #E2EAFF !important; border: 0.5px solid #66666682 !important;
					   color: #000 !important;
					   font-family: Arial, Helvetica, sans-serif; font-weight: bold !important;
					   padding: 11px 15px 11px 10px !important;
					   white-space: nowrap !important;
					}
					
					.summary td {
						border: 0.5px solid #66666682 !important; color: #000 !important;
						font-family: Arial, Helvetica, sans-serif; padding: 11px 15px 11px 10px !important;
						min-width: 100px !important; text-align: center !important;
					}
					td.intermediateStatusCell {
						font-weight: bold;
					}
					.summary td.time-taken {
						text-align: right !important;
					}
					#tcSummary td {
						text-align: left !important;
					}
					#tcSummary .status-icon {
						margin: 0;
					}
					#tcSummary .time-taken {
						text-align: right !important;
					}
					.date-time .flex-column span:first-child {
						font-weight: bold;
					}
					.date-time span, 
					.time-taken {
						font-size: 14px;
						font-weight: 500;
					}
					.date-time > span >span:last-child {
						font-size: 12px;
						font-weight: 500;
						color: #4E4E4E;
					}
					table.summary .date-time span {padding: 0 20px;}
					a.START,a.STOP{color:black;font-weight:bold;font-size: 16px}
					.table-button a {
					    text-decoration: none;cursor: pointer;
					    color: #4e4e4e;padding-left: 10px;
					    padding-right:10px;font-weight: bold;
					}
					
					#stepsDiv A IMG {padding:10px;border: 1px solid #ccc;}
					#stepsDiv {
					   margin-left: 60px; border: none;
					   padding-top: 20px; display: table; min-width: 95vw;
					}
					.steps {
						margin-top: 12px; padding: 20px 0px;
						border-radius: 10px;
					}
					.steps * { 
					   line-height: 19px;
					   font-size: 13px;
					   font-weight: 500;
					}
					.steps > * {margin-bottom: 12px;}
					.steps a {
					   color: black;
					   text-decoration:none;
					}
					.steps a:hover {text-decoration:underline;}
					.status-icon {
					   border: 1px solid black;
					   border-radius: 15px;font-weight: bold !important;
					   padding: 8px 12px;width: fit-content; margin: auto;
					   text-transform: capitalize;
					   white-space: nowrap;
					}

					.status-icon::before {
					content: '';
					display: inline-block;

					width: 14px;
					height: 14px;

					background-size: contain;
					background-repeat: no-repeat;

					}

					.status-icon:empty {
					display:none;
					}

					.status-icon.FAILURE {
					border-color: #C00100;
					color: #C00100;
					background-color: #FFE9E9;
					}

					.status-icon.FAILURE::before {
					background-image: url("data:image/svg+xml,%3Csvg width='24' height='24' viewBox='0 0 24 24' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cg clip-path='url(%23clip0_178_1249)'%3E%3Cpath d='M23.951 12.3L23.246 7.3C23.0727 6.10993 22.4783 5.02151 21.5707 4.23247C20.6631 3.44343 19.5026 3.00612 18.3 3H5C3.67441 3.00159 2.40356 3.52888 1.46622 4.46622C0.528882 5.40356 0.00158786 6.6744 0 8L0 13C0.00158786 14.3256 0.528882 15.5964 1.46622 16.5338C2.40356 17.4711 3.67441 17.9984 5 18H7.712L9.626 21.878C9.94777 22.5316 10.4938 23.0478 11.1644 23.3323C11.835 23.6169 12.5856 23.6509 13.2792 23.4282C13.9728 23.2055 14.5633 22.7409 14.9429 22.1191C15.3225 21.4973 15.4659 20.7597 15.347 20.041L15.011 18H19C19.7158 18 20.4232 17.8464 21.0745 17.5494C21.7258 17.2525 22.3057 16.8192 22.7751 16.2788C23.2445 15.7384 23.5923 15.1036 23.7952 14.4171C23.9981 13.7307 24.0512 13.0087 23.951 12.3ZM5 5H7V16H5C4.20435 16 3.44129 15.6839 2.87868 15.1213C2.31607 14.5587 2 13.7956 2 13V8C2 7.20435 2.31607 6.44129 2.87868 5.87868C3.44129 5.31607 4.20435 5 5 5V5ZM21.264 14.968C20.9824 15.292 20.6346 15.5517 20.244 15.7298C19.8535 15.9078 19.4292 16 19 16H13.833C13.688 16 13.5446 16.0315 13.413 16.0924C13.2814 16.1533 13.1645 16.2421 13.0706 16.3526C12.9767 16.4632 12.908 16.5928 12.8692 16.7326C12.8304 16.8723 12.8225 17.0189 12.846 17.162L13.374 20.362C13.3994 20.5105 13.3916 20.6628 13.3513 20.808C13.3111 20.9532 13.2392 21.0878 13.141 21.202C13.0258 21.3262 12.8828 21.4213 12.7237 21.4794C12.5645 21.5375 12.3939 21.557 12.2258 21.5363C12.0577 21.5156 11.8969 21.4553 11.7566 21.3603C11.6163 21.2653 11.5006 21.1384 11.419 20.99L9.23 16.558C9.17226 16.4471 9.09424 16.3481 9 16.266V5H18.3C19.0223 5.00264 19.7195 5.26473 20.2647 5.7385C20.8099 6.21227 21.1667 6.86616 21.27 7.581L21.976 12.581C22.0352 13.0067 22.0023 13.4401 21.8795 13.8519C21.7566 14.2637 21.5467 14.6443 21.264 14.968V14.968Z' fill='%23E62E2D'/%3E%3C/g%3E%3Cdefs%3E%3CclipPath id='clip0_178_1249'%3E%3Crect width='24' height='24' fill='white'/%3E%3C/clipPath%3E%3C/defs%3E%3C/svg%3E");
					}

					.status-icon.SUCCESS {
					border-color: #3B8004;
					color: #3B8004;
					background-color: #EBFFDB;
					}

					.status-icon.SUCCESS::before {
					background-image: url("data:image/svg+xml,%3Csvg width='24' height='24' viewBox='0 0 24 24' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cg clip-path='url(%23clip0_178_1255)'%3E%3Cpath d='M22.773 7.72139C22.3041 7.181 21.7245 6.74767 21.0736 6.45075C20.4226 6.15382 19.7155 6.00024 19 6.00039H15.011L15.347 3.95939C15.4659 3.24065 15.3225 2.50313 14.9429 1.88133C14.5633 1.25954 13.9728 0.794906 13.2792 0.572185C12.5856 0.349464 11.835 0.383494 11.1644 0.668068C10.4938 0.952642 9.94777 1.4688 9.626 2.12239L7.712 6.00039H5C3.6744 6.00198 2.40356 6.52927 1.46622 7.46661C0.528882 8.40395 0.00158786 9.6748 0 11.0004L0 16.0004C0.00158786 17.326 0.528882 18.5968 1.46622 19.5342C2.40356 20.4715 3.6744 20.9988 5 21.0004H18.3C19.5035 20.9955 20.6652 20.5587 21.5738 19.7696C22.4824 18.9804 23.0776 17.8913 23.251 16.7004L23.956 11.7004C24.0553 10.9911 24.001 10.2688 23.7969 9.58232C23.5928 8.89584 23.2437 8.26121 22.773 7.72139ZM2 16.0004V11.0004C2 10.2047 2.31607 9.44168 2.87868 8.87907C3.44129 8.31646 4.20435 8.00039 5 8.00039H7V19.0004H5C4.20435 19.0004 3.44129 18.6843 2.87868 18.1217C2.31607 17.5591 2 16.796 2 16.0004ZM21.971 11.4194L21.265 16.4194C21.1618 17.1334 20.8057 17.7866 20.2616 18.2603C19.7175 18.7339 19.0214 18.9966 18.3 19.0004H9V7.73439C9.09424 7.65229 9.17226 7.55324 9.23 7.44239L11.419 3.00739C11.5011 2.85932 11.6171 2.73284 11.7576 2.63835C11.8981 2.54386 12.059 2.48406 12.2271 2.46385C12.3952 2.44364 12.5657 2.46361 12.7246 2.52212C12.8834 2.58062 13.0262 2.67599 13.141 2.80039C13.2392 2.91464 13.3111 3.04916 13.3513 3.19436C13.3916 3.33956 13.3994 3.49186 13.374 3.64039L12.846 6.84039C12.8228 6.98337 12.831 7.12968 12.8699 7.2692C12.9089 7.40871 12.9776 7.5381 13.0715 7.64842C13.1654 7.75874 13.2821 7.84735 13.4136 7.90812C13.545 7.96889 13.6882 8.00038 13.833 8.00039H19C19.4294 8.00033 19.8538 8.09246 20.2445 8.27054C20.6353 8.44862 20.9832 8.7085 21.2649 9.03263C21.5465 9.35675 21.7553 9.73756 21.8772 10.1493C21.999 10.5611 22.031 10.9942 21.971 11.4194Z' fill='%233B8004'/%3E%3C/g%3E%3Cdefs%3E%3CclipPath id='clip0_178_1255'%3E%3Crect width='24' height='24' fill='white'/%3E%3C/clipPath%3E%3C/defs%3E%3C/svg%3E");
					}

					.status-icon.ERROR {
					border-color: #E62E2D;
					color: #E62E2D;
					background-color: #FFE9E9;
					}

					.status-icon.ERROR::before {
					background-image: url("data:image/svg+xml,%3Csvg width='24' height='24' viewBox='0 0 24 24' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cg clip-path='url(%23clip0_379_2718)'%3E%3Cpath d='M15.9999 8.00012C15.8124 7.81265 15.5581 7.70734 15.2929 7.70734C15.0278 7.70734 14.7735 7.81265 14.5859 8.00012L11.9999 10.5861L9.41395 8.00012C9.22534 7.81796 8.97274 7.71717 8.71055 7.71945C8.44835 7.72173 8.19754 7.8269 8.01213 8.0123C7.82672 8.19771 7.72155 8.44853 7.71928 8.71072C7.717 8.97292 7.81779 9.22552 7.99995 9.41412L10.5859 12.0001L7.99995 14.5861C7.81779 14.7747 7.717 15.0273 7.71928 15.2895C7.72155 15.5517 7.82672 15.8025 8.01213 15.9879C8.19754 16.1733 8.44835 16.2785 8.71055 16.2808C8.97274 16.2831 9.22534 16.1823 9.41395 16.0001L11.9999 13.4141L14.5859 16.0001C14.7745 16.1823 15.0271 16.2831 15.2893 16.2808C15.5515 16.2785 15.8023 16.1733 15.9878 15.9879C16.1732 15.8025 16.2783 15.5517 16.2806 15.2895C16.2829 15.0273 16.1821 14.7747 15.9999 14.5861L13.4139 12.0001L15.9999 9.41412C16.1874 9.22659 16.2927 8.97229 16.2927 8.70712C16.2927 8.44196 16.1874 8.18765 15.9999 8.00012Z' fill='%23E62E2D'/%3E%3Cpath d='M12 0C9.62663 0 7.30655 0.703788 5.33316 2.02236C3.35977 3.34094 1.8217 5.21509 0.913451 7.4078C0.00519943 9.60051 -0.232441 12.0133 0.230582 14.3411C0.693605 16.6689 1.83649 18.8071 3.51472 20.4853C5.19295 22.1635 7.33115 23.3064 9.65892 23.7694C11.9867 24.2324 14.3995 23.9948 16.5922 23.0866C18.7849 22.1783 20.6591 20.6402 21.9776 18.6668C23.2962 16.6935 24 14.3734 24 12C23.9966 8.81846 22.7312 5.76821 20.4815 3.51852C18.2318 1.26883 15.1815 0.00344108 12 0V0ZM12 22C10.0222 22 8.08879 21.4135 6.4443 20.3147C4.79981 19.2159 3.51809 17.6541 2.76121 15.8268C2.00433 13.9996 1.8063 11.9889 2.19215 10.0491C2.578 8.10929 3.53041 6.32746 4.92894 4.92893C6.32746 3.53041 8.10929 2.578 10.0491 2.19215C11.9889 1.8063 13.9996 2.00433 15.8268 2.7612C17.6541 3.51808 19.2159 4.79981 20.3147 6.4443C21.4135 8.08879 22 10.0222 22 12C21.9971 14.6513 20.9426 17.1931 19.0679 19.0679C17.1931 20.9426 14.6513 21.9971 12 22Z' fill='%23E62E2D'/%3E%3C/g%3E%3Cdefs%3E%3CclipPath id='clip0_379_2718'%3E%3Crect width='24' height='24' fill='white'/%3E%3C/clipPath%3E%3C/defs%3E%3C/svg%3E");
					}

					.status-icon.RUNNING {
					border-color: #EFA41C;
					color: #EFA41C;
					background-color: #FFF5E3;
					}

					.status-icon.RUNNING::before {
					background-image: url("data:image/svg+xml,%3Csvg width='24' height='24' viewBox='0 0 24 24' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cg clip-path='url(%23clip0_178_1264)'%3E%3Cpath d='M24 12C24 15.1826 22.7357 18.2348 20.4853 20.4853C18.2348 22.7357 15.1826 24 12 24C8.8174 24 5.76516 22.7357 3.51472 20.4853C1.26428 18.2348 0 15.1826 0 12C0 11.7348 0.105357 11.4804 0.292893 11.2929C0.48043 11.1054 0.734784 11 1 11C1.26522 11 1.51957 11.1054 1.70711 11.2929C1.89464 11.4804 2 11.7348 2 12C2 13.9778 2.58649 15.9112 3.6853 17.5557C4.78412 19.2002 6.3459 20.4819 8.17317 21.2388C10.0004 21.9957 12.0111 22.1937 13.9509 21.8079C15.8907 21.422 17.6725 20.4696 19.0711 19.0711C20.4696 17.6725 21.422 15.8907 21.8079 13.9509C22.1937 12.0111 21.9957 10.0004 21.2388 8.17317C20.4819 6.3459 19.2002 4.78412 17.5557 3.6853C15.9112 2.58649 13.9778 2 12 2C11.7348 2 11.4804 1.89464 11.2929 1.70711C11.1054 1.51957 11 1.26522 11 1C11 0.734784 11.1054 0.48043 11.2929 0.292893C11.4804 0.105357 11.7348 0 12 0C15.1815 0.00344108 18.2318 1.26883 20.4815 3.51852C22.7312 5.76821 23.9966 8.81846 24 12ZM10.277 11H8C7.73478 11 7.48043 11.1054 7.29289 11.2929C7.10536 11.4804 7 11.7348 7 12C7 12.2652 7.10536 12.5196 7.29289 12.7071C7.48043 12.8946 7.73478 13 8 13H10.277C10.4297 13.2652 10.6414 13.4917 10.8958 13.662C11.1501 13.8323 11.4402 13.9417 11.7436 13.9818C12.047 14.0219 12.3556 13.9917 12.6454 13.8934C12.9353 13.7951 13.1986 13.6314 13.415 13.415C13.6314 13.1986 13.7951 12.9353 13.8934 12.6454C13.9917 12.3556 14.0219 12.047 13.9818 11.7436C13.9417 11.4402 13.8323 11.1501 13.662 10.8958C13.4917 10.6414 13.2652 10.4297 13 10.277V7C13 6.73478 12.8946 6.48043 12.7071 6.29289C12.5196 6.10536 12.2652 6 12 6C11.7348 6 11.4804 6.10536 11.2929 6.29289C11.1054 6.48043 11 6.73478 11 7V10.277C10.7004 10.4513 10.4513 10.7004 10.277 11V11ZM1.827 8.784C2.02478 8.784 2.21812 8.72535 2.38257 8.61547C2.54702 8.50559 2.67519 8.34941 2.75088 8.16668C2.82657 7.98396 2.84637 7.78289 2.80779 7.58891C2.7692 7.39493 2.67396 7.21675 2.53411 7.07689C2.39425 6.93704 2.21607 6.8418 2.02209 6.80321C1.82811 6.76463 1.62704 6.78443 1.44432 6.86012C1.26159 6.93581 1.10541 7.06398 0.99553 7.22843C0.885649 7.39288 0.827 7.58622 0.827 7.784C0.827 8.04922 0.932357 8.30357 1.11989 8.49111C1.30743 8.67864 1.56178 8.784 1.827 8.784ZM4.221 5.207C4.41878 5.207 4.61212 5.14835 4.77657 5.03847C4.94102 4.92859 5.06919 4.77241 5.14488 4.58968C5.22057 4.40696 5.24037 4.20589 5.20179 4.01191C5.1632 3.81793 5.06796 3.63975 4.92811 3.49989C4.78825 3.36004 4.61007 3.2648 4.41609 3.22621C4.22211 3.18763 4.02104 3.20743 3.83832 3.28312C3.65559 3.35881 3.49941 3.48698 3.38953 3.65143C3.27965 3.81588 3.221 4.00922 3.221 4.207C3.221 4.47222 3.32636 4.72657 3.51389 4.91411C3.70143 5.10164 3.95578 5.207 4.221 5.207ZM7.779 2.841C7.97678 2.841 8.17012 2.78235 8.33457 2.67247C8.49902 2.56259 8.62719 2.40641 8.70288 2.22368C8.77857 2.04096 8.79837 1.83989 8.75979 1.64591C8.7212 1.45193 8.62596 1.27375 8.48611 1.13389C8.34625 0.994041 8.16807 0.8988 7.97409 0.860215C7.78011 0.821629 7.57904 0.841433 7.39632 0.91712C7.21359 0.992808 7.05741 1.12098 6.94753 1.28543C6.83765 1.44988 6.779 1.64322 6.779 1.841C6.779 2.10622 6.88436 2.36057 7.07189 2.54811C7.25943 2.73564 7.51378 2.841 7.779 2.841V2.841Z' fill='%23EFA41C'/%3E%3C/g%3E%3Cdefs%3E%3CclipPath id='clip0_178_1264'%3E%3Crect width='24' height='24' fill='white'/%3E%3C/clipPath%3E%3C/defs%3E%3C/svg%3E%0A");
					}

					.status-icon.USER_ABORTED {
					border-color: #A52A2A;
					color: #A52A2A;
					background-color: #FEEFEF;
					}

					.status-icon.USER_ABORTED::before {
					background-image: url("data:image/svg+xml,%3Csvg width='24' height='24' viewBox='0 0 24 24' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cg clip-path='url(%23clip0_178_1346)'%3E%3Cpath d='M9 12C10.1867 12 11.3467 11.6481 12.3334 10.9888C13.3201 10.3295 14.0892 9.39246 14.5433 8.2961C14.9974 7.19975 15.1162 5.99335 14.8847 4.82946C14.6532 3.66558 14.0818 2.59648 13.2426 1.75736C12.4035 0.918247 11.3344 0.346802 10.1705 0.115291C9.00666 -0.11622 7.80026 0.00259972 6.7039 0.456726C5.60754 0.910851 4.67047 1.67989 4.01118 2.66658C3.35189 3.65328 3 4.81332 3 6C3.00159 7.59082 3.63424 9.11602 4.75911 10.2409C5.88399 11.3658 7.40919 11.9984 9 12ZM9 2C9.79113 2 10.5645 2.2346 11.2223 2.67412C11.8801 3.11365 12.3928 3.73837 12.6955 4.46927C12.9983 5.20017 13.0775 6.00444 12.9231 6.78036C12.7688 7.55629 12.3878 8.26902 11.8284 8.82843C11.269 9.38784 10.5563 9.7688 9.78036 9.92315C9.00444 10.0775 8.20017 9.99827 7.46927 9.69552C6.73836 9.39277 6.11365 8.88008 5.67412 8.22228C5.2346 7.56449 5 6.79113 5 6C5 4.93914 5.42143 3.92172 6.17157 3.17158C6.92172 2.42143 7.93913 2 9 2V2ZM18 23C18 23.2652 17.8946 23.5196 17.7071 23.7071C17.5196 23.8946 17.2652 24 17 24C16.7348 24 16.4804 23.8946 16.2929 23.7071C16.1054 23.5196 16 23.2652 16 23C16 21.1435 15.2625 19.363 13.9497 18.0503C12.637 16.7375 10.8565 16 9 16C7.14349 16 5.36301 16.7375 4.05025 18.0503C2.7375 19.363 2 21.1435 2 23C2 23.2652 1.89464 23.5196 1.70711 23.7071C1.51957 23.8946 1.26522 24 1 24C0.734784 24 0.48043 23.8946 0.292893 23.7071C0.105357 23.5196 0 23.2652 0 23C0 20.6131 0.948212 18.3239 2.63604 16.636C4.32387 14.9482 6.61305 14 9 14C11.3869 14 13.6761 14.9482 15.364 16.636C17.0518 18.3239 18 20.6131 18 23V23ZM23.707 14.293C23.8025 14.3853 23.8787 14.4956 23.9311 14.6176C23.9835 14.7396 24.0111 14.8708 24.0123 15.0036C24.0134 15.1364 23.9881 15.2681 23.9378 15.391C23.8875 15.5139 23.8133 15.6255 23.7194 15.7194C23.6255 15.8133 23.5139 15.8875 23.391 15.9378C23.2681 15.9881 23.1364 16.0134 23.0036 16.0123C22.8708 16.0111 22.7396 15.9835 22.6176 15.9311C22.4956 15.8787 22.3852 15.8025 22.293 15.707L20.5 13.914L18.707 15.707C18.5184 15.8892 18.2658 15.99 18.0036 15.9877C17.7414 15.9854 17.4906 15.8802 17.3052 15.6948C17.1198 15.5094 17.0146 15.2586 17.0123 14.9964C17.01 14.7342 17.1108 14.4816 17.293 14.293L19.086 12.5L17.293 10.707C17.1108 10.5184 17.01 10.2658 17.0123 10.0036C17.0146 9.74141 17.1198 9.49059 17.3052 9.30519C17.4906 9.11978 17.7414 9.01461 18.0036 9.01233C18.2658 9.01005 18.5184 9.11085 18.707 9.293L20.5 11.086L22.293 9.293C22.4816 9.11085 22.7342 9.01005 22.9964 9.01233C23.2586 9.01461 23.5094 9.11978 23.6948 9.30519C23.8802 9.49059 23.9854 9.74141 23.9877 10.0036C23.99 10.2658 23.8892 10.5184 23.707 10.707L21.914 12.5L23.707 14.293Z' fill='%23A52A2A'/%3E%3C/g%3E%3Cdefs%3E%3CclipPath id='clip0_178_1346'%3E%3Crect width='24' height='24' fill='white'/%3E%3C/clipPath%3E%3C/defs%3E%3C/svg%3E%0A");
					}

					.status-icon.SKIPPED {
					border-color: #9E9E9E;
					color: #9E9E9E;
					background-color: #D8D8D8;
					}

					.status-icon.SKIPPED::before {
					background-image: url("data:image/svg+xml,%3Csvg width='24' height='24' viewBox='0 0 24 24' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath d='M10.4801 19C10.2178 18.9989 9.96637 18.8947 9.7801 18.71L5.1901 14.12C4.6283 13.5575 4.31274 12.795 4.31274 12C4.31274 11.205 4.6283 10.4425 5.1901 9.88L9.7801 5.29C9.96747 5.10375 10.2209 4.99921 10.4851 4.99921C10.7493 4.99921 11.0027 5.10375 11.1901 5.29C11.2838 5.38296 11.3582 5.49356 11.409 5.61542C11.4598 5.73728 11.4859 5.86799 11.4859 6C11.4859 6.13201 11.4598 6.26272 11.409 6.38458C11.3582 6.50644 11.2838 6.61704 11.1901 6.71L6.6001 11.29C6.50638 11.383 6.43198 11.4936 6.38121 11.6154C6.33044 11.7373 6.30431 11.868 6.30431 12C6.30431 12.132 6.33044 12.2627 6.38121 12.3846C6.43198 12.5064 6.50638 12.617 6.6001 12.71L11.1901 17.29C11.2838 17.383 11.3582 17.4936 11.409 17.6154C11.4598 17.7373 11.4859 17.868 11.4859 18C11.4859 18.132 11.4598 18.2627 11.409 18.3846C11.3582 18.5064 11.2838 18.617 11.1901 18.71C11.0967 18.8027 10.9858 18.876 10.864 18.9258C10.7422 18.9755 10.6117 19.0008 10.4801 19Z' fill='%23374957'/%3E%3Cpath d='M17.4799 19C17.2176 18.9989 16.9662 18.8947 16.7799 18.71L10.7799 12.71C10.6862 12.617 10.6118 12.5064 10.561 12.3846C10.5103 12.2627 10.4841 12.132 10.4841 12C10.4841 11.868 10.5103 11.7373 10.561 11.6154C10.6118 11.4936 10.6862 11.383 10.7799 11.29L16.7799 5.29C16.9673 5.10375 17.2207 4.99921 17.4849 4.99921C17.7491 4.99921 18.0026 5.10375 18.1899 5.29C18.2836 5.38296 18.358 5.49356 18.4088 5.61542C18.4596 5.73728 18.4857 5.86799 18.4857 6C18.4857 6.13201 18.4596 6.26272 18.4088 6.38458C18.358 6.50644 18.2836 6.61704 18.1899 6.71L12.8999 12L18.1899 17.29C18.2836 17.383 18.358 17.4936 18.4088 17.6154C18.4596 17.7373 18.4857 17.868 18.4857 18C18.4857 18.132 18.4596 18.2627 18.4088 18.3846C18.358 18.5064 18.2836 18.617 18.1899 18.71C18.0965 18.8027 17.9857 18.876 17.8638 18.9258C17.742 18.9755 17.6115 19.0008 17.4799 19Z' fill='%23374957'/%3E%3C/svg%3E");
					transform: rotate(180deg);
					}

					.status-icon.ABORTED {
					border-color: #A52A2A;
					color: #A52A2A;
					background-color: #FEEFEF;
					}

					.status-icon.ABORTED::before {
					background-image: url("data:image/svg+xml,%3Csvg width='24' height='24' viewBox='0 0 24 24' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cg clip-path='url(%23clip0_379_2736)'%3E%3Cpath d='M12 0C9.62663 0 7.30655 0.703788 5.33316 2.02236C3.35977 3.34094 1.8217 5.21509 0.913451 7.4078C0.00519943 9.60051 -0.232441 12.0133 0.230582 14.3411C0.693605 16.6689 1.83649 18.8071 3.51472 20.4853C5.19295 22.1635 7.33115 23.3064 9.65892 23.7694C11.9867 24.2324 14.3995 23.9948 16.5922 23.0866C18.7849 22.1783 20.6591 20.6402 21.9776 18.6668C23.2962 16.6935 24 14.3734 24 12C23.9966 8.81846 22.7312 5.76821 20.4815 3.51852C18.2318 1.26883 15.1815 0.00344108 12 0V0ZM12 22C10.0222 22 8.08879 21.4135 6.4443 20.3147C4.79981 19.2159 3.51809 17.6541 2.76121 15.8268C2.00433 13.9996 1.8063 11.9889 2.19215 10.0491C2.578 8.10929 3.53041 6.32746 4.92894 4.92893C6.32746 3.53041 8.10929 2.578 10.0491 2.19215C11.9889 1.8063 13.9996 2.00433 15.8268 2.7612C17.6541 3.51808 19.2159 4.79981 20.3147 6.4443C21.4135 8.08879 22 10.0222 22 12C21.9971 14.6513 20.9426 17.1931 19.0679 19.0679C17.1931 20.9426 14.6513 21.9971 12 22Z' fill='%23A52A2A'/%3E%3Cpath d='M12.0002 5.00012C11.735 5.00012 11.4807 5.10548 11.2931 5.29302C11.1056 5.48055 11.0002 5.73491 11.0002 6.00012V14.0001C11.0002 14.2653 11.1056 14.5197 11.2931 14.7072C11.4807 14.8948 11.735 15.0001 12.0002 15.0001C12.2655 15.0001 12.5198 14.8948 12.7074 14.7072C12.8949 14.5197 13.0003 14.2653 13.0003 14.0001V6.00012C13.0003 5.73491 12.8949 5.48055 12.7074 5.29302C12.5198 5.10548 12.2655 5.00012 12.0002 5.00012Z' fill='%23A52A2A'/%3E%3Cpath d='M13.0003 18.0001C13.0003 17.4478 12.5525 17.0001 12.0002 17.0001C11.448 17.0001 11.0002 17.4478 11.0002 18.0001C11.0002 18.5524 11.448 19.0001 12.0002 19.0001C12.5525 19.0001 13.0003 18.5524 13.0003 18.0001Z' fill='%23A52A2A'/%3E%3C/g%3E%3Cdefs%3E%3CclipPath id='clip0_379_2736'%3E%3Crect width='24' height='24' fill='white'/%3E%3C/clipPath%3E%3C/defs%3E%3C/svg%3E%0A");
					}

					.status-icon.NOT_SUPPORTED {
					border-color: #656565;
					color: #656565;
					background-color: #C2C2C2;
					}

					.status-icon.NOT_SUPPORTED::before {
					background-image: url("data:image/svg+xml,%3Csvg width='24' height='24' viewBox='0 0 24 24' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cg clip-path='url(%23clip0_379_2736)'%3E%3Cpath d='M12 0C9.62663 0 7.30655 0.703788 5.33316 2.02236C3.35977 3.34094 1.8217 5.21509 0.913451 7.4078C0.00519943 9.60051 -0.232441 12.0133 0.230582 14.3411C0.693605 16.6689 1.83649 18.8071 3.51472 20.4853C5.19295 22.1635 7.33115 23.3064 9.65892 23.7694C11.9867 24.2324 14.3995 23.9948 16.5922 23.0866C18.7849 22.1783 20.6591 20.6402 21.9776 18.6668C23.2962 16.6935 24 14.3734 24 12C23.9966 8.81846 22.7312 5.76821 20.4815 3.51852C18.2318 1.26883 15.1815 0.00344108 12 0V0ZM12 22C10.0222 22 8.08879 21.4135 6.4443 20.3147C4.79981 19.2159 3.51809 17.6541 2.76121 15.8268C2.00433 13.9996 1.8063 11.9889 2.19215 10.0491C2.578 8.10929 3.53041 6.32746 4.92894 4.92893C6.32746 3.53041 8.10929 2.578 10.0491 2.19215C11.9889 1.8063 13.9996 2.00433 15.8268 2.7612C17.6541 3.51808 19.2159 4.79981 20.3147 6.4443C21.4135 8.08879 22 10.0222 22 12C21.9971 14.6513 20.9426 17.1931 19.0679 19.0679C17.1931 20.9426 14.6513 21.9971 12 22Z' fill='%235A4F4F'/%3E%3Cpath d='M12.0002 5.00012C11.735 5.00012 11.4807 5.10548 11.2931 5.29302C11.1056 5.48055 11.0002 5.73491 11.0002 6.00012V14.0001C11.0002 14.2653 11.1056 14.5197 11.2931 14.7072C11.4807 14.8948 11.735 15.0001 12.0002 15.0001C12.2655 15.0001 12.5198 14.8948 12.7074 14.7072C12.8949 14.5197 13.0003 14.2653 13.0003 14.0001V6.00012C13.0003 5.73491 12.8949 5.48055 12.7074 5.29302C12.5198 5.10548 12.2655 5.00012 12.0002 5.00012Z' fill='%235A4F4F'/%3E%3Cpath d='M13.0003 18.0001C13.0003 17.4478 12.5525 17.0001 12.0002 17.0001C11.448 17.0001 11.0002 17.4478 11.0002 18.0001C11.0002 18.5524 11.448 19.0001 12.0002 19.0001C12.5525 19.0001 13.0003 18.5524 13.0003 18.0001Z' fill='%235A4F4F'/%3E%3C/g%3E%3Cdefs%3E%3CclipPath id='clip0_379_2736'%3E%3Crect width='24' height='24' fill='white'/%3E%3C/clipPath%3E%3C/defs%3E%3C/svg%3E");
					}

					.status-icon.ABORTED_TIMEOUT {
					border-color: #A52A2A;
					color: #A52A2A;
					background-color: #FEEFEF;
					}

					.status-icon.ABORTED_TIMEOUT::before {
					background-image: url("data:image/svg+xml,%3Csvg width='24' height='24' viewBox='0 0 24 24' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cg clip-path='url(%23clip0_379_2727)'%3E%3Cpath d='M23.7071 15.2936C23.5195 15.1062 23.2652 15.0009 23.0001 15.0009C22.7349 15.0009 22.4806 15.1062 22.2931 15.2936L19.5001 18.0866L16.7071 15.2936C16.5185 15.1115 16.2659 15.0107 16.0037 15.013C15.7415 15.0152 15.4907 15.1204 15.3053 15.3058C15.1199 15.4912 15.0147 15.742 15.0124 16.0042C15.0101 16.2664 15.1109 16.519 15.2931 16.7076L18.0861 19.5006L15.2931 22.2936C15.1976 22.3859 15.1214 22.4962 15.069 22.6182C15.0166 22.7402 14.989 22.8714 14.9878 23.0042C14.9867 23.137 15.012 23.2687 15.0623 23.3916C15.1125 23.5145 15.1868 23.6261 15.2807 23.72C15.3746 23.8139 15.4862 23.8882 15.6091 23.9384C15.732 23.9887 15.8637 24.014 15.9965 24.0129C16.1293 24.0117 16.2605 23.9841 16.3825 23.9317C16.5045 23.8793 16.6148 23.8031 16.7071 23.7076L19.5001 20.9146L22.2931 23.7076C22.4817 23.8898 22.7343 23.9906 22.9965 23.9883C23.2587 23.986 23.5095 23.8809 23.6949 23.6954C23.8803 23.51 23.9855 23.2592 23.9877 22.997C23.99 22.7348 23.8892 22.4822 23.7071 22.2936L20.9141 19.5006L23.7071 16.7076C23.8945 16.5201 23.9999 16.2658 23.9999 16.0006C23.9999 15.7355 23.8945 15.4812 23.7071 15.2936Z' fill='%23A52A2A'/%3E%3Cpath d='M12 22C10.0222 22 8.08879 21.4135 6.4443 20.3147C4.79981 19.2159 3.51809 17.6541 2.76121 15.8268C2.00433 13.9996 1.8063 11.9889 2.19215 10.0491C2.578 8.10929 3.53041 6.32746 4.92894 4.92894C6.32746 3.53041 8.10929 2.578 10.0491 2.19215C11.9889 1.8063 13.9996 2.00433 15.8268 2.76121C17.6541 3.51809 19.2159 4.79981 20.3147 6.4443C21.4135 8.08879 22 10.0222 22 12C22 12.2652 22.1054 12.5196 22.2929 12.7071C22.4804 12.8946 22.7348 13 23 13C23.2652 13 23.5196 12.8946 23.7071 12.7071C23.8946 12.5196 24 12.2652 24 12C24 9.62663 23.2962 7.30655 21.9776 5.33316C20.6591 3.35977 18.7849 1.8217 16.5922 0.913451C14.3995 0.00519943 11.9867 -0.232441 9.65892 0.230582C7.33115 0.693605 5.19295 1.83649 3.51472 3.51472C1.83649 5.19295 0.693605 7.33115 0.230582 9.65892C-0.232441 11.9867 0.00519943 14.3995 0.913451 16.5922C1.8217 18.7849 3.35977 20.6591 5.33316 21.9776C7.30655 23.2962 9.62663 24 12 24C12.2652 24 12.5196 23.8946 12.7071 23.7071C12.8946 23.5196 13 23.2652 13 23C13 22.7348 12.8946 22.4804 12.7071 22.2929C12.5196 22.1054 12.2652 22 12 22Z' fill='%23A52A2A'/%3E%3Cpath d='M12.0001 6C11.7349 6 11.4805 6.10536 11.293 6.29289C11.1054 6.48043 11.0001 6.73478 11.0001 7V11.586L8.29308 14.293C8.19757 14.3852 8.12139 14.4956 8.06898 14.6176C8.01657 14.7396 7.98898 14.8708 7.98783 15.0036C7.98668 15.1364 8.01198 15.268 8.06226 15.3909C8.11254 15.5138 8.18679 15.6255 8.28069 15.7194C8.37458 15.8133 8.48623 15.8875 8.60913 15.9378C8.73202 15.9881 8.8637 16.0134 8.99648 16.0122C9.12926 16.0111 9.26048 15.9835 9.38248 15.9311C9.50449 15.8787 9.61483 15.8025 9.70708 15.707L12.7071 12.707C12.8946 12.5195 13 12.2652 13.0001 12V7C13.0001 6.73478 12.8947 6.48043 12.7072 6.29289C12.5196 6.10536 12.2653 6 12.0001 6Z' fill='%23A52A2A'/%3E%3C/g%3E%3Cdefs%3E%3CclipPath id='clip0_379_2727'%3E%3Crect width='24' height='24' fill='white'/%3E%3C/clipPath%3E%3C/defs%3E%3C/svg%3E");
					}

					.status-icon.INTERNAL_ABORTED {
					border-color: #A52A2A;
					color: #A52A2A;
					background-color: #FEEFEF;
					}

					.status-icon.INTERNAL_ABORTED:before {
					background-image: url("data:image/svg+xml,%3Csvg width='24' height='24' viewBox='0 0 24 24' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cg clip-path='url(%23clip0_379_2718)'%3E%3Cpath d='M15.9999 8.00012C15.8124 7.81265 15.5581 7.70734 15.2929 7.70734C15.0278 7.70734 14.7735 7.81265 14.5859 8.00012L11.9999 10.5861L9.41395 8.00012C9.22534 7.81796 8.97274 7.71717 8.71055 7.71945C8.44835 7.72173 8.19754 7.8269 8.01213 8.0123C7.82672 8.19771 7.72155 8.44853 7.71928 8.71072C7.717 8.97292 7.81779 9.22552 7.99995 9.41412L10.5859 12.0001L7.99995 14.5861C7.81779 14.7747 7.717 15.0273 7.71928 15.2895C7.72155 15.5517 7.82672 15.8025 8.01213 15.9879C8.19754 16.1733 8.44835 16.2785 8.71055 16.2808C8.97274 16.2831 9.22534 16.1823 9.41395 16.0001L11.9999 13.4141L14.5859 16.0001C14.7745 16.1823 15.0271 16.2831 15.2893 16.2808C15.5515 16.2785 15.8023 16.1733 15.9878 15.9879C16.1732 15.8025 16.2783 15.5517 16.2806 15.2895C16.2829 15.0273 16.1821 14.7747 15.9999 14.5861L13.4139 12.0001L15.9999 9.41412C16.1874 9.22659 16.2927 8.97229 16.2927 8.70712C16.2927 8.44196 16.1874 8.18765 15.9999 8.00012Z' fill='%23A52A2A'/%3E%3Cpath d='M12 0C9.62663 0 7.30655 0.703788 5.33316 2.02236C3.35977 3.34094 1.8217 5.21509 0.913451 7.4078C0.00519943 9.60051 -0.232441 12.0133 0.230582 14.3411C0.693605 16.6689 1.83649 18.8071 3.51472 20.4853C5.19295 22.1635 7.33115 23.3064 9.65892 23.7694C11.9867 24.2324 14.3995 23.9948 16.5922 23.0866C18.7849 22.1783 20.6591 20.6402 21.9776 18.6668C23.2962 16.6935 24 14.3734 24 12C23.9966 8.81846 22.7312 5.76821 20.4815 3.51852C18.2318 1.26883 15.1815 0.00344108 12 0V0ZM12 22C10.0222 22 8.08879 21.4135 6.4443 20.3147C4.79981 19.2159 3.51809 17.6541 2.76121 15.8268C2.00433 13.9996 1.8063 11.9889 2.19215 10.0491C2.578 8.10929 3.53041 6.32746 4.92894 4.92893C6.32746 3.53041 8.10929 2.578 10.0491 2.19215C11.9889 1.8063 13.9996 2.00433 15.8268 2.7612C17.6541 3.51808 19.2159 4.79981 20.3147 6.4443C21.4135 8.08879 22 10.0222 22 12C21.9971 14.6513 20.9426 17.1931 19.0679 19.0679C17.1931 20.9426 14.6513 21.9971 12 22Z' fill='%23A52A2A'/%3E%3C/g%3E%3Cdefs%3E%3CclipPath id='clip0_379_2718'%3E%3Crect width='24' height='24' fill='white'/%3E%3C/clipPath%3E%3C/defs%3E%3C/svg%3E");
					}

					.status-icon.INTERNAL_ABORTED_RETRY,
					.status-icon.ABORTED_RETRY,
					.status-icon.FAILURE_RETRY {
					border-color: #A52A2A;
					color: #A52A2A;
					background-color: #FEEFEF;
					}
					a.IMAGE, a.CUSTOM, a.CUSTOM2, a.CUSTOM4{color:black}
					div.CUSTOM{background-color:yellow;}
					div.CUSTOM2{background-color:#EFEFEF;}
					div.CUSTOM3{background-color:green;}
					div.CUSTOM4{background-color:violet;}
					div.CUSTOM5{background-color:indigo;}
					div.CUSTOM {
					background-color: #fdfda0;
					border-left: 8px solid #ffd400;
					border-radius: 10px;
					padding-left: 10px;
					}

					div.CUSTOM1 {
					background-color: #fbe9c8;
					border-left: 8px solid #EFA41C;
					border-radius: 10px;
					padding-left: 10px;
					}

					div.CUSTOM2 {
					background-color: #EFEFEF;
					border-left: 8px solid #AEAEAE;
					border-radius: 10px;
					padding-left: 10px;
					}

					div.CUSTOM3 {
					background-color: #e3fbd1;
					border-left: 8px solid #3B8004;
					border-radius: 10px;
					padding-left: 10px;
					}

					div.CUSTOM4 {
					background-color: #ffd6ff;
					border-left: 8px solid #EC82EE;
					border-radius: 10px;
					padding-left: 10px;
					}

					div.CUSTOM5 {
					background-color: #eed5ff;
					border-left: 8px solid #4C0781;
					border-radius: 10px;
					padding-left: 10px;
					}
					
					div.SUCCESS:not(.GROUP_LABEL, .OBJECT_LABEL){
						background-color: #e9f9de;
						border-left: 5px solid #3B800440;
						padding: 10px 20px;
					}

					div.SUCCESS + div.SUCCESS {
						margin-top: -12px;
					}

					div.SUCCESS:has( > .placeHolderParent > a.SUCCESS),
					div.SUCCESS:has( > .placeHolderParent.SUCCESS) {
					background-color: #e9f9de;
					border-left: 5px solid #3B800440;
					padding: 10px 20px;
					}

					div.HEALED:has( > .placeHolderParent > a.SUCCESS),
					div.HEALED:has( > .placeHolderParent.SUCCESS),
					div.HEALED_SUCCESS:has( > .placeHolderParent > a.SUCCESS),
					div.HEALED_SUCCESS:has( > .placeHolderParent.SUCCESS) {
					background-color: #DEFFC3;
					border-left: 8px solid #67E900;
					padding: 10px 20px;
					}

					div.ERROR:not(.GROUP_LABEL, .OBJECT_LABEL){
						background-color: #ffecec;
						border-left: 5px solid #C0010040;
						padding: 10px 20px;
					}

					div.ERROR:has( > .placeHolderParent > a.ERROR),
					div.ERROR:has( > .placeHolderParent.ERROR) {
					background-color: #ffecec;
					border-left: 5px solid #C0010040;
					padding: 10px 20px;
					}

					div.FAILURE:not(.GROUP_LABEL, .OBJECT_LABEL){
						background-color: #ffecec;
						border-left: 5px solid #C0010040;
						padding: 10px 20px;
					}

					div.ABORTED:not(.GROUP_LABEL, .OBJECT_LABEL),
					div.ABORTED_TIMEOUT:not(.GROUP_LABEL, .OBJECT_LABEL),
					div.USER_ABORTED:not(.GROUP_LABEL, .OBJECT_LABEL),
					div.INTERNAL_ABORTED_RETRY:not(.GROUP_LABEL, .OBJECT_LABEL),
					div.INTERNAL_ABORTED:not(.GROUP_LABEL, .OBJECT_LABEL) {
						background-color: #FEEFEF;
						border-left: 8px solid #A52A2A;
						padding: 10px 20px;
					}

					div.FAILURE:has( > .placeHolderParent > a.FAILURE),
					div.FAILURE:has( > .placeHolderParent.FAILURE) {
					background-color: #ffecec;
					border-left: 5px solid #C0010040;
					padding: 10px 20px;
					}

					div.SUCCESS:has(+ div.SUCCESS),
					div.FAILURE:has(+ div.FAILURE),
					div.ERROR:has(+ div.ERROR) {
						margin-top: 0;
						margin-bottom: -12px;
					}

					/* SUCCESS, HEALED, ABORTED, ERROR, FAILURE, USER_ABORTED, ABORTED_TIMEOUT */
					div.SUCCESS:first-child,
					div.SUCCESS:first-of-type,
					div:not(.SUCCESS) + div.SUCCESS {
					border-top-left-radius: 10px !important;
					}

					div.FAILURE:first-child,
					div.FAILURE:first-of-type,
					div:not(.FAILURE) + div.FAILURE {
					border-top-left-radius: 10px !important;
					}

					div.ERROR:first-child,
					div.ERROR:first-of-type,
					div:not(.ERROR) + div.ERROR {
					border-top-left-radius: 10px !important;
					}

					div.ABORTED:first-child,
					div.ABORTED:first-of-type,
					div:not(.ABORTED) + div.ABORTED,
					div.USER_ABORTED:first-child,
					div.USER_ABORTED:first-of-type,
					div:not(.USER_ABORTED) + div.USER_ABORTED,
					div.ABORTED_TIMEOUT:first-child,
					div.ABORTED_TIMEOUT:first-of-type,
					div:not(.ABORTED_TIMEOUT) + div.ABORTED_TIMEOUT {
						border-top-left-radius: 10px !important;
					}

					div.SUCCESS:last-child,
					div.SUCCESS:last-of-type,
					div.SUCCESS:has(+ div:not(.SUCCESS))
					{
					border-bottom-left-radius: 10px;
					}

					div.ERROR:last-child,
					div.ERROR:last-of-type,
					div.ERROR:has(+ div:NOT(.ERROR))
					{
					border-bottom-left-radius: 10px;
					}

					div.FAILURE:last-child,
					div.FAILURE:last-of-type,
					div.FAILURE:has(+ div:not(.FAILURE))
					{
					border-bottom-left-radius: 10px;
					}

					div.ABORTED:last-child,
					div.ABORTED:last-of-type,
					div.ABORTED:has(+ div:not(.ABORTED)),
					div.USER_ABORTED:last-child,
					div.USER_ABORTED:last-of-type,
					div.USER_ABORTED:has(+ div:not(.USER_ABORTED)),
					div.ABORTED_TIMEOUT:last-child,
					div.ABORTED_TIMEOUT:last-of-type,
					div.ABORTED_TIMEOUT:has(+ div:not(.ABORTED_TIMEOUT))
					{
					border-bottom-left-radius: 10px;
					}
					
					.GROUP {
					border: none;
					position: relative;
					}

					.GROUP:has(>.hide-div) {
					padding: 0;
					margin: 0;
					}
					
					.GROUP_LABEL.collapser::before,
					.OBJECT_LABEL.collapser::before, {
					transform: rotate(0deg);
					transition: transform 300ms ease-in-out;
					}
					
					
					.OBJECT_LABEL::before {
					width: 18px;
					height: 18px;
					}
					.OBJECT_LABEL {
					display: inline-flex !important;
					padding-top: 0px !important;
					}
					.OBJECT_LABEL.collapser {
					font-size: 15px;
					}
					
					div.GROUP_LABEL.GROUP_START.SUCCESS {
					margin-bottom: 4px;
					}

					
					div.GROUP_LABEL.GROUP_START.FAILURE {
					margin-bottom: 4px;
					}

					div.GROUP_LABEL.GROUP_START::before {
					background-color: white;
					}

					div.GROUP_LABEL.TESTCASE_START span,
					div.GROUP_LABEL.GROUP_START span {
					font-size: 14px;
					line-height: 19px;
					margin: 0;
					margin-left: 10px;
					}
					.GROUP_INNER {
					position: relative;
					padding: 10px;
					padding-left: 40px;
					/*border-left: 4px solid #092572;
					border-radius: 5px;*/
					}

					.GROUP_INNER::before {
					content: '';
					display: inline-block;

					width: 3px;
					border-radius: 5px;
					background-color: #092572;
					opacity: 10%;

					position: absolute;
					left: 0;
					top: 5px;
					bottom: 5px;
					}

					.GROUP_INNER:has(.GROUP) {
					padding-left: 20px;
					}
					.GROUP_INNER div {
					margin-bottom: 4px;
					}
					.GROUP_ARGS_CONTAINER, .GROUP_OBJECT_ARG, .OBJECT_LABEL, .GROUP_ARG{
					padding: 0;
					cursor: pointer;
					}
					
					.OBJECT_DETAIL {
						display: none;
						white-space: pre;
						word-break: keep-all;
						max-width: 400px;
					}
					.GROUP_ARGS_CONTAINER,
					.GROUP_ARGS_CONTAINER div {
					margin: 0 !important;
					}
					.GROUP_ARG {
						padding: 1px 0px;
					}

					.GROUP_ARGS_CONTAINER {
						max-width: min-content;
						gap: 2px;
						align-items: flex-start;
					}

					span.extra {
					color: #666666;
					font-size: 12px;
					font-weight: 400;
					}
					 .datadrive-table {
                min-width: 800px;
            }

            .datadrive-table .table-header th:first-child {
                /*text-align: center;*/
                padding-left: 40px;
            }

            .datadrive-table .table-header th:only-child, .datadrive-table .table-data td:only-child {
                text-align: center;
            }
            
            .datadrive-table .table-header th {
                border: none;
                font-weight: 500 !important;
            }
            
            .datadrive-table tr.table-header {
                border-left: 5px solid #E2EAFF;
            }

            .datadrive-table td {
                border: none;
                font-family: Arial, Helvetica, sans-serif;
                padding: 11px 25px 11px 20px;
                text-align: left;
            }

            .datadrive-table td:first-child {
                padding-left: 40px;
            }

            .datadrive-table td.details {
                text-align: left;
                padding: 0;
                padding-left: 20px;
            }

            .datadrive-table div.details {
                margin-left: 0;
            }

            .scenario-report .datadrive-table tbody tr.step_SUCCESS {
                background-color: #EBFFDB;
                border-left: 3px solid #EBFFDB;
            }

            .datadrive-table tbody tr.step_SUCCESS + tr {
                border-left:3px solid #DEF1CF;
            }

            .scenario-report .datadrive-table tbody tr.step_FAILURE {
                background-color: #FFE9E9;
                border-left: 3px solid #FFE9E9;
            }
			.scenario-report tr.step_ABORTED,
			table.datadrive-table tr.step_ABORTED {
				background-color: #f5a9a7;
			}

			.datadrive-table tbody tr.step_ABORTED {
				border-left: 3px solid #f5a9a7;
			}

            .datadrive-table tbody tr.step_FAILURE + tr {
				border-left: 3px solid #FFE9E9;
			}
			.loglineStart{cursor:pointer;}
			.scenario-report tr.step_SUCCESS, table.datadrive-table tr.step_SUCCESS {background-color: #EBFFDB;}
			.scenario-report .status-column .flex-row {display: inline-flex;}		
			 table.fwTable td, .keyword-row td, .testcase-title-row td, .datadrive-info-row td {
			    border: 0px;margin: 0px;padding: 10px 20px !important;
			 }
			 
			 .scenario-report tr.loglineStart.show-arrow td.keywords-column::before {
			     width: 20px;height: 20px;
			     top: 6px;left: -6px;
			 }				
					.scenario-report tr.data > td:first-child::before {
						position: absolute !important;
						top: unset !important;
						left: 20px !important;
					}

					.scenario-report tr.data.expander td:first-child::before, .scenario-report tr.loglineStart.expander td.keywords-column::before {
					    transform: rotate(-90deg);
					}
					.scenario-report tr.data.collapser td:first-child::before,
					.scenario-report tr.loglineStart.collapser table.fwTable td:first-child::before,
					.scenario-report tr.loglineStart.collapser td.keywords-column::before {
						transform: rotate(0deg) !important; 
					}
					.loglineStart.step_SUCCESS td.fwDataTD,.loglineStart.step_FAILURE td.fwDataTD {
					    font-size: 14px;line-height: 15px;
					}
					.scenario-report tr.step_FAILURE, table.datadrive-table tr.step_FAILURE {
					    background-color: #FFE9E9;
					}
					.testcase .table-header th {text-align: left;font-weight: 600}
					
					.scenario-report > table > tbody > tr.loglineStart td.fwDataTD {
					width: fit-content;
					}
					.fwTable td {
					   min-width: 180px;max-width: 180px;
					   word-wrap: break-word;word-break: break-word;
					}
					.steps table {margin: 0;}
					tr.testcase-row, table.testcase {
						position: relative;
					}
					table.fwTable{border:0px;}
					.scenario-report > table, table.fwTable, table.testcase {
                       width: 100%;min-width: max(90vw, 1200px);
                    }
                    table.testcase > tbody > tr:not(:first-child) > td:first-child, table.testcase > tbody > tr > th:first-child {
                       border-left: 1px solid #66666654;
                    }
                    table.testcase > tbody > tr:not(:first-child) > td:last-child, table.testcase > tbody > tr > th:last-child {
                       border-right: 1px solid #66666654;
                    }
                    .scenario-report tr.data td:first-child::before,
					.scenario-report tr.loglineStart.show-arrow table.fwTable td:first-child::before,
					.scenario-report tr.loglineStart.show-arrow td.keywords-column::before {
						content: '';display: inline-block;
						width: 20px;height: 20px;
						background-image: url("data:image/svg+xml,%3Csvg width='20' height='20' viewBox='0 0 20 20' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath d='M15.5916 6.84167C15.5141 6.76356 15.4219 6.70156 15.3204 6.65926C15.2188 6.61695 15.1099 6.59517 14.9999 6.59517C14.8899 6.59517 14.781 6.61695 14.6794 6.65926C14.5779 6.70156 14.4857 6.76356 14.4082 6.84167L10.5916 10.6583C10.5141 10.7364 10.4219 10.7984 10.3204 10.8407C10.2188 10.883 10.1099 10.9048 9.99989 10.9048C9.88988 10.9048 9.78096 10.883 9.67941 10.8407C9.57786 10.7984 9.48569 10.7364 9.40822 10.6583L5.59155 6.84167C5.51409 6.76356 5.42192 6.70156 5.32037 6.65926C5.21882 6.61695 5.1099 6.59517 4.99989 6.59517C4.88988 6.59517 4.78096 6.61695 4.67941 6.65926C4.57786 6.70156 4.48569 6.76356 4.40822 6.84167C4.25301 6.9978 4.16589 7.20901 4.16589 7.42917C4.16589 7.64932 4.25301 7.86053 4.40822 8.01666L8.23322 11.8417C8.70197 12.3098 9.33739 12.5728 9.99989 12.5728C10.6624 12.5728 11.2978 12.3098 11.7666 11.8417L15.5916 8.01666C15.7468 7.86053 15.8339 7.64932 15.8339 7.42917C15.8339 7.20901 15.7468 6.9978 15.5916 6.84167V6.84167Z' fill='%23092572'/%3E%3C/svg%3E");
						background-size: contain;background-repeat: no-repeat;position: relative;
						left: 5px;top: 5px;
						transform: rotate(-90deg);
					}
					.scenario-report tr.loglineStart.show-arrow table.fwTable td:first-child::before {
						width: 24px;
						height: 24px;
						top: 0;
					}
					.scenario-report td,
					.scenario-report th {
						border: none !important;
					}
					.scenario-report td {
						font-size: 14px;
					}
					.border-none {
					   border: none;border-spacing: 0;
					   border-collapse: collapse;
					}
					.testcase-title-row td.title {
						color: #092572;
						font-size: 16px;
						text-align: left;
						font-weight: 600;
						white-space: nowrap;
						padding-left: 5px;
					}
					tr.testcase-row  tr.testcase-title-row > td.title::before {
						display: inline-block;
						content: '';

						position: absolute;
						left: -40px;

						background-image: url("data:image/svg+xml,%3Csvg width='20' height='20' viewBox='0 0 20 20' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath d='M15.5916 6.84167C15.5141 6.76356 15.4219 6.70156 15.3204 6.65926C15.2188 6.61695 15.1099 6.59517 14.9999 6.59517C14.8899 6.59517 14.781 6.61695 14.6794 6.65926C14.5779 6.70156 14.4857 6.76356 14.4082 6.84167L10.5916 10.6583C10.5141 10.7364 10.4219 10.7984 10.3204 10.8407C10.2188 10.883 10.1099 10.9048 9.99989 10.9048C9.88988 10.9048 9.78096 10.883 9.67941 10.8407C9.57786 10.7984 9.48569 10.7364 9.40822 10.6583L5.59155 6.84167C5.51409 6.76356 5.42192 6.70156 5.32037 6.65926C5.21882 6.61695 5.1099 6.59517 4.99989 6.59517C4.88988 6.59517 4.78096 6.61695 4.67941 6.65926C4.57786 6.70156 4.48569 6.76356 4.40822 6.84167C4.25301 6.9978 4.16589 7.20901 4.16589 7.42917C4.16589 7.64932 4.25301 7.86053 4.40822 8.01666L8.23322 11.8417C8.70197 12.3098 9.33739 12.5728 9.99989 12.5728C10.6624 12.5728 11.2978 12.3098 11.7666 11.8417L15.5916 8.01666C15.7468 7.86053 15.8339 7.64932 15.8339 7.42917C15.8339 7.20901 15.7468 6.9978 15.5916 6.84167V6.84167Z' fill='%23092572'/%3E%3C/svg%3E");
						width: 24px;
						height: 24px;
						background-size: contain;
						cursor: pointer;
					}

					tr.testcase-row > td:first-child.expander td.title::before {
						transform: rotate(0);
					}

					tr.testcase-row > td:first-child.collapser td.title::before {
						transform: rotate(-90deg);
					}

					tr.testcase-row > td:first-child {
					position: relative;
					padding: 10px 30px;
					}

					tr.testcase-row > td:first-child::before {
					content: '';
					display: inline-block;

					width: 3px;
					border-radius: 5px;
					background-color: #092572;
					opacity: 10%;

					position: absolute;
					left: 7px;
					top: 50px;
					bottom: 15px;
					}
					.table-header th {
						background-color: #E2EAFF; 
						border-bottom-width: 1.5px;
						color: #000;
						font-family: Arial, Helvetica, sans-serif;

						padding: 11px 15px 11px 10px;

						text-align: center;
						white-space: nowrap;
					}
					.FAILURE_ST {
					    background-color: #3f3f3f !important;
					    color: white;padding: 8px 12px;
					    margin: 5px 0;border-radius: 10px;
					}
					.FAILURE_ST * {
					   background-color: #3F3F3F !important;
					   color: #fff !important;
					}
					.script-name span {
						display: inline-block;
						max-width: 30ch;
						overflow: hidden;
						text-overflow: ellipsis;
						white-space: nowrap;
					}
					.scenario-report tr.testcase-title-row td.title {
						width: max(400px, 20vw);
						max-width: max(400px,20vw);
						overflow: hidden;
						text-overflow: ellipsis;
						white-space: nowrap;
					}
					.scenario-report tr.testcase-title-row td:not(.comments) {
						width: 400px;
						max-width: 400px;
						overflow: hidden;
						text-overflow: ellipsis;
						white-space: nowrap;
					}
					.steps .GROUP_LABEL span {
						font-weight: bolder;
						/*max-width: 500px;
						overflow: hidden;
						white-space: normal;
						overflow-wrap: break-word;*/
					}
					div.details{
					    border:0px solid #ccc;padding:10px 0px;
					    margin:10px 0px;display:none;
					    margin-left:35px;
				   }
				   .scenario-report .table-header th {
						padding-left: 20px;
					}
					.keyword-row > td:not(.empty-cell, .status-column) {
						width: max(400px, 20vw) !important;
					}
					.keyword-row .empty-cell, .keyword-row .status-column {
						width: 200px;
					}
					td.empty-cell,
					th.empty-cell {
						background-color: white;
					}
					.scenario-report tr.loglineStart.show-arrow td.keywords-column::before {
						width: 20px;
						height: 20px;
						top: 6px;
						left: -6px;
					}
					tr.testcase-row > td:first-child {
					   position: relative;
					   padding: 10px 30px 10px 37px;
					}
					
					.datadrive-row > td {
						position: relative;
					}

					.datadrive-row > td::before {
						content: '';
						display: inline-block;
						position: absolute;
						width: 2px;
						left: 0px;
						top: 1px;
						bottom: 10px;
					}

					.step_SUCCESS + .datadrive-row > td::before {
						/*background-color: #3B800466;*/
						background-color: #def1cf;
					}

					.step_FAILURE + .datadrive-row > td::before {
						background-color: #FFE9E9;
					}

					.data-header {
					   background-color: #E2EAFF;
					   width: fit-content;
					   padding: 10px 20px 10px 5px;
					   margin-bottom: -10px;margin-left: 10px;margin-top: 5px;
					   border-radius: 2px;
					   cursor: pointer;
					}

					.data-header .dd-row-count {
						font-size: 14px;
						margin-left: 20px;
					}

					.data-header::before {
						content: '';
						display: inline-block;
						width: 20px;
						height: 20px;
						background-size: contain;
						background-image: url("data:image/svg+xml,%3Csvg width='19' height='19' viewBox='0 0 19 19' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath d='M6.4998 4.18804C6.4256 4.26164 6.3667 4.3492 6.32651 4.44567C6.28632 4.54214 6.26563 4.64562 6.26563 4.75013C6.26563 4.85463 6.28632 4.95811 6.32651 5.05458C6.3667 5.15105 6.4256 5.23861 6.4998 5.31221L10.1256 8.93804C10.1998 9.01164 10.2587 9.0992 10.2989 9.19567C10.3391 9.29214 10.3598 9.39562 10.3598 9.50013C10.3598 9.60463 10.3391 9.70811 10.2989 9.80458C10.2587 9.90105 10.1998 9.98861 10.1256 10.0622L6.4998 13.688C6.4256 13.7616 6.3667 13.8492 6.32651 13.9457C6.28632 14.0421 6.26562 14.1456 6.26562 14.2501C6.26562 14.3546 6.28632 14.4581 6.32651 14.5546C6.3667 14.6511 6.4256 14.7386 6.4998 14.8122C6.64813 14.9597 6.84878 15.0424 7.05792 15.0424C7.26707 15.0424 7.46772 14.9597 7.61605 14.8122L11.2498 11.1785C11.6945 10.7331 11.9444 10.1295 11.9444 9.50013C11.9444 8.87075 11.6945 8.26711 11.2498 7.82179L7.61605 4.18804C7.46772 4.04059 7.26707 3.95783 7.05792 3.95783C6.84878 3.95783 6.64813 4.04059 6.4998 4.18804V4.18804Z' fill='%23092572'/%3E%3C/svg%3E");
					}

					.data-header.collapser::before {
						transform: rotate(90deg);
					}

					.data-header.expander::before {
						transform: rotate(0deg);
					}

					table.datadrive-table {
					   margin: 5px 10px 10px 10px !important;
					}
					#tcSummary .script-name span {
					   white-space: normal;
					   overflow-wrap: anywhere;
					}
					.scenario-report tr.testcase-title-row td.title { white-space: normal;}
					td.description span {
					  display: inline-block;max-width: 500px;
					  overflow: hidden;white-space: break-spaces;
					  overflow-wrap: anywhere;
					}
					#banner {
					   position: fixed;
					   display:none;
					   top: 0; left: 25%;
					   border-left: 8px solid #E62E2D;
					   border-radius: 10px;
					   background-color: #FFE6E5;
					   z-index: 100;width: 630px;
					   box-shadow: 0px 4px 14px 0px #5f5f5f;
					}
					#banner img {margin-top: 15px; margin-left: 10px; height: 40px}
					.warn { margin: 12px; line-height: 24px }
					.warn span, .warn strong {font-size: 16px}
					#warn {color: red}

					.stacktrace * {
					background-color: #3F3F3F !important;
					color: #fff !important;
					}

					.FAILURE_ST .status-icon,
					.stacktrace .status-icon {
						position: absolute;
						display: inline-flex;
						top: 4px;
						right: 20px;
						padding: 4px 6px;
						border-radius: 12px;
					}

					.show-more-keywords {
						/*margin-left: 5px;*/
						padding: 1px 3px;
						background-color: lightyellow;
						border-radius: 1px;
						box-shadow: 0 0 1px black;
						cursor: pointer; 
						white-space: nowrap;
						display: none;
					}

					.GROUP_LABEL {
						position: relative;
					}

					.OBJECT_DETAIL::before {
						display: inline-block;
						content: '';
						width: 3px;
						position: absolute;
						top: 30px;
						bottom: -10px;
						left: 0;
						background-color: #092572;
						opacity: 10%;
					}
				]]></style>
				<title><xsl:value-of select="result/summary/SCRIPTNAME"/></title>
			</head>

			<body onunload="onUnload()" onload="onLoad()">
				<script><![CDATA[
					function replaceObjectArgs(fnString){
						fnString = fnString.replace("[+]", "").replace("[-]", "");

						var fnNameLength = fnString.indexOf("(");
						var fnName = "<span class='step-message'>" + fnString.substr(0, fnNameLength) + "</span>";

						var scriptTags = document.getElementsByTagName("script");
						var parentGroup = scriptTags[scriptTags.length-1].parentNode.parentNode.getElementsByTagName("DIV")[0];
						var iconSpan = parentGroup.querySelector('span.status-icon');
						//scriptTags[scriptTags.length-1].parentNode.parentNode.getElementsByTagName("DIV")[0].innerHTML = fnString;
						parentGroup.innerHTML = fnName + fnString.substr(fnNameLength);
						if (iconSpan)
							parentGroup.appendChild(iconSpan);
					}

					function showMoreKeywords(showMoreBtn) {
						const keywordsSpan = showMoreBtn.parentNode?.firstElementChild;
						if (keywordsSpan) {
							const wrapBehavior = keywordsSpan.style.whiteSpace;
							if (wrapBehavior == 'nowrap') {
								keywordsSpan.style.whiteSpace = 'normal';
								showMoreBtn.innerText = 'show less';
							} else {
								keywordsSpan.style.whiteSpace = 'nowrap';
								showMoreBtn.innerText = 'show more';
							}
						}
					}
				]]></script>
				<xsl:apply-templates />
			</body>
		</html>
	</xsl:template>

	<xsl:template match="testCaseSummaries">
		<table id="tcSummary" class="summary" style="margin-top: 50px">
		<xsl:for-each select="testCaseSummary">
			<xsl:if test="(position()) = 1">
			<thead>
				<tr class='table-header'>
				   <th>Test Case Id</th>
					<th>
						<span style="white-space:nowrap;display:inline-block">Final Status</span><br />
					</th>
					<th>Description</th>
					<th>
						<span style="white-space:nowrap;display:inline-block">Intermediate Statuses</span><br />
					</th>
					 <th>Time Taken</th>
				 </tr>
			</thead>
			
		    </xsl:if>
			<xsl:param name="cn" select="tcstatus|TCSTATUS" />
			<xsl:param name="timeTaken" select="timeTaken|TIMETAKEN" />
			<tr class="table-data">
					<td class='script-name'>
						<span>
							<xsl:attribute name="title">
								<xsl:value-of disable-output-escaping="no" select="testCaseReportId|TESTCASEREPORTID" />
							</xsl:attribute>
							<xsl:text>
								<xsl:value-of disable-output-escaping="no" select="testCaseReportId|TESTCASEREPORTID" />
							</xsl:text>
						</span>
					</td>
					<td>
						<span class="flex-row {$cn} status-icon">
							<xsl:value-of disable-output-escaping="yes" select="translate(tcStatus|TCSTATUS, $uppercase, $lowercase)" />
							<!-- <xsl:value-of disable-output-escaping="yes" select="tcstatus|TCSTATUS" /> -->
						</span>
					</td>
					<td class="description">
						<span><xsl:value-of disable-output-escaping="no" select="description|DESCRIPTION" /></span>
					</td>
					<td class="intermediateStatusCell">
						<xsl:param name="tcintermediateStatus" select="tcintermediatestatuses|TCINTERMEDIATESTATUSES" />
						<xsl:choose>
							<xsl:when test="$tcintermediateStatus != '' and $tcintermediateStatus != 'null'">
								<xsl:value-of select="tcintermediatestatuses|TCINTERMEDIATESTATUSES" />
							</xsl:when>
							<xsl:otherwise>NA</xsl:otherwise>
						</xsl:choose>
					</td>
					<td class="time-taken">
						<xsl:attribute name="data-text">
							<xsl:value-of disable-output-escaping="yes" select="util:prettyTimeMoreThan24Hours($timeTaken)" />
						</xsl:attribute>
					</td>
				</tr>
		</xsl:for-each>
		</table>
	</xsl:template>

	<xsl:template match="summary">
		<xsl:param name="className" select="scriptstatus|SCRIPTSTATUS" />
		<xsl:param name="stepsCount" select="number(steps|TOTALSTEPS)" />
		<xsl:param name="failures" select="number(failures|FAILURES)" />
		<xsl:param name="errors" select="number(errors|ERRORS)" />
		<xsl:param name="suiteReportId" select="suiteReportId|SUITEREPORTID" />
		<xsl:param name="scriptReportId" select="scriptReportId|SCRIPTREPORTID" />
		<xsl:param name="load" select="number(loadcount|LOADCOUNT)" />
		<script type="text/javascript">var scriptReportID = '<xsl:value-of select="scriptReportId|SCRIPTREPORTID"/>'</script>
		<script type="text/javascript" src="/_s_/spr/util.js"></script>
		<script type="text/javascript"> 
		   window.onload = ('event',function() {
		     if(sahiIsIE()){
               let bannerId = document.getElementById('banner');
               bannerId.style.display = 'inline-flex';
             } else {
				onLoad();
			 }
		   });
        </script>
		<xsl:choose>
			<xsl:when test="$useDBURL = 'true'"> 
 				   <div id="banner"> 
 				       <div>
 				          <img src="/_s_/spr/images/caution_Icon_red.svg"/> 
 				       </div> 
 				       <div class="warn"> 
 				         <span id="warn">This Browser is not compatible. </span> 
 				         <span>Kindly switch to any modern browsers like 
 				           <strong>Google Chrome, Mozilla Firefox, Microsoft Edge, </strong><span>etc.</span> 
 				         </span> 
 				       </div> 
 				   </div> 
				<div class='navbar-container'>
					<div id='navbar' class='flex-row logo-header'>
						<a class="nav-sahi-logo" onclick="window.location.href='/_s_/dyn/pro/DBReports';" style="cursor: pointer; height: 50px;"><span id="sahi-logo" class="bg-sahi-logo"></span></a>
						<a href='/_s_/dyn/pro/DBReports'>Suites</a>
						<div id="compareScreenshots">Comparing ScreenShots</div>
					</div>
				</div>
			</xsl:when>
			<xsl:otherwise>
				<div id='navbar' class='flex-row logo-header'>
            		<a class="nav-sahi-logo" onclick="window.location.href='/_s_/dyn/pro/DBReports';" style="cursor: pointer;"><span id="sahi-logo" class="bg-sahi-logo"></span></a>
					<a href='/_s_/dyn/pro/DBReports'>Suites</a>
					<div id="compareScreenshots">Comparing ScreenShots</div>
	       		</div>
			</xsl:otherwise>
		</xsl:choose>
		
		<table class="summary" style="margin-top: 50px">
		     <tr class="table-header">
				<th>Script Name:</th>
				<th style="font-weight:600"><xsl:value-of select="scriptName|SCRIPTNAME" /></th>
				 <xsl:for-each select="/result/otherSummary">
			 	 <th style="font-weight:600"><xsl:value-of select="scriptName|SCRIPTNAME" /></th>
			  </xsl:for-each>
			 </tr>
			 <tr class='table-data'>
			   <td>Final Status:</td>
			   <xsl:variable name="className" ><xsl:value-of select="scriptstatus|SCRIPTSTATUS" /></xsl:variable>
			     <td>
				   <span class="{$className} flex-row status-icon">
					  <span><xsl:value-of select="translate(scriptstatus|SCRIPTSTATUS, $uppercase, $lowercase)" /></span>
				   </span>
			     </td>
			   <xsl:for-each select="/result/otherSummary">
			   <xsl:variable name="className" ><xsl:value-of select="scriptstatus|SCRIPTSTATUS" /></xsl:variable>
			     <td>
				   <span class="{$className} flex-row status-icon">
					  <span><xsl:value-of select="translate(scriptstatus|SCRIPTSTATUS, $uppercase, $lowercase)" /></span>
				   </span>
			     </td>
			   </xsl:for-each> 
			 </tr>
			 <tr class='table-data'>
			   <td>Start Time:</td>
			   <td class="date-time">
			       <xsl:attribute name="data-text">
							<xsl:value-of select="util:humanTime(STARTTIME)" />
				   </xsl:attribute>
			   </td>
			   <xsl:for-each select="/result/otherSummary">
			   <td class="date-time">
			       <xsl:attribute name="data-text">
							<xsl:value-of select="util:humanTime(STARTTIME)" />
				   </xsl:attribute>
			   </td>
			   </xsl:for-each> 
			 </tr>
			 <tr class='table-data'>
			   <td>Time Taken:</td>
			   <td><span class='time-taken' style="font-weight: bold;">	
						<xsl:attribute name="data-text">
							<xsl:value-of select="util:prettyTimeMoreThan24Hours(timeTaken|TIMETAKEN)" />
						</xsl:attribute>
					</span>
			   </td>
			   <xsl:for-each select="/result/otherSummary">
			     <td><span class='time-taken' style="font-weight: bold;">	
						<xsl:attribute name="data-text">
							<xsl:value-of select="util:prettyTimeMoreThan24Hours(timeTaken|TIMETAKEN)" />
						</xsl:attribute>
					</span>
			   </td>
			   </xsl:for-each>
			 </tr>
			 <tr class='table-data'>
			   <td>Browser:</td>
			   <td class="browser-type" style="font-weight: bold;">
			        <xsl:attribute name="data-text">
			           <xsl:value-of select="scriptinfo|SCRIPTINFO" />
			        </xsl:attribute>
			     </td>
			   <xsl:for-each select="/result/otherSummary">
			     <td class="browser-type" style="font-weight: bold;">
			        <xsl:attribute name="data-text">
			           <xsl:value-of select="scriptinfo|SCRIPTINFO" />
			        </xsl:attribute>
			     </td>
			   </xsl:for-each>
			 </tr>
			 <tr class='table-data'>
			   <td>Total Steps:</td>
			    <td style="font-weight: bold;"><xsl:value-of select="$stepsCount"/></td>
			   <xsl:for-each select="/result/otherSummary">
			   <xsl:variable name="stepCount" ><xsl:value-of select="number(steps|TOTALSTEPS)" /></xsl:variable>
			   <td style="font-weight: bold;"><xsl:value-of select="$stepCount"/></td>
			   </xsl:for-each>
			 </tr>
		   </table>
		
	</xsl:template>

	<xsl:template match="steps|STEPS">
	  <div id="stepsDiv">	
		<xsl:param name="isExcel">
				<xsl:value-of select="util:endsWith($scriptName, '.xls') or util:endsWith($scriptName, '.xlsx') or util:endsWith($scriptName, '.s.csv')"/> 
		</xsl:param>
		<br />
		<div class="START flex-row">
				<span><a class="START">Starting script</a></span>
				<span class='table-button expand-all'><a href="javascript:void(0)" onclick="javascript:expandAll('{$isExcel}'); return false;">Expand All</a></span>
				<span class='table-button collapse-all'><a href="javascript:void(0)" onclick="javascript:collapseAll('{$isExcel}'); return false;">Collapse All</a></span>
		</div>
		<div class="steps">
		<xsl:for-each select="step">
			<xsl:param name="ix" select="position()" />
			<xsl:param name="type" select="messagesubtype|MESSAGESUBTYPE" />
			<xsl:param name="className" select="type|MESSAGETYPE" />
			<xsl:param name="debugInfo" select="debugInformation|DEBUGINFORMATION" />
			<xsl:param name="failureMsg" select="failureMsg|FAILUREMESSAGE" />
			<xsl:param name="result" select="stepmessage|STEPMESSAGE" />
			<xsl:param name="scriptReportId" select="scriptReportId|SCRIPTREPORTID" />
			<xsl:param name="screenShot" select="SCREENSHOT" />
			
			<xsl:param name="debugInfoGit" select="util:replaceScriptPathForGit($debugInfo, $gitScriptPath)" />
			<xsl:param name="isExcel">
				<xsl:value-of select="util:endsWith($scriptName, '.xls') or util:endsWith($scriptName, '.xlsx')"/> 
			</xsl:param>
			<xsl:choose>
				<xsl:when test="starts-with($result,'_log') and $className!=&quot;ERROR&quot;">
				</xsl:when>
				<xsl:when test="$isExcel=&quot;true&quot; and ($className=&quot;TESTCASE_START&quot; or $className=&quot;TESTCASE_END&quot;)">
				</xsl:when>				
				<xsl:when test="$className=&quot;RAW&quot;">
					<xsl:value-of disable-output-escaping="yes" select="stepmessage|STEPMESSAGE" />
				</xsl:when>
				<xsl:when test="$className=&quot;TESTCASE_START&quot; or $className=&quot;GROUP_START&quot;">
					<xsl:text disable-output-escaping="yes">
						<![CDATA[
							<div class="GROUP">
				 		]]>
				 		</xsl:text>
						<div class="GROUP_LABEL flex-row expander {$className} {$failureMsg}">
						    
						    <span class="step-message"><xsl:value-of select="stepmessage|STEPMESSAGE" /></span>
							<xsl:if test="not($failureMsg='FAILURE' or $failureMsg='ERROR')">
								<span class="flex-row status-icon {$failureMsg}">
									<xsl:value-of select="translate($failureMsg, $uppercase, $lowercase)" />
								</span>
							</xsl:if>
						</div>
						<xsl:text disable-output-escaping="yes">
						<![CDATA[
						<div class="GROUP_INNER" style="display: none;">
						]]>
						</xsl:text>
				</xsl:when>
				<xsl:when test="$className=&quot;TESTCASE_END&quot; or $className=&quot;GROUP_END&quot;">
					<xsl:text disable-output-escaping="yes">
					<![CDATA[
					</div></div>
					]]>
					</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<div class="{$className}" style="position: relative;">						
						<a class="{$className}" href="/_s_/dyn/Log_highlight?href={$debugInfoGit}{$commitIdURI}#selected"
							title="{$debugInfo}">
							<xsl:value-of disable-output-escaping="yes" select="stepmessage|STEPMESSAGE" />
						</a>
						<span class='extra'>
						<xsl:variable name="time" select="time|MESSAGETIMESTAMP" />
						<xsl:variable name="fixedTime" select="util:fixMillis($time)" />
						</span>
						<xsl:if test="not($failureMsg = '' or $failureMsg ='null')">
							<div class="FAILURE_ST"><xsl:value-of disable-output-escaping="yes" select="$failureMsg" /></div>
						</xsl:if>
						<xsl:if test="not($screenShot = '' or $screenShot ='null') and not(contains($screenShot, ','))">
							<div id="like_{$screenShot}" class="imagegroup">
							<a href="/_s_/dyn/Log_viewLogs/images/{$screenShot}" style="margin:0px;padding:0px" target="_blank"><img style="margin-top:15px;margin-bottom:30px;display:block;" src="/_s_/dyn/Log_viewLogs/images/{$screenShot}" height="337" width="500" /></a>
							</div>
						</xsl:if>
						
					</div>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
		
		<script type="text/javascript">
		var commitIdURI = "<xsl:value-of select="$commitIdURI"/>";
		var gitLogEnabled = <xsl:value-of select="util:isGitLogIntegrationEnabled()" />;
		var gitScriptPath = "<xsl:value-of select="$gitScriptPath"/>";
		<![CDATA[
		var openedElement = new Array();
		var cookieHashMap = {};
		function hideImage(i){i.style.display='none';}
       /* var divs = document.getElementsByTagName('DIV'); 
        for (var i=0; i<divs.length; i++){
        	var d = divs[i]; 
        	if (d.className == 'GROUP') { attachFn(d); markStatus(d);} 
        }*/
        
        function attachFn(d){ d.getElementsByTagName('DIV')[0].onclick = function (e) {showHideDiv(e,d);}} 
        function getInnerDiv(d){var els = d.getElementsByTagName('DIV'); for (var i=0; i<els.length;i++) {if (els[i].className == 'GROUP_INNER') return els[i];}}
        
        
        function showHideDiv(e,groupDiv){
        	var target = e.target;
        	if(target.className.indexOf("GROUP_ARG")!=-1 || target.className.indexOf("GROUP_OBJECT_ARG")!=-1 || target.className.indexOf("OBJECT_LABEL")!=-1) {
				while(target.firstElementChild && target.className.indexOf("OBJECT_LABEL")==-1){
					target = target.firstElementChild;
				}
			}
			if(target.className.indexOf("OBJECT_LABEL")!=-1){
        		showHideObjectDetailDiv(target);
        	} else if(target.className.indexOf("OBJECT_DETAIL")!=-1){
        		showHideObjectDetailDiv(target.parentNode.firstElementChild);
        	} else {
        		var stepsDiv = getInnerDiv(groupDiv);
	        	var els = document.getElementsByTagName('DIV');
	        	for(var i = 0; i < els.length; i++){
	        		if (els[i] == stepsDiv){
	        			if(stepsDiv.style.display == 'block' || stepsDiv.style.display == ''){
	        				removeFromCookieArray(i);
	        				stepsDiv.style.display = 'none';
	        				changeIconToPlus(groupDiv);
	        				break;
	        			}else{
	        				stepsDiv.style.display = 'block';
	        				addToCookieArray(i);
	        				changeIconToMinus(groupDiv);
	        				break;
	        			}
	        		}	
	        	}
        	}
        };
        
        function showHideObjectDetailDiv(d){
        	var objDetailDiv = d.parentNode.getElementsByTagName("div")[1];
        	var els = document.getElementsByTagName('div');
        	for(var i = 0; i < els.length; i++){
        		if (els[i] == objDetailDiv){
        			var elArgsContainer = d.parentNode.parentNode.parentNode;
        			var groupLabel = elArgsContainer.parentNode;
        			if(objDetailDiv.style.display == 'block'){
        				removeFromCookieArray(i);
        				objDetailDiv.style.display = 'none';
        				if(!isAnyArgumentExpanded(elArgsContainer)){
        					d.parentNode.style.display = 'inline-block'; 
        					showHideArgsContainerDiv(elArgsContainer, false);
							groupLabel.classList.remove('arg-expanded');  
        				}
        				changeIconToPlus(d);
        			}else{
        				objDetailDiv.style.display = 'block';   
        				showHideArgsContainerDiv(elArgsContainer, true); 
        				addToCookieArray(i);
        				changeIconToMinus(d);
        				groupLabel.classList.add('arg-expanded');
        			}
        			break;
        		}	
        	}
        };
        
         function isAnyArgumentExpanded(elArgsContainer){
        	var argsEls = elArgsContainer.getElementsByClassName("OBJECT_DETAIL");
			var isExpanded = false;
			for(var i=0;i<argsEls.length;i++){
				var el = argsEls[i];
				if(el.style.display=="block"){
					isExpanded = true; 
					break;   
				}
			}
			return isExpanded;
        }
        
        function showHideArgsContainerDiv(elArgsContainer, isShow){
        	var display = '';
        	var padding = '';
        	if(!isShow){
        		display='inline-block';
	        	padding='0';
        	} else {
   				display='block';
   				padding='0';
        	}
        }
        
		function markStatus(d) {
			d.getElementsByTagName('DIV')[0].className += (d.innerHTML.indexOf('<!--SAHI_TESTCASE_FAIL_MARKER-->') == -1) ? ' SUCCESS' : ' FAILURE';
			
			d.querySelector('span.status-icon.SUCCESS')?.remove();
			if (d.innerText.indexOf("[Global SetUp]") != -1 ||
				d.innerText.indexOf("[Global TearDown]") != -1
			) {
				const addCls = getStatusClass([...d.querySelector('.GROUP_LABEL').classList])
				if (!addCls || !addCls.length) return;
				if (d.querySelector('.status-icon')) {
					d.querySelector('.status-icon').classList.add(addCls[0]);
					d.querySelector('.status-icon').style.display = '';
					d.querySelector('.status-icon').innerText = addCls[0].toLowerCase();
				}
			}

			if (d.classList.contains("GROUP")) {
				var isUserAborted = d.querySelector(":scope > .GROUP_INNER > .USER_ABORTED");
				if (isUserAborted) {
					var groupLabel = d.querySelector('.GROUP_LABEL'); 
					groupLabel?.classList.add('USER_ABORTED');

					var pGroupLabel = null;
					var p = d;
					while (p && p.parentNode && p.parentNode.classList.contains('GROUP_INNER')) {
						var pGroupLabel = p.parentNode.previousElementSibling; 
						pGroupLabel?.classList.add('USER_ABORTED');
						p = p.parentNode.parentNode;
					}
					
					if (!pGroupLabel) pGroupLabel = p.querySelector('.GROUP_LABEL');

					pGroupLabel.innerHTML += "<span class='flex-row status-icon USER_ABORTED'>user aborted</span>";
				}
			}
		};
		function addToCookieArray(element){
			openedElement.push(element)
		}
		function removeFromCookieArray(element){
			removeByValue(openedElement,element)
		}
		function removeByValue(arr, val) {
			for ( var i = 0; i < arr.length; i++) {
				if (arr[i] == val) {
					arr.splice(i, 1);
					break;
				}
			}
		}
		function getStatusClass(elClasses) {
			var statusClasses = [ 'SUCCESS', 'FAILURE', 'ERROR', 'USER_ABORTED', 'ABORTED', 'ABORTED_TIMEOUT', 'INTERNAL_ABORTED', 'INTERNAL_ABORTED_RETRY', 'SKIPPED', 'NOT_SUPPORTED', 'FAILURE_RETRY', 'ABORTED_RETRY' ];
			return elClasses.filter(cls => statusClasses.find(stCls => cls === stCls))
		}
		function fixStatusIcons() {
			var statusClasses = [ 'SUCCESS', 'FAILURE', 'ERROR', 'USER_ABORTED', 'ABORTED', 'ABORTED_TIMEOUT', 'INTERNAL_ABORTED', 'INTERNAL_ABORTED_RETRY', 'SKIPPED', 'NOT_SUPPORTED', 'FAILURE_RETRY', 'ABORTED_RETRY' ];

			var statusIcons = [...document.querySelectorAll('.status-icon')];
			statusIcons.forEach(statusIcon => {
				const classes = statusIcon.className.replace("flex-row", "").replace("status-icon", "").trim();
				const isFound = statusClasses.findIndex(x => x==classes);
				if (isFound==-1) {
					statusIcon.style.setProperty('display', "none", 'important');
				}
			});
		}
		const isEllipsisActive = (e) => {
			return (e.offsetWidth < e.scrollWidth);
		}
		function onLoad(){
			splitStartAndEndTimeColumns();
			formatTimeTakenColumn();
			getBrowserType();
			//createObjectDiv();
			var divs = document.getElementsByTagName('DIV');
	        for (var i=0; i<divs.length; i++){
	        	var d = divs[i];
	        	//if (d.className == 'GROUP') { attachFn(d); markStatus(d);} 
	        	
	        	if (d.className == 'OBJECT_DETAIL') {
	        		try{
		        		var jsonStr = JSON.parse(sahiTrimForObjectDetail(d.innerHTML));
		        		var str = JSON.stringify(jsonStr, null, 4); // spacing level = 4
						d.innerHTML = str.replaceAll(/\n/g, "<br>").replaceAll(/\\n/g, "<br>\t\t");
	        		}catch(e){}
	        	}

	        	if (d.className.indexOf('GROUP_LABEL')!=-1 || d.className.indexOf('OBJECT_LABEL')!=-1) {
					d.innerHTML = d.innerHTML.replace("[+]", "");
				}

				if (d.className.indexOf('OBJECT_LABEL')!=-1) {
					d.classList.add('expander');
				}

				if (d.classList.contains('GROUP_ARG') || 
					d.classList.contains('GROUP_ARGS_CONTAINER')
				) {
					d.classList.add('flex-row');
				}
				if (d.classList.contains('GROUP_ARGS_CONTAINER')) {
					d.parentNode.style.alignItems = 'start';
					d.parentNode.style.marginTop = 10;
					var statusIcons = d.parentNode.getElementsByClassName("status-icon");
					if (statusIcons && statusIcons.length>0) {
						statusIcons[0].style.marginTop = -10;
					}
				}
	        }
			fixStatusIcons();
			var cookieValue = readCookie("OpenedElementSS");
			if(cookieValue){
				cookieHashMap = eval("("+cookieValue+")");
				openedElement=cookieHashMap[scriptReportID];
				if (!openedElement) openedElement = [];
				delete cookieHashMap[scriptReportID];
				var els = document.getElementsByTagName('DIV');
				for(var i = 0; i < openedElement.length; i++){
					if (!els[openedElement[i]]) continue;
					els[openedElement[i]].style.display = 'block';
					var iconDiv = els[openedElement[i]].parentNode.children[0];
					if(iconDiv.className.indexOf("GROUP_LABEL") == 0){
						iconDiv.classList.remove('expander');
					    iconDiv.classList.add('collapser');
						iconDiv.innerHTML = iconDiv.innerHTML.replace("[+]", "[-]");
					}
					if(iconDiv.className.indexOf("OBJECT_LABEL") == 0){
						var d = iconDiv;
						d.innerHTML = d.innerHTML.replace("[+]", "");
						var objDetailDiv = d.parentNode.getElementsByTagName("div")[1];
						objDetailDiv.style.display = 'block';
						showHideArgsContainerDiv(d.parentNode.parentNode.parentNode, true);
						changeIconToMinus(d);
				   }
				   if(iconDiv.className.indexOf("GROUP_LABEL") != 0 || iconDiv.className.indexOf("OBJECT_LABEL") != 0){
						iconDiv.innerHTML = iconDiv.innerHTML.replace("[+]", "");
					}
				}
			}
			addStatusBadgesForScenario();
			addEventListenersForScenario();
			divs = document.getElementsByTagName('DIV');
        	for (var i=0; i<divs.length; i++){ 
        	   var d = divs[i];
        	   if (d.className == 'GROUP') { attachFn(d); markStatus(d);} 
            }
            
            var keywords = document.getElementsByClassName("dd-keywords");
			for (var i=0; i<keywords.length; i++){
				var d = keywords[i].parentNode;
				var sp = d.getElementsByClassName("show-more-keywords")[0];
				if(isEllipsisActive(keywords[i])) sp.style.display = 'block';
				else sp.style.display = 'none';
			}
		}
		function onUnload(){
			var count = 0;
			var firstElement;
			for(firstElement in cookieHashMap){
				break;
			}
			for(var j in cookieHashMap){
				count++;
			}
			if(count == 10){
				delete cookieHashMap[firstElement];
			}
			cookieHashMap[scriptReportID] = openedElement;
			var cookieValue = getJSON(cookieHashMap);
			createCookie("OpenedElementSS", cookieValue, 1);
		}
		function getJSON(o) {
			var s = "{";
			for (var i in o) {
				s += "'" + i + "':[" + o[i] + "],"
			}
			s += "}";
			return s;
		}
		function createCookie(name,value,days)
		{
			if (days) {
				var date = new Date();
				date.setTime(date.getTime()+(days*24*60*60*1000));
				var expires = "; expires="+date.toGMTString();
			}
			else var expires = "";
			document.cookie = name+"="+value+expires+"; path=/";
		}
		
		function readCookie(name)
		{
			var nameEQ = name + "=";
			var ca = document.cookie.split(';');
			for(var i=0;i < ca.length;i++)
			{
				var c = ca[i];
				while (c.charAt(0)==' ') c = c.substring(1,c.length);
				if (c.indexOf(nameEQ) == 0) return c.substring(nameEQ.length,c.length);
			}
			return null;
		}
		function fixImagePaths(){
			if (location.href.indexOf("http://") == 0 || location.href.indexOf("https://") == 0) return;
			var imgs = document.getElementsByTagName('IMG'); 
	        for (var i=0; i<imgs.length; i++){
	        	var img = imgs[i]; 	        	
 				if (img.src.indexOf("Log_viewLogs/images") != -1) {
 					img.src = makeRelative(img.src);
 					if (img.parentNode.tagName.toLowerCase() == "a") {
 						img.parentNode.href = makeRelative(img.parentNode.href);
 					}
 				}
	        }
		}
		function makeRelative(s){
			var ix = s.indexOf("/images/"); 
			if (ix != -1) {
				s = s.substring(ix+1);
			}
			return s;
		}
		function showComparisonImages(steps){
			//var groups = document.getElementsByClassName("imagegroup");
			var groups = [];
            var groupsDiv = document.getElementsByTagName("div");
			for(var i=0; i<groupsDiv.length; i++){
				if(groupsDiv[i].className == "imagegroup"){
					groups.push(groupsDiv[i]);
				}
			}
			var grouped = groupSimilarImages(steps);
			//alert(grouped);
			for (var j=0; j<groups.length; j++) {
				var g = groups[j];
				var id = g.id.replace("like_", "");
				var images = grouped[id];
				g.innerHTML = "";
				if(!images) continue;
				for (var k=0; k<images.length; k++) {
					g.innerHTML += '<a href="/_s_/dyn/Log_viewLogs/images/' + images[k] + '" style="margin:0px;padding:0px" target="_blank"><img style="margin :15px 10px 30px ;filter:drop-shadow(0px 12px 24px rgba(50, 50, 50, 0.25));display:inline;" src="/_s_/dyn/Log_viewLogs/images/' + images[k] + '" height="337" width="500" /></a>';
				}
				//alert(images);
			}
			//for (var i=1; i<steps.length; i++) {
			//	document.write("<img src='" + steps[i][2] + "'></img>");
			//}
		}
		
        function expandAll(isExcel){
	        if(isExcel == "true"){
	        	ignoregroup_showHideAll(true);
	        }
	        var allDiv = document.getElementsByTagName('DIV');
        	for(var i=0; i<allDiv.length; i++){
        		if(allDiv[i].className.indexOf("GROUP_LABEL") != -1) {
					var thisEl = allDiv[i]
					if (thisEl.classList.contains('expander')) {
						thisEl.classList.remove('expander')
						thisEl.classList.add('collapser')
					}
				}
        		if(allDiv[i].className.indexOf("GROUP_INNER") != -1){
       				allDiv[i].style.display = "block";
        			addToCookieArray(i);
        			var iconDiv = allDiv[i].parentNode.children[0];
					if(iconDiv.className.indexOf("GROUP_LABEL") == 0){
						iconDiv.innerHTML = iconDiv.innerHTML.replace("[+]", "[-]");
					}
        		}
        	}

			var allDataDriveRows = document.querySelectorAll('.scenario-report tr.data');
			if (allDataDriveRows) {
				[...allDataDriveRows].forEach(row => {
					row.classList.add('collapser');
					row.classList.remove('expander');
				})
			}

			var allExpandableRows = document.querySelectorAll('.scenario-report tr.show-arrow');
			if (allExpandableRows) {
				[...allExpandableRows].forEach(row => {
					row.classList.add('collapser')
					row.classList.remove('expander')
				})
			}
			if (document.querySelector('.scenario-report')) {
				var tcRows = document.querySelectorAll('tr.testcase-row');
				if (tcRows && tcRows.length>0) {
					tcRows.forEach(row => {
						const firstCell = row.querySelector("td:first-child");
						firstCell.classList.add("expander");
						firstCell.classList.remove("collapser");
						
						[...row.querySelectorAll('table.testcase > tbody > tr:not(:first-child)')]
							.forEach(r => {
								r.style.display = ''
							})
					})
				}
			}

			var dataHeaders = document.querySelectorAll('div.data-header.expander');
			if (dataHeaders && dataHeaders.length>0) {
				dataHeaders.forEach(dataHeader => dataHeader.click())
			}
        }
        
        function collapseAll(isExcel){
        	if(isExcel == "true"){
	        	ignoregroup_showHideAll(false);
	        }
	        var allDiv = document.getElementsByTagName('DIV');
        	for(var i=0; i<allDiv.length; i++){
        		if(allDiv[i].className.indexOf("GROUP_LABEL") != -1) {
					var thisEl = allDiv[i]
					if (thisEl.classList.contains('collapser')) {
						thisEl.classList.remove('collapser')
						thisEl.classList.add('expander')
					}
				}
        		if(allDiv[i].className.indexOf("GROUP_INNER") != -1){
        			allDiv[i].style.display = "none";
        			removeFromCookieArray(i);
        			var iconDiv = allDiv[i].parentNode.children[0];
					if(iconDiv.className.indexOf("GROUP_LABEL") == 0){
						iconDiv.innerHTML = iconDiv.innerHTML.replace("[-]", "[+]");
					}
        		}
        	}

			var allDataDriveRows = document.querySelectorAll('.scenario-report tr.data');
			if (allDataDriveRows) {
				[...allDataDriveRows].forEach(row => {
					row.classList.remove('collapser');
					row.classList.add('expander');
				})
			}

			var allExpandableRows = document.querySelectorAll('.scenario-report tr.show-arrow');
			if (allExpandableRows) {
				[...allExpandableRows].forEach(row => {
					row.classList.remove('collapser')
					row.classList.add('expander')
				})
			}
			if (document.querySelector('.scenario-report')) {
				var tcRows = document.querySelectorAll('tr.testcase-row');
				if (tcRows && tcRows.length>0) {
					tcRows.forEach(row => {
						const firstCell = row.querySelector("td:first-child");
						firstCell.classList.add("collapser");
						firstCell.classList.remove("expander");
						
						[...row.querySelectorAll('table.testcase > tbody > tr:not(:first-child)')]
							.forEach(r => {
								r.style.display = 'none'
							})
					})
				}
			}

			var dataHeaders = document.querySelectorAll('div.data-header.collapser');
			if (dataHeaders && dataHeaders.length>0) {
				dataHeaders.forEach(dataHeader => dataHeader.click())
			}
        }
        
        function changeIconToMinus(groupDiv){
        	if(groupDiv.className.indexOf("GROUP_LABEL") == 0 || groupDiv.className.indexOf("OBJECT_LABEL") == 0){
        		groupDiv.classList.remove('expander');
				groupDiv.classList.add('collapser');
        	}
        	else{
        		var div = getGroupLabelDiv(groupDiv);
        		if(div){
        			div.classList.remove('expander');
					div.classList.add('collapser');
        		}
        	}
        }
        function changeIconToPlus(groupDiv){
        	if(groupDiv.className.indexOf("GROUP_LABEL") == 0 || groupDiv.className.indexOf("OBJECT_LABEL") == 0){
        		groupDiv.classList.remove('collapser');
				groupDiv.classList.add('expander');
        	}
        	else{
        		var div = getGroupLabelDiv(groupDiv);
        		if(div){
        			div.classList.remove('collapser');
					div.classList.add('expander');
        		}
        	}
        }
        
        function getGroupLabelDiv(groupDiv){
        	var div = groupDiv.getElementsByTagName("DIV");
        	for(var i=0;i<div.length;i++){
        		if(div[i].className.indexOf("GROUP_LABEL") == 0){
        			return div[i];
        		}
        	}
        }
        
        function formatTimeTakenColumn() {
			const timeRegex = /\d+:\d+:\d+ \d+/
			const timeSplitRegex = /:|\s/
			document.querySelectorAll('.time-taken').forEach(el => {
			  const elText = el.dataset.text;
			  if (elText.match(timeRegex)) {
				 const arr = elText.split(timeSplitRegex)
				 let formattedTime = [];
				 
				 if (!arr[0].match(/^0+$/)) 
				 	formattedTime.push(arr[0].padStart(2,0));
				 formattedTime.push(arr[1].padStart(2,0));
				 formattedTime.push(arr[2].padStart(2,0));
				 let ms = arr[3].padStart(3,0);
				 
				 if (!formattedTime) formattedTime = '00:00.000';
				 else formattedTime = formattedTime.join(':');
				 formattedTime += "."+ms;
				 el.innerHTML = formattedTime;
			 }
		  })
		}
        
        function splitStartAndEndTimeColumns() {
			var dateTimes = document.querySelectorAll('.date-time'); 
			var dateTimeRegex = /[a-zA-Z]{3} \d+, \d{4} \d+:\d+:\d+ [a-zA-Z]{2}/;
			var dateTimeHTML = el => {
				var datetime = el.dataset.text;
				if (!datetime || !datetime.match(dateTimeRegex)) {
					el.innerHTML = datetime;
					return;
				}
				var parts = splitDateTime(datetime);
				if (parts)
					el.innerHTML = "<span class='flex-column'>" + parts.map(x => "<span>" + x + "</span>").join("") + "</span>";
			}
			dateTimes.forEach(dateTimeHTML);
		}
        
        function splitDateTime(datetime) {
            var ix = datetime.search(/\d+:\d+:\d+/);
            if (ix < 0) return null;
            var date = datetime.substr(0, ix-1), time = datetime.substr(ix);
            return [date, time.toUpperCase()];
		}
		
		function getBrowserType() {
		   document.querySelectorAll('.browser-type').forEach( ele => {
		        let browserName = ele.dataset.text;
		        let start = browserName.indexOf('=')+1;
		        let end = browserName.indexOf(" ");
		        ele.innerText = browserName.substring(start,end).toLowerCase();
		   });
		}
        
        function createObjectDiv() {
           let ele = document.getElementsByClassName("GROUP_LABEL");
           for(let i=0;i<ele.length;i++) {
              let el = document.getElementsByClassName("GROUP_LABEL")[i];
              let message = document.getElementsByClassName("GROUP_LABEL")[i].innerText;
              if(message.indexOf('onScriptFailure') != -1 || message.indexOf('onScriptDefaultFailure') != -1
                  || message.indexOf('onScriptError') != -1 || message.indexOf('onScriptDefaultError') != -1)
              {
                  let index = message.indexOf('(')+1;
                  let lastIndex = message.lastIndexOf(')');
                  
                  let objMessage = message.substring(message.indexOf('o'),index);
                  let detailObjMessage = message.substring(index,lastIndex);
                  let statusMessage = message.substring(lastIndex+1);
                  
                  document.getElementsByClassName("GROUP_LABEL")[i].innerText = objMessage;
                  
                  let tag = document.createElement("div");
                  tag.className = "GROUP_ARGS_CONTAINER";
                  el.append(tag);
                 
                  let childTag = document.createElement("div");
                  childTag.className = "GROUP_ARG";
                  tag.append(childTag);
                 
                  let childTag1 = document.createElement("div");
                  childTag1.className = "GROUP_OBJECT_ARG"
                  childTag.append(childTag1);
                 
                  let childTag2 = document.createElement("div");
                  childTag2.className = "OBJECT_LABEL";
                  let text = document.createTextNode("[object]");
                  childTag2.appendChild(text);
                  childTag1.append(childTag2);
                  
                  let innerChild = document.createElement("div");
                  innerChild.className = "OBJECT_DETAIL";
                  text = document.createTextNode(detailObjMessage);
                  innerChild.appendChild(text);
                  childTag1.append(innerChild);
                  
                  el.append(')');
                  
                  let statusSpan = document.createElement("span");
                  statusSpan.className = "flex-row status-icon " + statusMessage.toUpperCase();
                  text = document.createTextNode(statusMessage);
                  statusSpan.appendChild(text);
                  el.append(statusSpan);
              }
           }
        }
        
        function sahiTrimForObjectDetail(s){
		    if (s==null) return s;
		    if ((typeof s) != "string") return s;
		    s = s.replace(/&nbsp;/g, ' ');
		    s = s.replace(/\xA0/g, ' ');
		    s = s.replace(/\n/g, "\\n").replace(/\r/g, "\\r").replace(/\t/g, "\\t");
		    return s;
		}
        
        function addStatusBadgesForScenario() {
			var rows = [...document.querySelectorAll('.steps table tr.keyword-row[class *= step_]')];
			rows.forEach(row => {
				if (!row.classList.contains('step_INFO')) {
					var statusClass = [...row.classList].filter(cl => cl.startsWith("step_"))[0];
					statusClass = statusClass.substring(5);
					var col = row.querySelector('td.status-column');
					if (col) {
						col.innerHTML = "<span class='flex-row status-icon " + statusClass + "'>" + statusClass.toLowerCase() + "</span>";
					}
				}
			})

			var aborted_statuses = ['ABORTED', 'ABORTED_TIMEOUT', 'USER_ABORTED', 'INTERNAL_ABORTED'];
			rows = [...document.querySelectorAll('.steps table tr.datadrive-info-row')].forEach(row => {
				var ddRow = row.nextElementSibling;
				if (ddRow.classList.contains("datadrive-row")) {
					var statusClassRows = ddRow.querySelectorAll('tr.data.loglineStart');
					if (!statusClassRows) return;
					var statusClass;
					statusClassRows.forEach(statusClassRow => {
						var statusClassThis = [...statusClassRow.classList].filter(a => a.startsWith("step_"))[0]
						statusClass = (!statusClassThis || (statusClassThis.substring(5)=="FAILURE" || statusClass=="FAILURE"))? "FAILURE": statusClassThis.substring(5);

						aborted_statuses.forEach(st => {
							if (statusClassRow.nextElementSibling?.querySelector('.'+st)) {
								statusClassRow.classList.add('step_ABORTED');
							} 
						});
					});
					var col = row.querySelector('td.status-column');
					if (col && statusClass && statusClass!='INFO') {
						row.classList.add('step_'+statusClass)
						col.innerHTML = "<span class='flex-row status-icon " + statusClass + "'>" + statusClass.toLowerCase() + "</span>";
					}
				}
			})

			var ddKeywordCells = document.querySelectorAll('tr.datadrive-info-row td.keywords-column[data-kw-list]');
			if (ddKeywordCells) {
				ddKeywordCells.forEach(cell => {
					let kwList = cell.dataset.kwList;
					if (!kwList) return;
					kwList = kwList.split('{KW:SEP}');
					const kwString = kwList.join(", ");
					const kwTags = kwList.map(kw => `<span>${kw}</span>`).join(", ");
					let cellHtml = "<div class='flex-column' style='gap: 0; align-items: flex-start;'><span class='dd-keywords' style='white-space: nowrap; width: max(400px, 20vw); overflow: hidden; text-overflow: ellipsis;'>" + kwTags + "</span>";
					//if (kwString.length > 60) {
						cellHtml += "<span class='show-more-keywords' onclick='showMoreKeywords(this);'>show more</span></div>";
					//} else {
					//	cellHtml += "</div>";
					//}

					cell.innerHTML = cellHtml;
				})
			}
		}
     
        function addEventListenersForScenario() {
			const evListener = (row) => {
				const className = row.childNodes[0].className;
				if (className=='' || className=='collapser') {
					row.childNodes[0].classList.remove('collapser');
					row.childNodes[0].classList.add('expander');
				} else if (className=='expander') {
					row.childNodes[0].classList.remove('expander');
					row.childNodes[0].classList.add('collapser');
				}

				// hide child rows
				[...row.querySelectorAll('table.testcase > tbody > tr:not(:first-child)')]
					.forEach(r => {
						if(r.style.display=='') r.style.display='none';
						else r.style.display = ''
					})
			};

			if (document.querySelector('tr.testcase-row')) {
				[...document.querySelectorAll('tr.testcase-row')].forEach(row => {
					row.querySelector('table.testcase > tbody > tr:first-child')
						.addEventListener('click', () => evListener(row));

					//row.childNodes[0].childNodes[0].addEventListener("click", () => evListener(row));
				})
			}

			if (document.querySelector('.scenario-report tr.data')) {
				[...document.querySelectorAll('.scenario-report tr.data')].forEach(row => {
					row.addEventListener('click', (e) => {
						let id = row.getAttribute("id");
						if (id.indexOf("_") != -1) {
							id = id.substring(id.indexOf("_")+1);
							const stepsDiv = document.getElementById(id);
							
							if (stepsDiv.style.display == "" || stepsDiv.style.display == "none") {
								row.classList.add("expander");
								row.classList.remove("collapser");
							}
							else {
								row.classList.add("collapser");
								row.classList.remove("expander");
							}
						}
					})
				});
			}

			if (document.querySelector('.scenario-report')) {
				[...document.querySelectorAll('tr.loglineStart:not(.data)')].forEach(row => {
					let id = row.getAttribute("id");
					if (id.indexOf("_") != -1) {
						id = id.substring(id.indexOf("_") + 1);
						const stepsDiv = document.getElementById(id);
						if (!stepsDiv) return;
						const group = stepsDiv.querySelector('div');
						if (!group || group.style.display=='none') return;
						row.classList.add('show-arrow');

						row.addEventListener('click', () => {
							if (stepsDiv.style.display == "" || stepsDiv.style.display == "none") {
								row.classList.add("expander");
								row.classList.remove("collapser");
							} 
							
							else {
								row.classList.add("collapser");
								row.classList.remove("expander");
							}
						});
					}
				})
			}

			var dataDriveHeaders = document.querySelectorAll('.scenario-report div.data-header');
			if (dataDriveHeaders) {
				dataDriveHeaders.forEach(ddHeader => {
					var dataTable = ddHeader.nextElementSibling;
					var numChildren = dataTable.querySelectorAll('tbody > tr.data');

					ddHeader.classList.add('flex-row');
					ddHeader.innerHTML += "<span class='dd-row-count'>[" + numChildren.length + (numChildren.length==1 ? " row" : " rows") +  "  executed]</span>";
					ddHeader.classList.add('collapser');

					ddHeader.addEventListener("click", () => {
						if (ddHeader.classList.contains('collapser')) {
							ddHeader.classList.remove('collapser');
							ddHeader.classList.add('expander');
							ddHeader.style.marginBottom = '10px';

							dataTable.style.display = 'none';
						} 
						else if (ddHeader.classList.contains('expander')) {
							ddHeader.classList.remove('expander');
							ddHeader.classList.add('collapser');
							ddHeader.style.marginBottom = '';

							dataTable.style.display = '';
						}
					})

					var prevRow = ddHeader.closest('.datadrive-row').previousElementSibling;
					if (prevRow.classList.contains('step_SUCCESS')) {
						ddHeader.click();
					}
				})
			}
		}
		function groupSimilarImages(steps){
			var map = {};
			var temp = new Object();
			for (var i=1; i<steps.length; i++) {
				var step = steps[i];
				var msg = step[0];
				var scr = step[2];
				
				if(msg == "STEPMESSAGE") {
					temp = {}; //empty the temp object
				}
				
				if(temp[msg]) {
					var index = parseInt(temp[msg]);
					temp[msg] = index + 1;
					msg = msg + "_" + index;
				} else {
					temp[msg] = 1;
				}
				
				if (!map[msg]) {
					map[msg] = [];
				}
				map[msg].push(scr);
			}
			var newMap = {};
			for (var k in map) {
				newMap[map[k][0]] = map[k];
			}
			return newMap;
		}
		function trim(s) {
			return s.replace(/^\s*/, '').replace(/\s*$/, '')
		} 
		
		function showStackTraceMessages() { 
			var els = document.getElementsByClassName("FAILURE_ST");
			for (var i=0; i<els.length; i++) {
				if (els[i].tagName == "DIV") {
					try {
						els[i].innerHTML = showStackTraceMessage(els[i]);
					} catch (e){}
				}
			}
		}

		function getStatusIconFromClassList(el) {
			const classList = el.classList;
			var status = null, text="";
			if (classList.contains("ERROR")) {
				status = "ERROR";
			} else if (classList.contains("FAILURE")) {
				status = "FAILURE";
			} else if (classList.contains("HEALED") || classList.contains("HEALED_WARNING")) {
				status = "HEALED";
			}

			if (status)
				return "<span class='flex-row status-icon "+status+"'>"+status.toLowerCase()+"</span>";
			return "";
		}

		function showStackTraceMessage(el) {
			var status = getStatusIconFromClassList(el.parentNode);
			var message = el.innerHTML;
			var hasStackTrace = false;
			message = message.replace("_STACKTRACE_", "\n");
			var noparse = false;
			if (message.indexOf("_NOPARSE_") != -1) {
				noparse = true;
				message = message.replace("_NOPARSE_", "");
			}
			var paths = message.split("\n");
			var length = paths.length;
			var s = "";
			var pathReplaceWith = gitLogEnabled? gitScriptPath:"";
			for (var i=0;i<length;i++) {
				var path = trim(paths[i]);
				if (path == "") continue;
				var re = /^\s*at /;
				if (path.match(re)) {
					hasStackTrace = true;
					var path = paths[i].replace(re, "").replace('/\s*$/', '').replace(/\\\\/g, "\\");
					var fnName = path.substring(path.indexOf(" "), path.length);
					path = path.substring(0, path.length - fnName.length);
					var link = "";
					if( path != ""){
						path = path.replace(/^temp\/scripts\/staging\//g, pathReplaceWith);
						var onClick = "/_s_/dyn/Log_highlight?href=" + path + (noparse ? "" : "&parsed=true") + commitIdURI + "#selected";
						link = "at: <a style='text-decoration:underline' href=" + onClick + "> (" + path.replace(/&n=/g, ' ') + ")</a> <b>" + fnName + "</b>";
					}else{
						link = "at: (<b>" + fnName + "</b>)";
					}
					s += link;
				} else {
					s += path;
				}
				if (i != length-1) {
					s += "</br>";
				}
			}
			if (hasStackTrace) {
				s = "<div style='background-color:#222;color:white;position:relative;'>" + s + "</div>" + status;
			}
			else s += status;
			return s;
		}
		fixImagePaths();
		showStackTraceMessages();
        ]]>
        </script>
        </div>
        <div class="STOP">
			<a class="STOP">Stopping script</a>
		</div>
      </div>  
	</xsl:template>
	<xsl:template match="otherSummary">
	</xsl:template>
	<xsl:template match="otherScreenShots">
	<script>
	var o = <xsl:value-of disable-output-escaping="yes" select="." />;
	showComparisonImages(o);
	</script>
	</xsl:template>
	<xsl:template match="suiteInfo">
	</xsl:template>
</xsl:stylesheet>