<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:util="in.co.sahi.util.XSLUtils"
	version="1.0">
	<xsl:output method="html" indent="yes" />
	<xsl:param name="useDBURL" select="false" />
	<xsl:param name="inlineJS" select="false" />
	<xsl:param name="mainSuiteCount" select="count(suites/suite)" />
	<xsl:variable name="lowercase" select='"abcdefghijklmnopqrstuvwxyz "' />
	<xsl:variable name="uppercase" select='"ABCDEFGHIJKLMNOPQRSTUVWXYZ_"' />

	<xsl:template match="suites">
		<html>
			<head>
				<meta http-equiv="content-type" content="text/html; charset=UTF-8" />
				<xsl:choose>
					<xsl:when test="$useDBURL = 'true'">
						<link rel="shortcut icon" href="/_s_/spr/images/favicon.ico" type="image/png"/>
						<xsl:value-of select="document('jquery.treetable.dependency')" disable-output-escaping="yes" />
						<xsl:value-of select="document('graph.offline.dependency')" disable-output-escaping="yes" />
						<script language="JavaScript" src="/_s_/spr/charts/JSClass/FusionCharts.js"></script>
						<script type="text/javascript" src="/_s_/spr/util.js"></script>
						<script type="text/javascript" src="/_s_/spr/login/logout.js"></script>
						<script type="text/javascript" src="/_s_/spr/ext/easyui/jquery.easyui.min.js"></script>
						<script type="text/javascript" src="/_s_/spr/classlist_wrapper.js"></script>
						<script type="text/javascript"> 
						   $(window).load(function () {
						      if(sahiIsIE()){
						         let bannerId = document.getElementById('banner');
						         bannerId.style.display = 'inline-flex';
						      }
						   });
						</script>
						<link rel="stylesheet" type="text/css" href="/_s_/spr/ext/easyui/themes/gray/easyui.css" />
						<xsl:value-of select="document('classlist_wrapper.js.dependency')" disable-output-escaping="yes" />
						<xsl:value-of select="document(easyui.min.js.dependency)" disable-output-escaping="yes" />
						<xsl:value-of select="document(easyui.css.dependency)" disable-output-escaping="yes" />
						<link rel="stylesheet" href="/_s_/spr/css/reports_styles.css" type="text/css" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="not($inlineJS='true')">
							<script src="common.js"></script>
						</xsl:if>
						<xsl:if test="$inlineJS = 'true'">
							<xsl:value-of select="document('jquery.treetable.dependency')" disable-output-escaping="yes" />
							<xsl:value-of select="document('graph.offline.dependency')" disable-output-escaping="yes" />
							<xsl:value-of select="document('easyui.min.js.dependency')" disable-output-escaping="yes" />
							<xsl:value-of select="document('easyui.css.dependency')" disable-output-escaping="yes" />
							<xsl:value-of select="document('classlist_wrapper.js.dependency')" disable-output-escaping="yes" />
						</xsl:if>
						<link href="common.css" rel="stylesheet" type="text/css" />
						<link href="styles.css" rel="stylesheet" type="text/css" />
					</xsl:otherwise>
				</xsl:choose>
				<style><![CDATA[
					.flex-row {
						display: flex;
						flex-direction: row;
						gap: 10px;
						align-items: center;
					}

					.flex-column {
						display: flex;
						flex-direction: column;
						gap: 10px;
						align-items: center;
					}

					.suite-details-container {
						align-items: flex-start;
						gap: 25px;
					}

					.suite-details-container .flex-column,
					.suite-detail-group.flex-row {
						align-items: flex-start;
					}

					.suite-details-container .date-time .flex-column {
						gap: 3px;
					}

					.main-title {
						align-self: flex-start;
						margin-top: 25px;
						margin-left: 20px;
						gap: max(800px, 60vw);
					}

					.suite-name-main-title {
						font-family: Arial, Helvetica, sans-serif;
						font-weight: 700;
						font-size: 20px;
						line-height: 24px;
						color: #253F89;
					}

					.suite-statistics .subtitle {
						font-weight: 700;
						font-size: 16px;
						line-height: 19px;
						color: #4e4e4e;
						margin-left: 20px;
					}
					
					.healed-value {

					}

					.suite-summary {
						min-width: 600px;
						border: 0.5px solid #66666666;
						border-radius: 10px;
						padding: 20px 50px 20px 30px;
						margin-left: 20px;

						justify-content: space-between;
						gap: 60px;
					}

					.suite-name-title, 
					.suite-detail-item-title {
						font-weight: 600;
						font-size: 14px;
						line-height: 19px;
						color: #000;
						opacity: 70%;
					}

					.suite-details-left .flex-column:first-child .suite-detail-item-title {
						flex-basis: 40%;
						align-self: center;
					}

					.suite-details .suite-name {
						font-weight: 700;
						font-size: 14px;
						line-height: 19px;
						color: #1b1b1b;
					}

					.suite-times .flex-row {
						width: 100%;
						justify-content: space-between;
					}

					.scripts-details > .flex-row {
						gap: 90px;
					}

					.scripts-details td {
						padding: 4px 5px 4px 0;
					}

					.scripts-details h2 {
						margin: 0;
						font-weight: 600;
						font-size: 16px;
						line-height: 19px;
					}

					.scripts-details .suite-detail-group {
						gap: 10px;
					}
					
					.scripts-details .suite-detail-item-title,
					.scripts-details .suite-detail-item-value {
						white-space: nowrap;
					}

					.suite-detail-group {
						width: calc(100% + 30px);
						display: inline-flex;
						flex-direction: row;
						gap: 10px;
						align-items: center;
					}

					.suite-detail-item-title {
						font-size: 14px;
					}

					.suite-detail-item-value,
					.suite-detail-item-value span:not(.status-icon) {
						font-weight: 600;
						font-size: 14px !important;
						line-height: 19px;
						color: #000;
						align-self: flex-start;
					}

					.suite-summary-stats {
						display: inline-block;
						width: 3ch;
						text-align: right;
					}

					.date-time > span > span:first-child, 
					.time-taken {
						font-size: 14px !important;
						font-weight: 500;
						align-items: flex-start;
					}

					.suite-summary .date-time > span > span:first-child, 
					.suite-summary .time-taken,
					.compare_suite_summary .date-time > span > span:first-child,
					.compare_suite_summary .time-taken,
					.compare_suite_summary .table-data td:not(:first-child) {
						font-size: 14px;
						font-weight: 600;
					}

					.compare_suite_summary .flex-column {
						align-items: flex-start;
					}

					.date-time > span > span:last-child {
						font-size: 12px !important;
						font-weight: 500;
						color: #4E4E4E;
					}

					body{display:table;min-width:100%;margin:0px; background-color:white}
					body.modal-open {
						overflow: hidden;
					}
					body > * {
						margin-left: 20px;
					}
					body *{
						font-family: Arial, Helvetica, sans-serif !important;
						font-size:10pt;
					}

					.navbar-container {
						position: sticky;
						top: 0px;
						z-index: 2;

						margin: 0;
						padding: 0;
						margin-top: 0px;

						width: 100%;
						min-width: 100vw;
						background-color: #253F89;
					}
					#navbar {
						position: sticky;
						left: 0;

						width: 100%;
						max-width: 98.5vw;
						min-width: 1200px;

						height:50px;
						justify-content: space-between;
					}

					#navbar > .left-nav {
						padding-left: 35px;
						align-self: stretch;
						gap: 10px;
						align-items: flex-end;
					}
					
					#navbar > .left-nav a:not(.selected, .nav-sahi-logo) {
						padding: 11px 24px 11px 24px;
					    margin-bottom: 3px;
					    border-radius: 5px;
				    }
					
					#navbar > .left-nav a:not(.selected, .nav-sahi-logo):hover {
						background-color: #E2EAFF;
						color: #253F89;
					}

					#navbar > .right-nav {
						margin-right: 10px;
					}

					#navbar a:not(.nav-sahi-logo){
						color: #D3D3D3;
						text-decoration: none;
						font-size: 14px;
						white-space: nowrap;
						font-weight: 700;
					}
					#navbar a.selected:not(.nav-sahi-logo) {
						color: #253F89;
						font-weight: 700;
						background-color: white;
						padding: 13px 25px 0 25px;
						border-bottom: none;
						margin-bottom: -1px;
						height: 65%;
						border-radius: 5px 5px 0px 0px;
					}

					.actionButton {
					    box-sizing: border-box;display: inline-flex;text-align: center;
					    margin-right: 15px;margin-left: 10px;height: 38px;cursor: pointer;
					    background: #FFFFFF;border: 1px solid #4E4E4E66;border-radius: 10px;
						font-weight: 500; padding: 5px 15px;
					}

					label[for='auto_refresh'] {
						cursor: pointer;
					}

					label[for='auto_refresh']:hover,
					.actionButton:hover {
						background-color: #f8f8f8;
					}
					.actionButton span {
						font-size: 14px;
						line-height: 19px;
					}
					.actionButton.brand {
						border-color: #09257266;
						color: #092572;
						font-weight: bold;
					}
					#scriptActions {
					   white-space: nowrap;
					   margin-left: 20px;
					}
					.auto-refresh * {
					    cursor: pointer;
					}
					.auto-refresh:has(input:checked) *{
						color: #092572;
						border-color: #092572;
						border-width: 2px; 
					}

					.status-icon {
						border: 1.5px solid black;
						border-radius: 15px;

						font-size: 13px;
						font-weight: 600;
						padding: 8px 12px !important;
						width: fit-content;

						margin: auto;
						text-transform: capitalize;
						white-space: nowrap;
					}

					.status-icon::before {
						content: '';
						display: inline-block;

						width: 16px;
						height: 16px;

						background-size: contain;
						background-repeat: no-repeat;

					}

					.table-header {
						width: 100%;
					}

					.table-header th {
						background-color: #E2EAFF !important;
						border: 0.5px solid #66666682;
						
						color: #000 !important;
						font-family: Arial, Helvetica, sans-serif;
						font-weight: bold !important;

						padding: 11px 15px 11px 10px !important;

						text-align: center !important; 
						white-space: nowrap !important;
					}

					.table-header:nth-child(2) th {
						color: #4e4e4e !important; 
						font-weight: 500 !important;
					}

					/* use this class on table data rows only */
					.table-data td {
						border: 0.5px solid #ccc !important;
						color: #000 !important;
						font-family: Arial, Helvetica, sans-serif;

						padding: 11px 15px 11px 10px !important;
						min-width: 100px !important;

						text-align: left !important;
					}

					.icon-group {
						padding: 10px;
						border: 1px solid #4e4e4e;
						border-radius: 15px;
						color: #4e4e4e;
					}
					
					.icon-group::before {
						content: '';
						display: inline-block;

						width: 16px;
						height: 16px;
						
						background-image: url('/_s_/spr/images/fi-sr-refresh.svg');
						background-size: contain;
						background-repeat: no-repeat;
					}

					.icon-group input[type="checkbox"] {
						display: none;
					}
					a{text-decoration:none;color:white;}
					a.INFO{color:black}
					a.START,a.STOP{color:black;font-weight:bold;}
					div.INFO{background-color:white}
					/* div.SUCCESS{background-color:green;color:white}
 					div.FAILURE,div.ERROR{background-color:red;color:white} */
					a.CUSTOM,a.CUSTOM2, a.CUSTOM4{color:black}
					div.CUSTOM{background-color:yellow;}
					div.CUSTOM1{background-color:orange;}
					div.CUSTOM2{background-color:#EFEFEF;}
					div.CUSTOM3{background-color:green;}
					div.CUSTOM4{background-color:violet;}
					div.CUSTOM5{background-color:indigo;}
					a.SCRIPT{color: black;}
					span.extra{color:#CCC;}
 					/*  div.SKIPPED{background-color:#eed;}
 					a.SKIPPED{color:gray;} */

					table.scriptSummaries{background-color:white;width:100%;border-top:1px solid gray;border-right:1px solid gray;border-spacing:0px; /*border-collapse:collapse;*/ }
					table.scriptSummaries td{
						border-bottom:1px solid #66666640;
						/*border-left:1px solid #66666640;*/
						padding:5px 10px !important; 
						/*padding-top: 10px !important; */
						vertical-align:top;
					}

					table.scriptSummaries td:nth-child(n+2) {
						padding-top: 10px !important;
					}

					tr[data-tt-parent-id="null"] td:first-child {
						white-space: nowrap;
					}

					/*table.scriptSummaries td.failures-count,
					table.scriptSummaries td.tc-failures-count,
					table.scriptSummaries td.intemediateStatusCell {
						border-left:1px solid #66666640;
					}*/

					td.total-count, td.tc-total-count,
					td.errors-count, td.tc-passed-count,
					td.success-pct, td.tc-success-pct {
						border-left: none !important;
					}

					td.intemediateStatusCell {
						font-weight: bold;
					}

					table.scriptSummaries tr[rowtype='script'] td {text-align: center;}
					table.scriptSummaries tr[rowtype='script'] td.right-align {text-align: right; padding-right: 20px;}
					table.scriptSummaries tr[rowtype='script'] td.script-name-cell { text-align: left; }
					
					tale.scriptSummaries {}
					
					table#scriptSummaries thead {
						position: sticky;
						top: 104px;
						z-index: 2;
					}
					div.scriptargs {color:gray;font-size:9pt;padding:5px 0px 3px 0px;text-align:left;}
                    .FAILURE.Status{ 
 					   color: red; background: #FFE9E9;width: 110px; 
 					   border: 1.5px solid #C00100; border-radius: 12px; 
                       font-size: 15px;display: flex;margin:auto; 
                       text-align: center; 
					} 
 					.SUCCESS.Status{ 
 					   color:green;background: #EBFFDB;width: 109px; 
					   border: 1.5px solid #3B8004;border-radius: 12px; 
 					   font-size: 15px;display: flex;margin:auto; 
                       text-align: center; 
					}
 					.USER_ABORTED.Status,.ABORTED.Status,.INTERNAL_ABORTED.Status,
 					.ABORTED_TIMEOUT.Status,.INTERNAL_ABORTED_RETRY.Status,
 					.FAILURE_RETRY.Status,.ABORTED_RETRY.Status
 					{
 					    color: #A52A2A;background: #FEEFEF;width: 152px;
 					    border: 1.5px solid #A52A2A;border-radius: 12px;
 					    font-size: 15px;display: flex;margin:auto;
                        text-align: center;
 					 }
 					 .ABORTED.Status {width: 100px;}
 					 .INTERNAL_ABORTED_RETRY.Status {width:170px}
  					 .RUNNING.Status{
   					    color:orange;background: #FFF5E3;
   					    border: 1.5px solid #EFA41C;border-radius: 15px;
   					    font-size: 15px;display: flex;margin:auto; 
                        text-align: center;width: 110px; 
   					}
   					.ERROR.Status {
   					    color: #E62E2D;background: #FFE9E9;
   					    border: 1.5px solid #C00100;border-radius: 12px;
   					    display: flex;margin:auto; 
                        text-align: center;width: 75px; 
   					}
   					.SKIPPED.Status {
   					    background: #D8D8D8;
   					    border: 1.5px solid #9E9E9E;border-radius: 13px;
   					    display: flex;margin:auto; 
                        text-align: center;width: 78px; 
   					} 
					table.suite_summary {
					    position: relative;top: 19px;
					    border:1px solid #666666;border-radius: 10px;
					    background-color:#fff;width:600px;height: 333px;
					} 
					table.compare_suite_summary {
					    border:1px solid #666666;
					    background-color:#fff;width:fit-content;
					    border-collapse: collapse;
						height: 200px;
					}
					table.compare_suite_summary td {
					    padding: 8px 10px !important;
					    border-top: 1px solid black;
					    border-bottom: 1px solid black;
					    border-right: 1px solid #ddd;
					    border-left:1px solid #ddd;
					}
					table.suite_summary td {vertical-align:top;padding:3px;text-align:left;}
					table.suite_summary_part {border:0px;}
					table.suite_summary_part *{border:0px;spacing:0px;}
					
					.combobox-item, .combobox-group{font-size:10pt !important;}
					.combo-arrow {
					   background:url(" data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAALklEQVR42mNgGAXUBcbGxv9BmFx5uAJsivDJEVRItGZsGkjWjMsQmgTqKKASAADJyyyhLrHD5wAAAABJRU5ErkJggg==") no-repeat center center !important; 
					   background-color: #f3f3f3 !important;
					   opacity:1 !important;
					}
					
					.axis path,
					.axis line {
					  fill: none;
					  stroke: #4e4e4e;
					}

					.x.axis path { display: block;}

					.line {
					  fill: none;
					  stroke: steelblue;
					  stroke-width: 2px;
					}
					
					div.d3-tooltip {	
						position: absolute;			
						text-align: center;			
						min-width: 100px;					
						min-height: 20px;					
						padding: 2px;				
						font: 16px sans-serif;		
						background: black;
						color: white;
						border-radius: 4px;		
						pointer-events: none;
					}
					#scriptSummariesHeader span, #scriptSummariesHeader a{
						height: 15px !important;
						padding: 0.5px !important;
					}
					.logo-header {
						position: fixed;
						left: 0;
						right: 0;
						height: 50px;
						z-index: 2;
						background-color: #253F89;
						margin: 0;
					}
					#sahi-logo {
						display: inline-block;
						width: 110px;
						height: 50px;
						margin: 0;
						padding: 0;
					}
					
					#comparsionSuite {
					    display: none;
					    font-weight: bold;
						background-color: white;
						padding: 13px 25px 0 25px;
						border-bottom: none;
						margin-bottom: -1px;
						height: 65%;
						align-self: flex-end;
						border-radius: 5px 5px 0px 0px;
    					color: #253F89;
					}
					table.nodesInfo {
					   width: 550px;text-align: center;
					   border: 1px solid gray;border-collapse: collapse;
					}
					table.nodesInfo td {
					   border-left: 1px solid #66666640;
					   border-bottom: 1px solid gray;
					}
					.radioSpan {
					   box-sizing: border-box;
					   display: flex;
					   gap: 10px;
					   align-items: center;
					   text-align: center;
					   margin-right: 5px;
					   height: 38px;
					   border: 1px solid #bebebe;
					   border-radius: 15px; 
					   padding: 5px 10px;
					}
					.radioSpan.radio-checked {
						border: 1px solid #3C2AA8;
						padding: 5px 10px;
					}

					.radioSpan span {
						font-weight: 500;
					}
					
					.radioSpan.radio-checked span{
						color: #3C2AA8;
					}

					.radioSpan input[type='radio'] {
						appearance: none;
						
						display: inline-block;
						width: 14px;
						height: 14px;
						background-color: white;
						border: 1px solid #a1a1a1;
						padding: 1px;
						border-radius: 50%;
						margin: 0;
					}

					.radioSpan input[type='radio']::before {
						content: '';
						display: inline-block;
						position: relative;
						width: 8px;
						height: 8px;
						border-radius: 50%;
						background-color: white;
					}

					.radioSpan input[type='radio']:checked::before {
						background-color: #3C2AA8;
					}

					.radioSpan input[type='radio']:checked {
						border-width: 2px;
						border-color: #3C2AA8; 
					}

					.suite-info {
						margin-top: 20px;
						margin-bottom: 10px;
					}

					.suite-info, 
					.nodes-info {
						margin-left: 35px;
					}

					span#suiteInfoLink, span#nodesInfoLink {
						gap: 0;
						display: inline-flex;
					}
					span#suiteInfoLink a,
					span#nodesInfoLink a {
						color: #000;
						text-decoration: none;
						cursor: pointer;

						font-size: 15px !important;
						line-height: 19px;
						font-weight: bold; 
						gap: 0;
					}
					#suiteInfo {
					   padding: 10px;
					   border: 1px solid black;
					   border-radius: 10px;
					   background-color: white;
					   width: fit-content;
					}
					#chContainer {
					   height: 420px;background-color: white;width: 95%;
					   border: 1px solid #ccc;padding: 5px;margin-left: 20px;
					   margin-top:25px;
					   border-radius: 10px;
					}
					.suite-statistics {
						align-items: flex-start;
						width: max(95%, 1200px);
					}
					.wrapper {
					   height: 400px;
					   background-color: white; width: 100%;
					   padding: 5px;
					}
					#chartContainer{
					   background-color: white;
					   width: 100%;
					   height: 100%;
					   overflow:auto;
				    }
					#chartContainer svg {
						height: 100%;
						width: 100%;
						display: inline-block;
					}

				    .downloadFileType {
				        display: none;width: 200px;
				        background-color: white;
						padding: 10px 5px;
				        border: 1px solid #999999;border-radius: 15px;
				        position: fixed;left: 45%;top: 50%;
				        transform: translate(-50%, -50%);z-index: 9;
				    }

					.downloadFileType .popup-header span {
						font-family: Arial, Helvetica, sans-serif;
						font-size: 16px;
						line-height: 19px;
						font-weight: bold;
						color: #000;
					}
				    .popUpContainer {
				        margin-top: 20px;margin-left:20px;margin-right: 20px;
				    }
					.popUpContainer .flex-row {
						width: 100%;
						justify-content: space-between;
					}
				    .popUpButton {
				        /*width:106px;
						height: 30px;*/
						margin-top: 10px;
						padding: 10px 20px;
				        background: #092572;
						color:white;
				        border: none;
						border-radius: 10px;
						cursor: pointer;    
				    }
				    .closePopupContainer {
				        font-weight: 700;float: right;
				        height: 25px;width: 30px;
				        cursor: pointer;
				        background: url('/_s_/spr/images/fi-rr-cross.svg')no-repeat ;
				    }
				    .combo input[type="text"] {
				        padding: 0;
				        width: 100% !important;height: 100% !important;
				        padding-left: 5px;padding-top: 2px !important;
				        padding-bottom: 2px !important;
                    }
                    .textbox.combo {
                        padding-left: 0;padding-top: 0;
                        border-radius: 8px;
						height: 22px !important;
						width: 150px !important;
                    }
                    .combo .textbox-addon a {
                        background-image: url("data:image/svg+xml,%3Csvg width='20' height='20' viewBox='0 0 20 20' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath d='M15.5916 6.84167C15.5141 6.76356 15.4219 6.70156 15.3204 6.65926C15.2188 6.61695 15.1099 6.59517 14.9999 6.59517C14.8899 6.59517 14.781 6.61695 14.6794 6.65926C14.5779 6.70156 14.4857 6.76356 14.4082 6.84167L10.5916 10.6583C10.5141 10.7364 10.4219 10.7984 10.3204 10.8407C10.2188 10.883 10.1099 10.9048 9.99989 10.9048C9.88988 10.9048 9.78096 10.883 9.67941 10.8407C9.57786 10.7984 9.48569 10.7364 9.40822 10.6583L5.59155 6.84167C5.51409 6.76356 5.42192 6.70156 5.32037 6.65926C5.21882 6.61695 5.1099 6.59517 4.99989 6.59517C4.88988 6.59517 4.78096 6.61695 4.67941 6.65926C4.57786 6.70156 4.48569 6.76356 4.40822 6.84167C4.25301 6.9978 4.16589 7.20901 4.16589 7.42917C4.16589 7.64932 4.25301 7.86053 4.40822 8.01666L8.23322 11.8417C8.70197 12.3098 9.33739 12.5728 9.99989 12.5728C10.6624 12.5728 11.2978 12.3098 11.7666 11.8417L15.5916 8.01666C15.7468 7.86053 15.8339 7.64932 15.8339 7.42917C15.8339 7.20901 15.7468 6.9978 15.5916 6.84167V6.84167Z' fill='%23374957'/%3E%3C/svg%3E");
                        background-size: contain;background-repeat: no-repeat;
                        width: 18px !important;height: 20px !important;
                    }
                    .combo .textbox-addon {
                       display: flex;flex-direction: column;
                       justify-content: center;
                    }
					#table-buttons {
						padding-top: 5px;
						padding-bottom: 10px;
						position: sticky;
						top: 51px;
						background-color: white;
						z-index: 2;
						min-height: 50px;
						margin-left: 0;
						padding-left: 40px;
					}
					table.treetable {
						border-collapse: unset !important;
						margin-top: 0 !important;
						border: none !important;
					}
				    table.treetable tr.branch {
				        background-color: white !important;
				    }

					table.treetable td > span:not(.status-icon, .indenter) {
						padding: 0 !important;
					}

					table.treetable .date-time span {
						padding: 0 20px;
					}

					table#scriptSummaries input[type="checkbox"] {
						width: 16px;
						height: 16px;
					}

					table#scriptSummaries td,
					table#scriptSummaries td span:not(.status-icon) {
						font-size: 14px;
					}

					table#scriptSummaries th {
						border: 0;
						border-left: 0.5px solid #66666682 !important;
					}

					table#scriptSummaries th:first-child,
					table#scriptSummaries td:first-child {
						border-left: 0 !important;
						padding-left: 40px !important;
					}

					table#scriptSummaries th:last-child,
					table#scriptSummaries td:last-child {
						border-right: 0 !important;
						padding-right: 75px !important;
					}

					table#scriptSummaries tbody > tr:hover {
						background-color: #F8F8F8 !important;
					}

					table#scriptSummaries td:first-child {
						padding-right: 20px !important;
						vertical-align: middle;
					}

					table#scriptSummaries td a {
						padding: 1px 0;
					}

					table#scriptSummaries td:first-child a {
						font-size: 14px;
						max-width: 40ch;
						overflow: hidden;
						text-overflow: ellipsis;
					}

					table#scriptSummaries thead tr:last-child th {
						border-bottom: 1px solid #66666682 !important;
					}

					table#scriptSummaries thead tr:first-child th {
						border-top: 0.5px solid #66666682 !important;
					}

					table.treetable tr span.indenter {
						margin-right: 10px;
					}

					table.treetable tr span.indenter a {
						background-image: url("data:image/svg+xml,%3Csvg width='20' height='20' viewBox='0 0 20 20' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath d='M15.5916 6.84167C15.5141 6.76356 15.4219 6.70156 15.3204 6.65926C15.2188 6.61695 15.1099 6.59517 14.9999 6.59517C14.8899 6.59517 14.781 6.61695 14.6794 6.65926C14.5779 6.70156 14.4857 6.76356 14.4082 6.84167L10.5916 10.6583C10.5141 10.7364 10.4219 10.7984 10.3204 10.8407C10.2188 10.883 10.1099 10.9048 9.99989 10.9048C9.88988 10.9048 9.78096 10.883 9.67941 10.8407C9.57786 10.7984 9.48569 10.7364 9.40822 10.6583L5.59155 6.84167C5.51409 6.76356 5.42192 6.70156 5.32037 6.65926C5.21882 6.61695 5.1099 6.59517 4.99989 6.59517C4.88988 6.59517 4.78096 6.61695 4.67941 6.65926C4.57786 6.70156 4.48569 6.76356 4.40822 6.84167C4.25301 6.9978 4.16589 7.20901 4.16589 7.42917C4.16589 7.64932 4.25301 7.86053 4.40822 8.01666L8.23322 11.8417C8.70197 12.3098 9.33739 12.5728 9.99989 12.5728C10.6624 12.5728 11.2978 12.3098 11.7666 11.8417L15.5916 8.01666C15.7468 7.86053 15.8339 7.64932 15.8339 7.42917C15.8339 7.20901 15.7468 6.9978 15.5916 6.84167V6.84167Z' fill='%23374957'/%3E%3C/svg%3E") !important;
						background-size: contain;
						background-repeat: no-repeat;
						width: 18px;
						height: 18px;
						transform: rotate(-90deg);
						z-index: 1;

						position: relative;
						top: calc(50% - 9px);
					}

					table.treetable tr.expanded span.indenter a {
						transform: rotate(0);
					}

					.collapser img {
						transform: rotate(0deg);
					}

					.expander img {
						transform: rotate(-90deg);
					}

					input[type='checkbox'] {
						appearance: none;

						height: 20px !important;
						width: 20px !important;
						border: 1px solid #092572;
						border-radius: 5px;
						
						background-color: #fff;
						display: grid;
						place-content: center;
					}

					input[type='checkbox']::before {
						content: '';
						display: inline-block;
						width: 18px;
						height: 18px;
						box-shadow: inset 16px 16px #fff;
						clip-path: polygon(13% 45%, 37% 65%, 83% 1%, 99% 14%, 39% 98%, 0 64%);
					}

					input.indeterminate-checkbox::before {
						clip-path: polygon(15% 40%, 15% 60%, 85% 60%, 85% 40%);
					}

					input[type='checkbox']:checked::before {
						clip-path: polygon(13% 45%, 37% 65%, 83% 1%, 99% 14%, 39% 98%, 0 64%);
					}

					input[type='checkbox']:checked,
					input.indeterminate-checkbox {
						background-color: #253f89;
					}

					.auto-refresh {
						font-family: Arial, Helvetica, sans-serif;
						padding: 8px 10px;
						border: 1px solid #ccc;
						border-radius: 10px;
					}

					.auto-refresh span {
						font-size: 14px;
						color: #4E4E4E;
						font-weight: 500;
						white-space: nowrap;
					}

					.auto-refresh::after {
						content: '';
						display: inline-block;

						width: 16px;
						height: 16px;
						
						background-image: url('/_s_/spr/images/fi-rr-refresh.svg');
						background-size: contain;
						background-repeat: no-repeat;
					}

					.auto-refresh.checked {
						border-color: #253F89;
						border-width: 2px;
						padding: 7px 9px;
					}

					.auto-refresh.checked::after {
						background-image: url('/_s_/spr/images/fi-rr-refresh-active.svg');
					}

					.auto-refresh.checked span {
						color: #253F89;
					}

					.auto-refresh input[type="checkbox"] {
						appearance: none;

						background-color: #fff;
						margin: 0;

						font: inherit;
						color: white;
						width: 18px;
						height: 18px;
						border: 2px solid #46474aa3;
						border-radius: 3px;

						display: grid;
						place-content: center;
					}

					.auto-refresh input[type="checkbox"]::before {
						content: '';
						display: inline-block;
						width: 18px;
						height: 18px;
						box-shadow: inset 14px 14px #fff;

						transform: scale(0);
						transition: transform 120ms ease-in-out;
						transform-origin: bottom left;
						clip-path: polygon(13% 45%, 37% 65%, 83% 1%, 99% 14%, 39% 98%, 0 64%);
					}

					.auto-refresh input[type="checkbox"]:checked {
						background-color: #092572;
					}

					.auto-refresh input[type="checkbox"]:checked::before {
						/* background-color: #092572; */
						transform: scale(1);
					}

					a:not(.no-link):hover {
						text-decoration: underline !important;
					}

					#navbar a:hover {
						text-decoration: none !important;
					}
					
					.container{
						--darker: #f8f8f8;

						box-sizing: border-box;
						display: flex;
						flex-direction: row;
						align-items: center;
						gap: 8px;
						cursor: pointer;
						padding: 8px 16px;
						background: #FFFFFF;
						border: 1px solid #4E4E4E;
						border-radius: 15px;
					}
					.logo-header .container {
					    background: transparent;
					    border-color: #FFF;
					}
					.container img {
					    height: 16px;
					    width: 16px;
					}
					.logo-header .container span {
					    color: #FFF;
					}

					.mask {
						position: fixed;
						left: 0;
						top: 0;
						right: 0;
						bottom: 0;
						background-color: rgba(255, 255, 255, 0.4);
						z-index: 8;
						margin: 0;
					}
					#banner {
					   position: fixed;
					   display:none;
					   top: 0; left: 25%;
					   border-left: 8px solid #E62E2D;
					   border-radius: 10px;
					   background-color: #FFE6E5;
					   z-index: 100;width: 630px;
					   box-shadow: 0px 4px 14px 0px #5f5f5f;
					}
					#banner img {margin-top: 15px; margin-left: 10px; height: 40px}
					.warn { margin: 12px; line-height: 24px }
					.warn span, .warn strong {font-size: 16px}
					#warn {color: red}
				]]></style>	
				<title><xsl:value-of select="suite/suiteSummary/SUITENAME"/></title>
			</head>

			<body onunload="onUnload()" onload="onLoad()" onclick="hideBigImg()" onresize="onResize()">
				<script><![CDATA[
					function fixPaddingsForOfflineReport() {
						var parentMap = {}, levelMap = {}
						var rows = [...document.querySelectorAll('table#scriptSummaries > tbody > tr')];				
						if (rows && rows.length) {
							rows.forEach((row, idx) => {
								var thisId = row.getAttribute("data-tt-id");
								var parentId = row.getAttribute("data-tt-parent-id");
								parentMap[thisId] = parentId;
							})
							
							Object.keys(parentMap).forEach(rowId => {
								var level = 0;
								var parent = parentMap[rowId]
								while(parent != 'null') {
									level++;
									parent = parentMap[parent];
								}
								levelMap[rowId] = level;
							})
						}

						var pLeft = 29;
						Object.keys(levelMap).forEach(rowId => {
							var row = document.querySelector("tr[data-tt-id='" + rowId + "']");
							if (row) {
								if(row.getAttribute('rowtype') == 'script') {
									var padding = `${(levelMap[rowId] * pLeft)}px`;
									var nameSpan = row.querySelector('td.script-name-cell > span.flex-column');
									if (nameSpan) {
										nameSpan.style.setProperty('padding-left', padding, 'important');
									}
								}
							}
						})
					}

					// functions for formatting the date and time columns
					function splitDateTime(datetime) {
						var ix = datetime.search(/\d+:\d+:\d+/);
						if (ix < 0) return null;
						var date = datetime.substr(0, ix-1), time = datetime.substr(ix);
						return [date, time.toUpperCase()];
					}

					function splitStartAndEndTimeColumns() {
						var dateTimes = document.querySelectorAll('.date-time');
						var dateTimeRegex = /[a-zA-Z]{3} \d+, \d{4} \d+:\d+:\d+ [a-zA-Z]{2}/;

						var dateTimeHTML = el => {
							var datetime = el.dataset.text;
							if (!datetime || !datetime.match(dateTimeRegex)) {
								if (datetime === undefined || datetime === null)
									el.innerHTML = '';
								else
									el.innerHTML = datetime;
								return;
							}

							var parts = splitDateTime(datetime);
							if (parts)
								el.innerHTML = "<span class='flex-column' style='padding: 0;'>" + parts.map(x => "<span>" + x + "</span>").join("") + "</span>";
						}

						dateTimes.forEach(dateTimeHTML);
					}

					function toggleExpander(el) {
						if (el.classList.contains('expander')) {
							el.classList.remove('expander')
							el.classList.add('collapser')
						} else if (el.classList.contains('collapser')) {
							el.classList.remove('collapser')
							el.classList.add('expander')
						}
					}

					function formatTimeTakenColumn() {
						const timeRegex = /\d+:\d+:\d+ \d+/
						const timeSplitRegex = /:|\s/
						document.querySelectorAll('.time-taken').forEach(el => {
							const elText = el.dataset.text;
							if (!elText) return;
							if (elText.match(timeRegex)) {
								const arr = elText.split(timeSplitRegex)
								let formattedTime = [];
								
								if (!arr[0].match(/^0+$/)) 
									formattedTime.push(arr[0].padStart(2,0));
								formattedTime.push(arr[1].padStart(2,0));
								formattedTime.push(arr[2].padStart(2,0));
								let ms = arr[3].padStart(3,0);
								
								if (!formattedTime) formattedTime = '00:00.000';
								else formattedTime = formattedTime.join(':');
								formattedTime += "."+ms;
								el.innerHTML = formattedTime;
							}
						})
					}	

					function addRadioChecked(el) {
						var els = [...document.querySelectorAll('.radioSpan')];
						els.forEach(el => {
							const radio = el.querySelector('input[type="radio"]');
							if (radio && radio.checked == true) {
								el.classList.add('radio-checked');
							} else {
								el.classList.remove('radio-checked');
							}
						})
					}
				]]></script>
				<div id="largeImageContainer" style="display:none; border: 1px solid #ddd;" onclick="event.stopPropagation()"></div>
				<xsl:param name="suiteId" select="suite/suiteSummary/SUITEREPORTID" />
				<xsl:param name="suiteName" select="suite/suiteSummary/SUITENAME" />
				<xsl:param name="suitePath" select="suite/suiteSummary/SUITEPATH" />
				<xsl:param name="startTime" select="suite/suiteSummary/STARTTIME" />
				<xsl:param name="endTime" select="suite/suiteSummary/ENDTIME" />
				<xsl:param name="className" select="suite/suiteSummary/SUITESTATUS" />
				<xsl:param name="totalCount" select="suite/suiteSummary/TOTALCOUNT" />
				<xsl:param name="passedCount" select="suite/suiteSummary/PASSEDCOUNT" />
				<xsl:param name="failedCount" select="suite/suiteSummary/FAILEDCOUNT" />
				<xsl:param name="errorCount" select="suite/suiteSummary/ERRORCOUNT" />
				<xsl:param name="skippedCount" select="suite/suiteSummary/SKIPPEDCOUNT" />
				<xsl:param name="abortedCount" select="suite/suiteSummary/ABORTEDCOUNT" />
				<xsl:param name="notSupportedCount" select="suite/suiteSummary/NOTSUPPORTEDCOUNT" />
				<xsl:param name="abortedTimeoutCount" select="suite/suiteSummary/ABORTEDTIMEOUTCOUNT" />
				<xsl:param name="timeTaken" select="suite/suiteSummary/TIMETAKEN" />
				<xsl:param name="browserType" select="suite/suiteSummary/BROWSERTYPE" />
				<xsl:param name="androidDevice" select="suite/suiteSummary/ANDROIDDEVICE" />
				<xsl:param name="androidDeviceInfo" select="suite/suiteSummary/ANDROIDDEVICEINFO" />
				<xsl:param name="iOSDevice" select="suite/suiteSummary/IOSDEVICE" />
				<xsl:param name="iOSDeviceInfo" select="suite/suiteSummary/IOSDEVICEINFO" />
				<xsl:param name="suiteInfo" select="suite/suiteSummary/SUITEINFO" />
				<xsl:param name="tccount" select="suite/suiteSummary/TCCOUNT" />
				<xsl:param name="tcpassed" select="suite/suiteSummary/TCPASSED" />
				<xsl:param name="tcfailed" select="suite/suiteSummary/TCFAILED" />
				<xsl:param name="machineName" select="suite/suiteSummary/MACHINENAME" />
				<xsl:param name="healedCount" select="suite/suiteSummary/HEALEDCOUNT" />
				<xsl:param name="failedHealedCount" select="suite/suiteSummary/FAILEDHEALEDCOUNT" />
				<xsl:param name="errorHealedCount" select="suite/suiteSummary/ERRORHEALEDCOUNT" />
				<xsl:param name="abortedHealedCount" select="suite/suiteSummary/ABORTEDHEALEDCOUNT" />
				<xsl:param name="abortedTimeoutHealedCount" select="suite/suiteSummary/ABORTEDTIMEOUTHEALEDCOUNT" />
				
				<xsl:param name="retriedsuitereportid" select="util:fetchInfo($suiteInfo, 'retriedSuiteReportId')" />
				<xsl:param name="firstrunsuitereportid" select="util:fetchInfo($suiteInfo, 'firstRunSuiteReportId')" />
				<xsl:param name="internalAborted" select="suite/suiteSummary/INTERNALABORTED" />
				
				<script type="text/javascript">
					var useDBURL = '<xsl:value-of select="($useDBURL)"/>';
					var timer = 1;
					<![CDATA[
						function readCookie(name){
							var nameEQ = name + "=";
							var ca = document.cookie.split(';');
							for(var i=0;i<ca.length;i++){
								var c = ca[i];
								c = c.replace(/[,][}]$/,'}');
								while (c.charAt(0)==' ') c = c.substring(1,c.length);
								if (c.indexOf(nameEQ) == 0) return c.substring(nameEQ.length,c.length);
							}
							return null;
						}
				
						function enableDisableAutoRefresh(autoRefresh){
							var isAutoRefreshEnable = autoRefresh.checked;
							if(isAutoRefreshEnable){
								createCookie("auto_refresh","true",1);
								refreshPage();
								autoRefresh.title = "Disable Auto Refresh";
								autoRefresh.parentNode.classList.add('checked');
							} else{
								createCookie("auto_refresh","false",1);
								autoRefresh.title = "Enable Auto Refresh";
								if(timer) clearTimeout(timer);
								autoRefresh.parentNode.classList.remove('checked');
							}
						}
						
						function refreshPage(){
							if(useDBURL == "false") return;
							var el = document.getElementById("status");
							if (el && (
								el.classList.contains("SUCCESS") || 
								el.classList.contains("FAILURE") || 
								el.classList.contains("ERROR") || 
								el.classList.contains("USER_ABORTED") || 
								el.classList.contains("ABORTED_TIMEOUT")
							)) {
								return;
							}
							var isAutoRefreshCookieEnable = (readCookie("auto_refresh") == "true");
							if(isAutoRefreshCookieEnable) timer = setTimeout(function(){ window.location.reload(); }, 2000);
						}
						refreshPage();
						function getCodeCoverage(){
							window.open("DBReports_getCodeCoverage?id="+suiteReportID,'_blank');
						}
					]]>
					var suiteReportID = '<xsl:value-of select="$suiteId"/>'
					var suitestatus = '<xsl:value-of select="$className"/>';
					if(suitestatus != "RUNNING" || readCookie("auto_refresh") != "true") clearTimeout(timer);
				</script>
				<xsl:choose>
					<xsl:when test="$useDBURL = 'true'">
						  <div id="banner">
						     <div>
						       <img src="/_s_/spr/images/caution_Icon_red.svg"/>
						     </div>
						     <div class="warn">
						        <span id="warn">This Browser is not compatible. </span>
						        <span>Kindly switch to any modern browsers like <strong>Google Chrome, Mozilla Firefox, Microsoft Edge, </strong><span>etc.</span></span>
						     </div>
						  </div>
						<div class='navbar-container'>
							<div id='navbar' class="navbar flex-row logo-header">
								<div class='left-nav flex-row'>
									<a class="nav-sahi-logo" onclick="window.location.href='/_s_/dyn/pro/DBReports';" style="cursor: pointer;"><span id="sahi-logo" class="bg-sahi-logo"></span></a>
									<span class='flex-row'><a href='/_s_/dyn/pro/DBReports'>Suites</a></span>
									<div id="comparsionSuite">Comparison Suite</div>
									<span id="singleSuite_navBar" class="flex-row" style="gap: 10px; height: 50px; align-items: flex-end;">
										<div style="display:none; height: 65%;" id="parentSuite">
											<a id="parentSuiteLink" style="display: block;" href='/_s_/dyn/pro/DBReports_suiteReport'>Parent Suite Report</a> 
										</div>
										<xsl:choose>
											<xsl:when test="$firstrunsuitereportid != 'null' and $firstrunsuitereportid != ''">
												<a class="navLink selected" href='/_s_/dyn/pro/DBReports_suiteReport?id={$firstrunsuitereportid}' style="color:black;"><b>Suite Report</b></a> 
											</xsl:when>			
											<xsl:otherwise>
												<a class="navLink selected" href='/_s_/dyn/pro/DBReports_suiteReport?id={$suiteId}'>Suite Report</a> 
											</xsl:otherwise>
										</xsl:choose>
										<xsl:choose>
											<xsl:when test="starts-with($suiteId, 'LOAD_')">
												<a href='/_s_/dyn/pro/DBReports_reconciledReport?id={$suiteId}'
													>Load Test Summary</a>
											</xsl:when>
											<xsl:otherwise>
												<a id="testcasesReportLink" class="navLink" href='/_s_/dyn/pro/DBReports_testCaseReport?id={$suiteId}'
													>Test Cases Report</a>
												<xsl:if
													test="(contains(SUITENAME, '.csv')) and not(contains(SUITENAME, '.dd.csv')) and not(contains(SUITENAME, '.s.csv'))">
												
													<a id="testcasesReportSummaryLink" class="navLink" href='/_s_/dyn/pro/DBReports_csvTestCasesReport?id={$suiteId}'
														>Test Cases Report Summary</a>
												</xsl:if>
											</xsl:otherwise>
										</xsl:choose>
										<xsl:if test="$retriedsuitereportid != 'null' and $retriedsuitereportid != ''">
											<a href='/_s_/dyn/pro/DBReports_suiteReport?id={$retriedsuitereportid}' id="linkshowretrylogs">Show retry logs</a>
										</xsl:if>
										<div id="jsCodeCoverage">
											<a id="jsCodeCoverageLink" class="navLink" style="display: block;" href='/_s_/dyn/pro/JSCodeCoverage?suiteReportId={$suiteId}'>JS Code Coverage Report</a>
										</div>
								
										<a id="suiteAnalysisLink" class="navLink" href='/_s_/dyn/pro/DBReports_failureReport?id={$suiteId}'>Suite Analysis</a>
									</span>	
								</div>
								<div class='right-nav flex-row'>
									<a href="#" onclick="exportToExcel()">
										<img border="0" src="/_s_/spr/images/excel.png" title="Export to Excel" width="25" height="25" />
									</a>
									<a href='/_s_/dyn/pro/DBReports_allArtifactsAsZip?suiteReportId={$suiteId}&amp;download=true&amp;suffixEnabled={util:artifactSuffixEnabled()}' id='downloadArtifacts'>
										<img border="0" src="/_s_/spr/images/package.png" title="Download all Artifacts" width="25" height="25" />
									</a>
									<span class="container" onclick="logout()" id="logout" style="display:none;">
										<img src="/_s_/spr/images/fi-rr-log-out.svg"/>
										<a href="#" title="Log out" style="xcolor:#000;" onclick="logout()">Log out</a>
									</span>
								</div>
							</div>
						</div>
					</xsl:when>
					<xsl:otherwise>
						<div class='navbar-container'>
							<div id='navbar' class="navbar flex-row logo-header">
								<div class='left-nav flex-row' style="align-items: flex-end;">
									<span id="sahi-logo" class="bg-sahi-logo"></span>
									<a class="selected" href='index.html' style="color:black" id="linksuitereports">Suite Report</a>
									<xsl:choose>
										<xsl:when test="starts-with($suiteId, 'LOAD_')">
											<a href='dload.html'>Load Test Summary</a>
										</xsl:when>
										<xsl:otherwise>
											<a href='testcase_summary.html'>Test Cases Report</a>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:if test="(number($failedCount) != 0 or number($errorCount) != 0 or number($abortedCount) != 0 or number($notSupportedCount) != 0 or number($abortedTimeoutCount) != 0) and $retriedsuitereportid != 'null' and $retriedsuitereportid != ''">
									<a href="retry/index.html" id="linkshowretrylogs">Show retry logs</a>
									</xsl:if>
									<a href='js_code_coverage_summary.html'>JS Code Coverage Report</a>
									<a href='suite_analysis_summary.html'>Suite Analysis</a>
								</div>
							</div>
						</div>
					</xsl:otherwise>
				</xsl:choose>
				
				<div id="chContainer" style=""></div>
				<div id="statistics_view_header" style="font-weight: 600; margin-top: 20px; margin-bottom: 20px;">Select the view of statistics</div>
				<div id="radio_span" class="flex-row">
					<label for="timeTaken-selectGraph">
							<span class="radioSpan flex-row radio-checked">
								<input type="radio" id="timeTaken-selectGraph" name="selectGraph" value="timeTaken" onclick="addRadioChecked(this);changeGraph(this.value)" checked="checked" />
							<span>Time taken</span>
						</span>
					</label>
					<label for="totalSteps-selectGraph">
						<span class="radioSpan flex-row">
				       		<input type="radio" id="totalSteps-selectGraph" name="selectGraph" value="totalSteps" onclick="addRadioChecked(this);changeGraph(this.value)" />
				        	<span>Total steps</span>
						</span>
					</label>
					<label for="failuresCount-selectGraph">
						<span class="radioSpan flex-row">
				       		<input type="radio" id="failuresCount-selectGraph" name="selectGraph" value="failuresCount" onclick="addRadioChecked(this);changeGraph(this.value)"  />
				        	<span>Failures count</span>
						</span>
					</label>
					<label for="errorsCount-selectGraph">
						<span class="radioSpan flex-row">
							<input type="radio" id="errorsCount-selectGraph" name="selectGraph" value="errorsCount" onclick="addRadioChecked(this);changeGraph(this.value)" />
				        	<span>Errors count</span>
						</span>
					</label>
				</div>
				
				<xsl:choose>
					<xsl:when test="count(/suites/suite)=1">
						<xsl:param name="gitScriptPath" select="util:fetchInfo($suiteInfo, 'gitScriptPath')" />
						<xsl:param name="copiedScriptPath" select="util:fetchInfo($suiteInfo, 'copiedScriptsPath')" />
						<xsl:param name="suitePathGit" select="util:replaceSuitePathForGit($suitePath, $copiedScriptPath, $gitScriptPath)" />
						<xsl:param name="commitId" select="util:fetchInfo($suiteInfo, 'commitId')"/>
						<xsl:variable name="commitIdURI">
					        <xsl:choose>
					            <xsl:when test="$commitId !=''">
					            <xsl:value-of select="concat('&amp;commitId=',$commitId)"/>
					        </xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="''"/>
							</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
					
					<div class="flex-column suite-details-container">
						<div class="flex-row main-title">
							<div class='suite-name-main-title'>
								<xsl:value-of select="$suiteName" />
							</div>
							<xsl:if test="$useDBURL = 'true'">
								<label for="auto_refresh">
									<span class='auto-refresh flex-row'>
										<input title="Disable Auto Refresh" type="checkbox" id="auto_refresh" onchange="enableDisableAutoRefresh(this)"/>
										<span>Auto Refresh</span>
									</span>
								</label>
							</xsl:if>
						</div>

						<div class="suite-statistics flex-column" style="">
							<div class='subtitle'>Statistics</div>
							<div class="wrapper"><div id="chartContainer"></div></div>
						</div>

						<div class='suite-summary flex-row' style="align-items: flex-start;">
							<div class='suite-details flex-column'>
								<span class="flex-row">
									<span class='suite-name-title'>Suite Name:</span>
									<xsl:if test="$useDBURL = 'true'">
										<a class='suite-name' href="/_s_/dyn/Log_highlight?href={$suitePathGit}{$commitIdURI}">
											<xsl:value-of select="$suiteName" />
										</a> 
									</xsl:if>
									<xsl:if test="not($useDBURL = 'true')">
										<a class='suite-name'><xsl:value-of select="$suiteName" /></a>
									</xsl:if>
								</span>
								<div class='suite-details-left flex-row' style='gap: 100px;'>
									<div class='flex-column'>
										<div class='suite-detail-group flex-row'>
											<span  class='suite-detail-item-title'>Status:</span>
											<span class='suite-detail-item-value suite-status'>
												<span id="status" class="status-icon flex-row {$className}" style="display: inline-flex;">
													<xsl:value-of select="translate($className, $uppercase, $lowercase)" />
												</span>
											</span>
										</div>
										<div class='suite-detail-group'>
											<span class='suite-detail-item-title'>Time Taken:</span>
											<span class='suite-detail-item-value time-taken'>
												<xsl:choose>
													<xsl:when test="$timeTaken != 'null'">
														<xsl:attribute name="data-text">
															<xsl:copy-of select="util:prettyTimeMoreThan24Hours($timeTaken)" />
														</xsl:attribute>
													</xsl:when>
													<xsl:otherwise>NA</xsl:otherwise>
												</xsl:choose>
												<br />
											</span>
										</div>
										<xsl:if test="$browserType != 'null' and $browserType != '' and $browserType != 'undefined'">
											<div class='suite-detail-group'>
												<span class='suite-detail-item-title'>Browser Type:</span>
												<span class='suite-detail-item-value'>
													<xsl:value-of select="$browserType" />
												</span>
											</div>
										</xsl:if>
										<xsl:if test="$androidDevice != 'null' and $androidDevice != '' and $androidDevice != 'undefined'">
											<div class='suite-detail-group'>
												<span class='suite-detail-item-title'>Android Device:</span>
												<span class='suite-detail-item-value'>
													<div title="{$androidDevice}">
														<xsl:value-of select="$androidDevice" />
													</div>
												</span>
											</div>
										</xsl:if>
										<xsl:if test="$iOSDevice != 'null' and $iOSDevice != '' and $iOSDevice != 'undefined'">
											<div class='suite-detail-group'>
												<span class='suite-detail-item-title'>iOS Device:</span>
												<span class='suite-detail-item-value'>
													<div title="{$iOSDevice}">
														<xsl:value-of select="$iOSDevice" />
													</div>
												</span>
											</div>
										</xsl:if>
									</div>
									<div class='flex-column suite-times'>
										<div class='flex-column'>
											<div class='suite-detail-group flex-row'>
												<span class='suite-detail-item-title' style="width: 30px;flex-basis: auto;margin-right: 10px; align-self: flex-start;">Start Time:</span>
												<span class='suite-detail-item-value'>
													<div class="forStartTIme date-time">
														<xsl:attribute name="data-text">
															<xsl:copy-of select="util:humanTime($startTime)" />
														</xsl:attribute>
													</div>
												</span>
											</div>
											<div class='suite-detail-group flex-row'>
												<span class='suite-detail-item-title' style="width: 30px;flex-basis: auto;margin-right: 10px; align-self: flex-start;">End Time:</span>
												<span class='suite-detail-item-value'>
													<xsl:choose>
														<xsl:when test="$endTime != 'null'">
															<div class="forEndTIme date-time">
																<xsl:attribute name="data-text">
																	<xsl:copy-of select="util:humanTime($endTime)" />
																</xsl:attribute>
															</div>
														</xsl:when>
														<xsl:otherwise>NA</xsl:otherwise>
													</xsl:choose>
												</span>
											</div>
										</div>
									</div>
								</div>
							</div>
							<div class='scripts-details flex-column'>
								<div class='suite-details-right-title'>
									<h2>Scripts</h2>
								</div>
								<div class='flex-row'>
									<div class='suite-details flex-column'>
										<table>
											<tr>
												<td><span class='suite-detail-item-title'>Total:</span></td>
												<td><span class='suite-detail-item-value'>
													<xsl:choose>
														<xsl:when test="$totalCount != 'null'">
															<span class="suite-summary-stats"><xsl:value-of select="$totalCount" /></span>
														</xsl:when>
														<xsl:otherwise>NA</xsl:otherwise>
													</xsl:choose>
												</span></td>
											</tr>
											<tr>
												<td><span class='suite-detail-item-title'>Passed:</span></td>
												<td><span class='suite-detail-item-value'>
													<xsl:choose>
														<xsl:when test="$passedCount != 'null'">
															<span>
																<span class="suite-summary-stats"><xsl:value-of select="$passedCount" /></span>
																<span class='healed-value'>
																	<xsl:if test="number($healedCount)">
																		(<xsl:value-of select="$healedCount" /> HEALED)
																	</xsl:if>
																</span>
															</span>
														</xsl:when>
														<xsl:otherwise>
														<span class="suite-summary-stats">NA</span>
														</xsl:otherwise>
													</xsl:choose>
												</span></td>
											</tr>
											<tr>
												<td><span class='suite-detail-item-title'>Failed:</span></td>
												<td><span class='suite-detail-item-value healed-value'>
													<xsl:choose>
														<xsl:when test="$failedCount != 'null'">
															<span class='healed-value'>
																<span class="suite-summary-stats"><xsl:value-of select="$failedCount" /></span>
																<xsl:if test="number($failedHealedCount)">
																	(<xsl:value-of select="$failedHealedCount" /> HEALED)
																</xsl:if>
															</span>
														</xsl:when>
														<xsl:otherwise>
														<span class="suite-summary-stats">NA</span>
														</xsl:otherwise>
													</xsl:choose>
												</span></td>
											</tr>
											<tr>
												<td><span class='suite-detail-item-title'>Errored:</span></td>
												<td><span class='suite-detail-item-value healed-value'>
													<xsl:choose>
														<xsl:when test="$errorCount != 'null'">
														<span class="suite-summary-stats"><xsl:value-of select="$errorCount" /></span>
														<span class='healed-value'>
															<xsl:if test="number($errorHealedCount)">
																(<xsl:value-of select="$errorHealedCount" /> HEALED)
															</xsl:if>
														</span>
														</xsl:when>
														<xsl:otherwise>
														<span class="suite-summary-stats">NA</span>
														</xsl:otherwise>
													</xsl:choose>
												</span></td>
											</tr>
										</table>
									</div>
									<div class='suite-details flex-column'>
										<table>
											<tr>
												<td><span class='suite-detail-item-title healed-value'>Aborted:</span></td>
												<td><span class='suite-detail-item-value'>
													<xsl:choose>
														<xsl:when test="$abortedCount != 'null'">
															<span class="suite-summary-stats"><xsl:value-of select="$abortedCount" /></span>
															<span class='healed-value'>
																<xsl:if test="number($abortedHealedCount)">
																	(<xsl:value-of select="$abortedHealedCount" /> HEALED)
																</xsl:if>
															</span>
															</xsl:when>
														<xsl:otherwise><span class="suite-summary-stats">NA</span></xsl:otherwise>
													</xsl:choose>
												</span></td>
											</tr>
											<tr>
												<td><span class='suite-detail-item-title'>Aborted timeout:</span></td>
												<td><span class='suite-detail-item-value healed-value'>
													<xsl:choose>
														<xsl:when test="$abortedTimeoutCount != 'null'">
														<span class="suite-summary-stats"><xsl:value-of select="$abortedTimeoutCount" /></span>
														<span class='healed-value'>
															<xsl:if test="number($abortedTimeoutHealedCount)">
																(<xsl:value-of select="$abortedTimeoutHealedCount" /> HEALED)
															</xsl:if>
														</span>
														</xsl:when>
														<xsl:otherwise><span class="suite-summary-stats">NA</span></xsl:otherwise>
													</xsl:choose>
												</span></td>
											</tr>
											<xsl:if test="number($internalAborted)">
												<tr>
													<td><span class='suite-detail-item-title'>Internal aborted:</span></td>
													<td><span class='suite-detail-item-value'>
														<span class="suite-summary-stats"><xsl:value-of select="$internalAborted" /></span>
													</span></td>
												</tr>
											</xsl:if>
											<tr>
												<td><span class='suite-detail-item-title'>Skipped:</span></td>
												<td><span class='suite-detail-item-value'>
													<xsl:choose>
														<xsl:when test="$skippedCount != 'null'">
															<span class="suite-summary-stats"><xsl:value-of select="$skippedCount" /></span>
														</xsl:when>
														<xsl:otherwise><span class="suite-summary-stats">NA</span></xsl:otherwise>
													</xsl:choose>
												</span></td>
											</tr>
											<tr>
												<td><span class='suite-detail-item-title'>Not supported:</span></td>
												<td><span class='suite-detail-item-value'>
													<xsl:choose>
														<xsl:when test="$notSupportedCount != 'null'">
															<span class="suite-summary-stats"><xsl:value-of select="$notSupportedCount" /></span>
														</xsl:when>
														<xsl:otherwise><span class="suite-summary-stats">NA</span></xsl:otherwise>
													</xsl:choose>
												</span></td>
											</tr>
										</table>
									</div>
								</div>
							</div>
						</div>
					</div>

					<div class='suite-info'>
						<span id="suiteInfoLink" class="expander flex-row" href="#" onclick="showSuiteInfoData();toggleExpander(this);return false;">
							<img src="data:image/svg+xml,%3Csvg width='20' height='20' viewBox='0 0 20 20' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath d='M15.5916 6.84167C15.5141 6.76356 15.4219 6.70156 15.3204 6.65926C15.2188 6.61695 15.1099 6.59517 14.9999 6.59517C14.8899 6.59517 14.781 6.61695 14.6794 6.65926C14.5779 6.70156 14.4857 6.76356 14.4082 6.84167L10.5916 10.6583C10.5141 10.7364 10.4219 10.7984 10.3204 10.8407C10.2188 10.883 10.1099 10.9048 9.99989 10.9048C9.88988 10.9048 9.78096 10.883 9.67941 10.8407C9.57786 10.7984 9.48569 10.7364 9.40822 10.6583L5.59155 6.84167C5.51409 6.76356 5.42192 6.70156 5.32037 6.65926C5.21882 6.61695 5.1099 6.59517 4.99989 6.59517C4.88988 6.59517 4.78096 6.61695 4.67941 6.65926C4.57786 6.70156 4.48569 6.76356 4.40822 6.84167C4.25301 6.9978 4.16589 7.20901 4.16589 7.42917C4.16589 7.64932 4.25301 7.86053 4.40822 8.01666L8.23322 11.8417C8.70197 12.3098 9.33739 12.5728 9.99989 12.5728C10.6624 12.5728 11.2978 12.3098 11.7666 11.8417L15.5916 8.01666C15.7468 7.86053 15.8339 7.64932 15.8339 7.42917C15.8339 7.20901 15.7468 6.9978 15.5916 6.84167V6.84167Z' fill='%23374957'/%3E%3C/svg%3E" />
							<a style="padding-left: 7px;">Suite Info</a>
						</span>
						<div id="suiteInfo" style="display:none; margin-top: 20px; margin-left: 25px;">
							<pre style="margin: 8px"><xsl:copy-of select="$suiteInfo" /></pre>
							<a id='consoleLogs' href='/_s_/dyn/pro/DBReports_downloadConsoleLogs?suiteReportId={$suiteId}' style="color:blue; display:none">Click here to download Console logs</a>										
						</div>
					</div>
					<div class='nodes-info'>
						<span id="nodesInfoLink" class="expander flex-row" href="#" onclick="showHide('nodesInfo');toggleExpander(this);return false;">
							<img src="data:image/svg+xml,%3Csvg width='20' height='20' viewBox='0 0 20 20' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath d='M15.5916 6.84167C15.5141 6.76356 15.4219 6.70156 15.3204 6.65926C15.2188 6.61695 15.1099 6.59517 14.9999 6.59517C14.8899 6.59517 14.781 6.61695 14.6794 6.65926C14.5779 6.70156 14.4857 6.76356 14.4082 6.84167L10.5916 10.6583C10.5141 10.7364 10.4219 10.7984 10.3204 10.8407C10.2188 10.883 10.1099 10.9048 9.99989 10.9048C9.88988 10.9048 9.78096 10.883 9.67941 10.8407C9.57786 10.7984 9.48569 10.7364 9.40822 10.6583L5.59155 6.84167C5.51409 6.76356 5.42192 6.70156 5.32037 6.65926C5.21882 6.61695 5.1099 6.59517 4.99989 6.59517C4.88988 6.59517 4.78096 6.61695 4.67941 6.65926C4.57786 6.70156 4.48569 6.76356 4.40822 6.84167C4.25301 6.9978 4.16589 7.20901 4.16589 7.42917C4.16589 7.64932 4.25301 7.86053 4.40822 8.01666L8.23322 11.8417C8.70197 12.3098 9.33739 12.5728 9.99989 12.5728C10.6624 12.5728 11.2978 12.3098 11.7666 11.8417L15.5916 8.01666C15.7468 7.86053 15.8339 7.64932 15.8339 7.42917C15.8339 7.20901 15.7468 6.9978 15.5916 6.84167V6.84167Z' fill='%23374957'/%3E%3C/svg%3E" />
							<a style="padding-left: 7px;">Nodes Info</a>
						</span>
						<div id="nodesInfo" style="display:none; margin-top: 20px; margin-left: 25px;">
							<table class="nodesInfo">
								<tr class='table-header'>
									<th>Host</th>
									<th>Port</th>
									<xsl:choose>	
										<xsl:when test="starts-with($suiteName, 'LOAD_')">
											<th>Noise Tests executed</th>
										</xsl:when>
										<xsl:otherwise>
											<th>Tests executed </th>
										</xsl:otherwise>
									</xsl:choose>
								</tr>
								<xsl:for-each select="suite/suiteSummary/nodes/node">
									<tr class='table-data'>
										<td>
											<xsl:value-of select="HOSTNAME" />
										</td>
										<td>
											<xsl:value-of select="PORT" />
										</td>
										<td>
											<xsl:value-of select="SCRIPTCOUNT" />
										</td>
									</tr>
								</xsl:for-each>
							</table>
						</div>
					</div>
				</xsl:when>
				<xsl:otherwise>
					<h2 style="font-size: 16px;font-weight: 600;">Suites Comparsion</h2>
					<table class="compare_suite_summary">
						<tr class="table-header">
							<th colspan="2">Suite Name:</th>
							<xsl:for-each select="/suites/suite/suiteSummary">
								<xsl:variable name="checkAllSelected"><xsl:value-of select="suitename|SUITENAME" /></xsl:variable>
								<xsl:if test="$checkAllSelected != '' and $checkAllSelected != 'null' ">
									<th style="font-weight:600"><xsl:value-of select="suitename|SUITENAME" /></th>
								</xsl:if>
							</xsl:for-each>
						</tr>
						<tr class='table-data'>
							<td colspan="2">Final Status:</td>
							<xsl:for-each select="/suites/suite/suiteSummary">
							<xsl:variable name="checkAllSelected"><xsl:value-of select="suitename|SUITENAME" /></xsl:variable>
							<xsl:variable name="className" ><xsl:value-of select="suitestatus|SUITESTATUS" /></xsl:variable>
							<xsl:if test="$checkAllSelected != '' and $checkAllSelected != 'null' ">
							<td>
								<span class="{$className} flex-row status-icon" style="margin: unset;">
									<span><xsl:value-of select="translate(suitestatus|SUITESTATUS, $uppercase, $lowercase)" /></span>
								</span>
							</td> 
							</xsl:if>
							</xsl:for-each>
						</tr>
						<tr class='table-data'>
							<td colspan="2">Start Time:</td>
							<xsl:for-each select="/suites/suite/suiteSummary">
								<xsl:variable name="checkAllSelected"><xsl:value-of select="suitename|SUITENAME" /></xsl:variable>
								<xsl:if test="$checkAllSelected != '' and $checkAllSelected != 'null' ">
									<td class='date-time'>
										<xsl:attribute name="data-text">
											<xsl:value-of select="util:humanTime(STARTTIME)" />
										</xsl:attribute>
									</td>
								</xsl:if>
							</xsl:for-each>
						</tr>
						<tr class='table-data'>
							<td colspan="2">Time Taken:</td>
							<xsl:for-each select="/suites/suite/suiteSummary">
							<xsl:variable name="checkAllSelected"><xsl:value-of select="suitename|SUITENAME" /></xsl:variable>
							<xsl:if test="$checkAllSelected != '' and $checkAllSelected != 'null' ">
								<td class='time-taken'>
									<xsl:attribute name="data-text">
										<xsl:value-of select="util:prettyTimeMoreThan24Hours(TIMETAKEN)" />
									</xsl:attribute>
								</td>
							</xsl:if>
							</xsl:for-each>
						</tr>
						<tr class='table-data'>
							<td colspan="2">Browser:</td>
							<xsl:for-each select="/suites/suite/suiteSummary">
							<xsl:variable name="checkAllSelected"><xsl:value-of select="suitename|SUITENAME" /></xsl:variable>
							<xsl:variable name="browserType" select="BROWSERTYPE" />
							<xsl:if test="$checkAllSelected != '' and $checkAllSelected != 'null' ">
								<td>
								<xsl:if test="$browserType != 'null' and $browserType != ''">
									<span><xsl:value-of select="$browserType" /></span>
								</xsl:if>
								</td>
							</xsl:if>
							</xsl:for-each>
						</tr> 
						<tr class='table-data'>
							<td rowspan="4">Steps:</td>
						</tr>
						<tr class='table-data'>
							<td>Passed</td>
							<xsl:for-each select="/suites/suite/suiteSummary">
							<xsl:variable name="checkAllSelected"><xsl:value-of select="suitename|SUITENAME" /></xsl:variable>
							<xsl:if test="$checkAllSelected != '' and $checkAllSelected != 'null' ">
								<td>
								<xsl:value-of select="passedCount|PASSEDCOUNT" />
								</td>
							</xsl:if>
							</xsl:for-each>
						</tr>
						<tr class='table-data'>
							<td>Failed</td>
							<xsl:for-each select="/suites/suite/suiteSummary">
							<xsl:variable name="checkAllSelected"><xsl:value-of select="suitename|SUITENAME" /></xsl:variable>
							<xsl:if test="$checkAllSelected != '' and $checkAllSelected != 'null' ">
								<td>
								<xsl:value-of select="failedCount|FAILEDCOUNT" />
								</td>
							</xsl:if>
							</xsl:for-each>
						</tr>
						<tr class='table-data'>
							<td>Total</td>
							<xsl:for-each select="/suites/suite/suiteSummary">
							<xsl:variable name="checkAllSelected"><xsl:value-of select="suitename|SUITENAME" /></xsl:variable>
							<xsl:if test="$checkAllSelected != '' and $checkAllSelected != 'null' ">
								<td>
								<xsl:value-of select="totalCount|TOTALCOUNT" />
								</td>
							</xsl:if>
							</xsl:for-each>
						</tr>
					</table>
				</xsl:otherwise>
			</xsl:choose>
				
				<script>
					<![CDATA[
					
					
					function getCount(elId) {
						var el = $_(elId);
						if (!el) return 0;
						var t = el.textContent;
						return isNaN(t) ? 0 : parseInt(t);
					}
							
					function xrefreshPage(){
						return;
						var el = document.getElementById("status");
						if (el && (el.className == "SUCCESS" || el.className == "FAILURE")){
							return;
						}
						window.setTimeout("window.location.reload();", 2000);
					}
					xrefreshPage();
					function showHide(s){var el=document.getElementById(s);el.style.display = (el.style.display == 'block') ? 'none' : 'block'; }; 
					function getCheckedScripts(){
						var elements = document.getElementById("scriptSummaries").getElementsByTagName("INPUT");
						var ids=[];
						mainSuiteIds.length = 0;
						subSuiteIds.length = 0;
						for(var itr=0;itr<elements.length;itr++){
							var element = elements[itr];
							if(element.type == "checkbox" && element.checked && element.id != 'checkAllCB' && element.getAttribute("name") != "cbs"){
								ids.push(element.value);
								var pid = element.parentNode.parentNode.parentNode.getAttribute("data-tt-parent-id");
								setParentInHierarchy(pid);
							}
						}
						return ids;
					}
					var consoleLogVerified = false;
					function showSuiteInfoData() {
						if (useDBURL && !consoleLogVerified)  {
							if (mainSuiteCount == 1) {
								//displayConsoleLogs(suiteReportID);
								consoleLogVerified = true;
							}
						}
						showHide('suiteInfo');
					}
					function getSuites(){
						var elements = document.getElementById("scriptSummaries").getElementsByTagName("INPUT");
						var ids=[];
						mainSuiteIds.length = 0;
						subSuiteIds.length = 0;
						for(var itr=0;itr<elements.length;itr++){
							var element = elements[itr];
							if(element.type == "checkbox" && element.id != 'checkAllCB' && element.getAttribute("name") == "cbs"){
								ids.push(element.value);
							}
						}
						return ids;
					}
					var mainSuiteIds=[];
					var subSuiteIds=[];
					function setParentInHierarchy(id) {
						var parent = document.querySelectorAll("[data-tt-id='"+id+"']")[0];
						if (parent == undefined) return;
						var el = parent.getElementsByTagName("INPUT")[0];
						
						var pid = parent.getAttribute("data-tt-parent-id")
						if(pid == "null") {
							if($.inArray(el.value, mainSuiteIds) == -1){
								mainSuiteIds.push(el.value);
							}
						} else {
							if($.inArray(el.value, subSuiteIds) == -1){
								subSuiteIds.push(el.value);
							}
						}
						setParentInHierarchy(pid);
					}
					function compareUI() {
						var ids = getCheckedScripts();
						if(ids.length < 2){
							alert("Please select two or more scripts to compare");
							return;
						}
						location.href = "DBReports_scriptUIComparisonReport?id="+ids[0]+"&compareIds="+ids.slice(1).join(',');
					}
					function checkAll(isChecked){
						var els = document.getElementsByTagName("INPUT");
						for (var i=0; i<els.length; i++) {
							var el = els[i];
							if (el.type == "checkbox") {
								el.checked = false;
								if(el.parentNode.parentNode.style.display != "none"){
									el.checked = isChecked;
								}
							}
						}
					}
					function onCheckClick(e){
						var name = e.getAttribute("name");
						if (name == "cbs") {
							var pid = e.parentNode.parentNode.parentNode.getAttribute("data-tt-id");
							//var length = document.querySelectorAll("[data-tt-parent-id='"+pid+"']").length;
							selectAllChildCheckbox(pid, true && !e.getAttribute("data-children-checked"));
							if (!e.getAttribute("data-children-checked")) {
								e.setAttribute("data-children-checked", "checked");
								e.checked = true;
								checkVisibleBranches(pid, true);
							} else {
								e.removeAttribute("data-children-checked");
								e.checked = false;
								e.classList.remove('indeterminate-checkbox');
								checkVisibleBranches(pid, false);
							}
						}
						if(!e.checked){
							//uncheck parent suites
							var pid = e.parentNode.parentNode.parentNode.getAttribute("data-tt-parent-id");
							if (pid && pid !== "null") {
								setParentNodesCheckStatus(pid, false);
							}
						} else {
							var pid = e.parentNode.parentNode.parentNode.getAttribute("data-tt-parent-id");
							if (pid && pid !== "null") {
								setParentNodesCheckStatus(pid, true);
							}
						}
					}

					function checkVisibleBranches(parentId, isCheck) {
						var scriptRows = document.querySelectorAll('tr[data-tt-parent-id="' + parentId + '"]');

						for (var i = 0; i < scriptRows.length; i++) {

							if (scriptRows[i].style.display !== "none") {
							
								if (_classList.contains(scriptRows[i], "branch")) {

									var el = scriptRows[i].getElementsByTagName("INPUT")[0];
									el.indeterminate = false;
									el.checked = isCheck;
									if (isCheck) {
										el.setAttribute("data-children-checked", "checked");
									} else {
										el.removeAttribute("data-children-checked");
									}
								}
							}
							checkVisibleBranches(scriptRows[i].getAttribute("data-tt-id"), isCheck);
						}
					}
					
					function setParentNodesCheckStatus(pid, check) {
						var parentRow = document.querySelectorAll("[data-tt-id='"+pid+"']");

						if (!parentRow || parentRow.length==0 || parentRow[0].style.display == 'none') return;

						parentRow[0].cells[0].children[1].children[0].indeterminate = false;
						parentRow[0].cells[0].children[1].children[0].checked = check;
						if (check && isSiblingsChecked(pid, true)) {
							parentRow[0].cells[0].children[1].children[0].checked = check;
						} else if (check && !isSiblingsChecked(pid, true)) {
							parentRow[0].cells[0].children[1].children[0].checked = false;
							parentRow[0].cells[0].children[1].children[0].indeterminate = true;
							parentRow[0].cells[0].children[1].children[0].removeAttribute("data-children-checked");
						} else if (!check && isSiblingsChecked(pid, false)) {
							parentRow[0].cells[0].children[1].children[0].checked = false;
							parentRow[0].cells[0].children[1].children[0].indeterminate = true;
							parentRow[0].cells[0].children[1].children[0].removeAttribute("data-children-checked");
						}

						if (parentRow[0].cells[0].children[1].children[0].indeterminate == true) {
							parentRow[0].cells[0].children[1].children[0].classList.add('indeterminate-checkbox');
						} else {
							parentRow[0].cells[0].children[1].children[0].classList.remove('indeterminate-checkbox');
						}
						if(parentRow[0].getAttribute("data-tt-parent-id") == 'null') return;
						setParentNodesCheckStatus(parentRow[0].getAttribute("data-tt-parent-id"), check);
					}
					
					function isSiblingsChecked(parentId, isAllChecked) {
					
						var siblings = document.querySelectorAll('tr[data-tt-parent-id="' + parentId + '"]');

						for (var i = 0; i < siblings.length; i++) {

							if (!siblings[i].cells 
								|| !siblings[i].cells[0].children[1] 
								|| !siblings[i].cells[0].children[1].children[0] 
								|| isRowElementMatchesUncheckedFilter(siblings[i])
							) {
							
								continue;
							}
							if (siblings[i].cells[0].children[1].children[0].checked) {
								
								if (!isAllChecked) {
									
									return true;
									
								}
							} else if (isAllChecked) {
								
								return false;
							}
						}
						
						return true && isAllChecked;
					}
					
					function isRowElementMatchesUncheckedFilter(el) {
						for (var j = 0; j < nonSelectedStatusValues.length; j++) {
							if(_classList.contains(el, nonSelectedStatusValues[j])) {
								return true;
							}
						}
						return false;
					}
					
					function selectAllChildCheckbox(pid, isChecked) {
						var rows = document.querySelectorAll("[data-tt-parent-id='"+pid+"']");
						var isStatusMatch = false;
						for (var i=0;i<rows.length;i++) {
							for (var j = 0; j < selectedStatusValues.length; j++) {
								if (_classList.contains(rows[i], selectedStatusValues[j])) {
									isStatusMatch = true;
									break;
								}
							}
							if (isStatusMatch) {
								var el = rows[i].getElementsByTagName("INPUT")[0];
								el.indeterminate = false;
								el.checked = isChecked;
								
								isStatusMatch = false;
							}
							
							var pid = rows[i].getAttribute("data-tt-id");
							selectAllChildCheckbox(pid, isChecked);
						}
					}
					function hideBigImg(){
						var container = document.getElementById("largeImageContainer");
						if(container.style.display == "block"){
							container.style.display = "none";
						}
					}
					
					function bigImg(e){
						var container = document.getElementById("largeImageContainer");
						var newImg = '<img src="' + e.src + '"';
						var defaultgalleryWidth = "800";
						var defaultgalleryHeight = "600";
						container.style.width = defaultgalleryWidth;
						container.style.height = defaultgalleryHeight;
						newImg += 'style="';
						if(e.naturalWidth > defaultgalleryWidth){
							var newWidth =  defaultgalleryWidth - getScrollbarWidth();
							newImg += 'width: ' + newWidth + 'px;';
						}else{
							container.style.width = e.naturalWidth + getScrollbarWidth();
						}
						newImg += '"';
						newImg += '/>';
						container.style.zIndex = '1000';
						container.style.display = "block";
						container.style.position = "fixed";
						container.innerHTML = newImg;
						container.style.background = "white";
						container.style.overflowY = "scroll";
					}
					
					function getScrollbarWidth() {
					    var outer = document.createElement("div");
					    outer.style.visibility = "hidden";
					    outer.style.width = "100px";
					    document.body.appendChild(outer);
					    
					    var widthNoScroll = outer.offsetWidth;
					    // force scrollbars
					    outer.style.overflow = "scroll";
					    
					    // add innerdiv
					    var inner = document.createElement("div");
					    inner.style.width = "100%";
					    outer.appendChild(inner);        
					    
					    var widthWithScroll = inner.offsetWidth;
					    
					    // remove divs
					    outer.parentNode.removeChild(outer);
					    
					    return widthNoScroll - widthWithScroll;
					}
					
					function getViewport() {
						 var viewPortWidth;
						 var viewPortHeight;
						
						 // the more standards compliant browsers (mozilla/netscape/opera/IE7) use window.innerWidth and window.innerHeight
						 if (typeof window.innerWidth != 'undefined') {
						   viewPortWidth = window.innerWidth,
						   viewPortHeight = window.innerHeight
						 }
						
						// IE6 in standards compliant mode (i.e. with a valid doctype as the first line in the document)
						 else if (typeof document.documentElement != 'undefined'
						 && typeof document.documentElement.clientWidth !=
						 'undefined' && document.documentElement.clientWidth != 0) {
						    viewPortWidth = document.documentElement.clientWidth,
						    viewPortHeight = document.documentElement.clientHeight
						 }
						
						 // older versions of IE
						 else {
						   viewPortWidth = document.getElementsByTagName('body')[0].clientWidth,
						   viewPortHeight = document.getElementsByTagName('body')[0].clientHeight
						 }
						 return [viewPortWidth, viewPortHeight];
					}
					
					function addImages(screenShots, useDBURL){
						/*var images = screenShots.split(",");
						var msg =  '<div>';
						for(var i=0; i<images.length; i++){
							var img = images[i];
							if (img == "") continue;
							if (useDBURL) {
								msg += "<img width='20px' height='20px' src='/_s_/dyn/Log_viewLogs/images/" + img + "' style='cursor:pointer;border:1px solid white; margin:2px;' onclick='window.open(this.src)' onmouseover='bigImg(this)'>";
							} else {
								msg += "<img width='20px' height='20px' src='images/" + img + "' style='cursor:pointer;border:1px solid white; margin:2px;' onclick='window.open(this.src)' onmouseover='bigImg(this)'>";
							}
						}
						msg += '</div>';
						document.write(msg);*/
					}
					function addArtifacts(artifacts, scriptReportId, useDBURL){
						var artifactAr = artifacts.split(",");
						var msg =  '';
						for(var i=0; i<artifactAr.length; i++){
							var artifact = artifactAr[i];
							if(artifact == "") continue;
							var artifactName = getArtifactName(artifact, scriptReportId);
							if (useDBURL) {
								msg += '<a href="/_s_/dyn/Log_viewLogs/images/' + artifact +  '" style="margin:0px 10px 0px 0px;padding:0px;text-decoration:underline;" target="_blank">' + artifactName + '</a></br>';
							} else {
								msg += '<a href="images/' + artifact +  '" style="margin:0px 10px 0px 0px;padding:0px;text-decoration:underline;" target="_blank">' + artifactName + '</a></br>';
							}
						}
						document.write(msg);
					}
					function getArtifactName(artifact, scriptReportId){
						var artifactName = artifact.replace(scriptReportId, "");
						artifactName = artifactName.replace(/^_\d+_/,"");
						return artifactName;	
					}
					function modifyArtifactName(artifact, scriptReportId, suffixEnabled) {
						var name = getArtifactName(artifact, scriptReportId);
						if (!suffixEnabled) return name;
						var id = artifact.replace(name, "").replace(/_$/, "");
						var nameWithoutExtension = name.substring(0, name.lastIndexOf("."));
						var modifiedName = name.replace(nameWithoutExtension, nameWithoutExtension+"_"+id);
						return modifiedName;
					}
					function createDownloadLink(artifacts, scriptReportId, suffixEnabled){
						var artifactAr = artifacts.split(",");
						var downloadArtifactsLink = document.getElementById('downloadArtifacts');
						var href = downloadArtifactsLink.href;
						var artifactsName = "&artifactsName=";
						for(var i=0; i<artifactAr.length; i++){
							var artifact = artifactAr[i];
							if(artifact == "") continue;
							
							if(i != 0) {
								href += ",";
								artifactsName += ",";
							}
							artifactsName += modifyArtifactName(artifact, scriptReportId, suffixEnabled);
							href += artifact;
						}
						href += artifactsName;
						downloadArtifactsLink.href = href;
					}
					function displayConsoleLogs(suiteReportId){
						var url = '/_s_/dyn/pro/DBReports_hasConsoleLogs?suiteReportId='+suiteReportId;
						sahiSendToServer(url,true,function (res){
							if(res){
								if (res == "true") {
									$_('consoleLogs').style.display="";
								}
							}
						});
					}
					]]>
					</script>
				<div id="downloadFileType" class="downloadFileType">
				   <div class='popup-header flex-row' style="margin-left: 10px; margin-right: 10px; justify-content: space-between;">
				       <span style="font-weight: 700;text-align: left;">Download As</span>
				       <span class="closePopupContainer" onclick="closePopUp()"></span>
				   </div>
				   <div class='download-options'>
				        <div class="popUpContainer">
							<label for="excel"><span class='flex-row'>
								excel
								<input type="radio" name="fileType" id="excel" value="excel"/>
							</span></label>
				        </div>
				        <div class="popUpContainer">
							<label for="xml"><span class='flex-row'>
								xml
								<input type="radio" name="fileType" id="xml" value="xml"/>
							</span></label>
				        </div>
				        <div class="popUpContainer">
							<label for="html"><span class='flex-row'>
								html
								<input type="radio" name="fileType" id="html" value="html"/>
							</span></label>
				        </div>
				        <div class="popUpContainer">
							<label for="email"><span class='flex-row'>
								email
								<input type="radio" name="fileType" id="email" value="email"/>
							</span></label>
				        </div>
				        <div class="popUpContainer">
							<label for="junit"><span class='flex-row'>
								junit
								<input type="radio" name="fileType" id="junit" value="junit"/>
							</span></label>
				        </div>
			       </div>
			       <div style="padding-top: 20px; text-align: center;">
			         <input type="button" class="popUpButton" onclick="downloadScriptsArchiveAs()"  value="Download"/>
			       </div>
		        </div>
				<div class='mask download-mask' style="display: none;"></div>

				<div id="table-buttons" style="margin-top: 25px;">
				 <span style="font-size: 18px;font-weight: 700;">Suite Report</span>
				 <span id="scriptActions">
				   <span id="expandAll" style="cursor:pointer;margin-right:20px; font-weight: 600; color: #4E4E4E;" onclick="expandCollapseAll(true)">Expand All</span>
				   <span id="collapseAll" style="cursor:pointer;margin-right:60px; font-weight: 600; color: #4E4E4E;" onclick="expandCollapseAll(false)">Collapse All</span>
				   <xsl:choose>
				      <xsl:when test="$useDBURL = 'true'">
				         <span class="actionButton flex-row" onclick="compareUI()" style="margin-left: 75px;">
				           <img src="/_s_/spr/images/fi-rr-gallery.svg"/>
						   <span>Compare Screenshots</span>
				         </span>
						 <span class="actionButton flex-row" onclick="compareLogs()">
						      <img src="/_s_/spr/images/fi-rr-file.svg"/>
							  <span>Compare Logs</span>
						 </span>
						 <span id="downloadScripts" class="actionButton brand flex-row" onclick="downloadScriptsArchive()">
							  <img src="/_s_/spr/images/fi-sr-download.svg"/>
							  <span>Download</span>
						 </span>
					   </xsl:when>
					</xsl:choose>
				 </span>	
			  </div>
		
			<div style="min-height:250px; margin-left: 0px;" id='suite-table'>
				<table class="scriptSummaries treetable" id="scriptSummaries">
					<thead>
						<tr class='table-header' id="scriptSummariesHeader">
							<th>Test</th>
							<!-- <th>Start Url</th> -->
							<th>Final Status</th>
							<th colspan="4" class="steps-header">Steps</th>
							<th colspan="4" class="tc-header">Testcases</th>
							<th>Intermediate Statuses</th>
							<th>Start Time</th>
							<th width="90px;">Time Taken</th>
							<th>Load</th>
							<th>Node</th>
							<!-- Custom Field header-->
							<!-- <th id="RowNo">Custom Field</th> -->
						</tr>
						<tr class='table-header'>
							<th></th>
							<!-- <th></th> -->
							<th><input id="statusCombo" class="easyui-combobox" data-options="data:statusData,
										onChange:showHideRows,valueField:'id',textField:'text',
										value:['SUCCESS','FAILURE','ERROR','ABORTED','ABORTED_TIMEOUT','SKIPPED','NOT_SUPPORTED'],
										multiple:true,editable:false,panelHeight:'auto'">
								</input>
							</th>
							<th colspan='4' class="steps-header">Failed / Errors / Success % / Total</th>
							<th colspan='4' class="tc-header">Failed / Passed / Success % / Total</th>
							<th><input id="intermediateStatusCombo" class="easyui-combobox" data-options="data:intermediateStatusData,
								onChange:showHideRows,valueField:'id',textField:'text',
								value:['HEALED','FAILURE','ERROR', 'NA'],
								multiple:true,editable:false,panelHeight:'auto'">
								</input>
							</th>
							<th></th>
							<th></th>
							<th></th>
							<th></th>
							<!-- Uncomment in case of using Custom Field header-->
							<!-- <th id="RowNoAcc"></th> -->
						</tr>  
					</thead>
					<tbody>
						<xsl:apply-templates select="suite" />
					</tbody>
					<script type="text/javascript">
						var suiteName = '<xsl:value-of select="$suiteName" />';
						var mainSuiteCount = '<xsl:value-of select="($mainSuiteCount)"/>';
						var statusData = [{"id":"SUCCESS", "text":"Success"}, {"id":"FAILURE", "text":"Failure"}, {"id":"ERROR", "text":"Error"}, {"id":"ABORTED", "text":"Aborted"},
						{"id":"ABORTED_TIMEOUT", "text":"Aborted Timeout"}, {"id":"SKIPPED", "text":"Skipped"}, {"id":"NOT_SUPPORTED", "text":"Not Supported"},
						{"id":"FAILURE_RETRY", "text":"Retried"},{"id":"INTERNAL_ABORTED", "text":"Internal  Aborted"}];
						var intermediateStatusData = [{"id":"HEALED", "text":"Healed"}, {"id":"FAILURE", "text":"Failure"}, {"id":"ERROR", "text":"Error"}, {"id":"NA", "text":"NA"}];
						<![CDATA[
						arrangeRetriedScripts();
						var checkedIds =[];
						if (window.location.search.indexOf('o=list')!=-1 && !isSuite(suiteName)) {
							removeRetriedScripts()
							var getTable = document.getElementById('scriptSummaries');
							var links = getTable.getElementsByTagName('a');
							var redirect = (links[1].href.indexOf('DBReports_scriptReport')!=-1) ? links[1].href : '';
							window.location.replace(redirect);
						}
						var cookieHashMap = {};
						var nodeHashMap = {};
						function $_(id) {
							return document.getElementById(id);
						}
						function hasClass(ele,cls) {
							return ele.className.match(new RegExp('(\\s|^)'+cls+'(\\s|$)'));
						}
						
						function getRandomNumberWithin(limit){
							return Math.round(Math.random() * limit);
						}
						var colors = ['0000FF', 'FF00FF', 'FFA500', '800000', '0000A0', '808000', '808080', 'A52A2A', '00FFFF', 'ffa500'];
						var colorIx = 0;
						function getRandomColor(){
							return colors[(colorIx++)%(colors.length)];
						    var possibilities = '0123456789ABCDEF'.split('');
						    var color = '';
						    for (var itr=0; itr<6 ; itr++ ) {
						        color += possibilities[getRandomNumberWithin(15)];
						    }
						    return color;
						};
			
						function isSuite(name) {
							if (endsWith(name, ".suite") || endsWith(name, ".dd.csv")) {
								return true;
							}
							return false;
						}
						
						function endsWith(str, suffix) {
							return str.indexOf(suffix, str.length - suffix.length) !== -1;
						}
						
						function ifNotCounterExists(counter){
							return $_("script-"+counter) == null;
						}
						function getScriptName(counter){
							return $_("script-"+counter).innerHTML;
						}
						function getReportId(counter){
							return $_("script-"+counter).parentNode.parentNode.parentNode.id;
						}
						function getTimeTaken(counter){
							var timeTaken = getCount("timetaken-"+counter);
							if (hasClass($_("status-"+counter),"SKIPPED") || hasClass($_("status-"+counter),"NOT_SUPPORTED") || hasClass($_("status-"+counter),"null") || (hasClass($_("status-"+counter),"INTERNAL_ABORTED") && timeTaken == 0)) {
								return 20000;
							}
							return timeTaken;
						}
						function getTotalSteps(counter){
							return getCount("totalsteps-"+counter);
						}
						function getErrorsCount(counter){
							return getCount("errors-"+counter);
						}
						function getFailuresCount(counter){
							return getCount("failures-"+counter);
						}
						function getStatus(counter){
							return $_("status-"+counter).className;
						}
						function getBarColor(counter){
							let tr = document.getElementById("status-"+counter);
							let td = tr.getElementsByTagName("td")[1].querySelectorAll("span")[1].innerText;
							if(td == "SUCCESS") return "008000";
							else if(td == "ABORTED" || td == "INTERNAL_ABORTED" || td == "INTERNAL_ABORTED_RETRY" ||
							        td == "ABORTED_TIMEOUT" || td == "USER_ABORTED")  return "A52A2A";
							else if(td == "ERROR" || td == "FAILURE") return "FF0000";
							else if(td == "SKIPPED") return "A9A9A9";
							else if(td == "NOT_SUPPORTED") return "76777b";
						    else return "ffa500";
						}
						function getLinkHref(counter){
							return $_("script-"+counter).href;
						}
						
						function getDataPointsForCompare(graphObj,yAxis){
							var data = [];
							for(line in graphObj){
								var arr = [];
								var lineColor = getRandomColor();
								var counter = 0;
								for(point in graphObj[line]){
									var obj = {};
									obj.suiteId = line;
									obj.color = lineColor;
									obj.scriptName = point;
									obj.index = counter++;
									if(graphObj[line][point] != null){
										obj.y = graphObj[line][point][yAxis];
									} else {
										obj.y = 0;
									}
									arr.push(obj);
								}
								data.push(arr);
							}
							return data;
						}
		
		     	 		function nullifySuitesWithoutScript(graphObj,scriptName){ //to nullify suites without certain scripts that are present in other compared suites
		     	 			for(each in graphObj){
		     	 				if(typeof graphObj[each][scriptName] == "undefined"){
		     	 					graphObj[each][scriptName] = null;
		     	 				}
		     	 			}
		     	 		}
						
						function getScriptObject(counter){
							var scriptObj = {};
					 		scriptObj["status"] = getStatus(counter);
					 		scriptObj["timeTaken"] = getTimeTaken(counter);
					 		scriptObj["totalSteps"] = getTotalSteps(counter);
					 		scriptObj["errorsCount"] = getErrorsCount(counter);
					 		scriptObj["failuresCount"] = getFailuresCount(counter);
						 	return scriptObj;	
						}
						
						var queryStringObject = function () { //returns URL QueryString parameters as a JSON object
						  var query_string = {};
						  var query = window.location.search.substring(1);
						  var vars = query.split("&");
						  for (var i=0;i<vars.length;i++) {
						    var pair = vars[i].split("=");
						        query_string[pair[0]] = pair[1];
						  } 
						    return query_string;
						}();
		
						function getGraphObject(allIds){
							var graphObj = {};
							for(var each=0;each<allIds.length;each++) graphObj[allIds[each]] = {};
							var current_script_name = "";
							
							for(var counter=1;;counter++){
							 	if(ifNotCounterExists(counter)) break;
						 		if( (current_script_name != "") || (current_script_name != getScriptName(counter)) ){ //first script for same name as previous script
						 			nullifySuitesWithoutScript(graphObj,getScriptName(counter));	
						 		}
					 			current_script_name = getScriptName(counter);
					 			var report_id = getReportId(counter);
						 		graphObj[report_id][current_script_name] = getScriptObject(counter);	
					 						 		
							}
							return graphObj;
						}

						function roundUp(n) {
							if (n > 50)
								return (n+50) - ((n+50) % 50) + 10;
							return (n+10) - ((n+10) % 10) + 10;
						}
						
						function renderSingleBarChart(containerDiv){
							const containerWidth = $_(containerDiv).clientWidth;
							const containerHeight = $_(containerDiv).clientHeight;

							var margin = {
								top: 20, 
								bottom: 50, 
								right: 20, 
								left: 80 
							};

							var innerWidth = containerWidth - margin.left - margin.right;
							var innerHeight = containerHeight - margin.top - margin.bottom;

							var barData = getBarData();
							var data = [barData];
							let dataLength = barData.length;

							let outerPadding = 5, innerPadding = 0.5;
							let barWidth = 300;		// max bar-width

							dataLength = 2
							barWidth = Math.floor(Math.min(barWidth, (innerWidth - 2*outerPadding)/dataLength));

							if (innerWidth - (barWidth * dataLength) < 20) {
								innerPadding = 0.1 * barWidth;
								barWidth = barWidth - 2*innerPadding;
							} else {
								innerPadding = (innerWidth - barWidth*dataLength) / (dataLength-1)
							}

							const xValue = d => d.index
							const xDomain = barData.map(d => xValue(d).toString())
							const xRange = [0, innerWidth]
							const xScale = d3.scale.ordinal()
								.domain(xDomain)
								.rangeBands(xRange, 0.5, 2.0);

							const yValue = d => d.x
							const yDomain = [0, Math.ceil(d3.max(barData, yValue))];
							const yRange = [0, innerHeight]
							const yScale = d3.scale.linear()
								.domain(yDomain)
								.range(yRange)
								.nice();
							const yScaleTicks = yScale.ticks(5)

							var svg = d3.select("#"+containerDiv)
									.append("svg")
									.attr("class", "chart")
									.attr("viewBox", `0 0 ${containerWidth} ${containerHeight}`)
									.attr("preserveAspectRatio", "xMidYMid meet");

							svg.append('rect')
								.attr('x', margin.left)
								.attr('y', margin.top)
								.attr('width', innerWidth)
								.attr('height', innerHeight)
								.attr('fill', 'none')

							const yAxisParent = svg.append("g")
								.attr("class","y-axis")
								.attr("transform", `translate(${margin.left}, ${margin.top})`);

							yAxisParent.append("line")
								.attr("x1", 0)
								.attr("x2", 0)
								.attr("y1", 0)
								.attr("y2", innerHeight)
								.attr("stroke", "#bebebe")
								.attr("fill", "none");

							const yAxisTicks = yAxisParent.selectAll('g.ticks')
								.data(yScaleTicks)
								.enter()
								.append("g")
								.attr('class', 'ticks');

							yAxisTicks.append('line')
								.attr('x1', 0)
								.attr('x2', -8)
								.attr('y1', d => innerHeight - yScale(d))
								.attr('y2', d => innerHeight - yScale(d))
								.attr('stroke', '#bebebe')
								.attr('fill', 'none');

							yAxisTicks.append('line')
								.attr('class', 'grid-line')
								.attr('x1', 0)
								.attr('x2', innerWidth)
								.attr('y1', d => innerHeight - yScale(d))
								.attr('y2', d => innerHeight - yScale(d))
								.attr('stroke', '#ddd')
								.attr('fill', 'none');
							
							yAxisTicks.append('text')
								.text(d => d)
								.attr("x", -20)
								.attr("y", d => innerHeight - yScale(d))
								.attr("dy", "5px")
								.style("text-anchor", "middle")
								.style("font-size", "12px");

							yAxisParent.append('g')
								.attr('class', 'label')
								.attr('transform', `translate(-55, ${innerHeight/2}) rotate(-90)`)
								.append('text')
								.text('Run Time (sec)')
								.style('text-anchor', 'middle')
								.style('font-family', 'Arial, Helvetica, sans-serif')
								.style('font-weight', 600)
								.style('font-size', '16px')
								.style('fill', '#092572');

							const xAxis = svg.append('g')
								.attr('class', 'x-axis')
								.attr('transform', `translate(${margin.left}, ${margin.top + innerHeight})`)
							
							xAxis.append('line')
								.attr('x1', 0)
								.attr('x2', innerWidth)
								.attr('y1', 0)
								.attr('y2', 0)
								.attr('stroke', '#bebebe')
								.attr('fill', 'none');

							xAxis.append('line')
								.attr('class', 'tick')
								.attr('y2', 8)
								.attr('stroke', '#bebebe')

							xAxis.append('line')
								.attr('class', 'tick')
								.attr('x1', innerWidth)
								.attr('x2', innerWidth)
								.attr('y2', 8)
								.attr('stroke', '#bebebe')

							xAxis.append('g')
								.attr('class', 'label')
								.attr('transform', `translate(${innerWidth/2}, 30)`)
								.append('text')
								.text('Scripts')
								.style('text-anchor', 'middle')
								.style('font-family', 'Arial, Helvetica, sans-serif')
								.style('font-weight', 600)
								.style('font-size', '16px')
								.style('fill', '#092572');

							const bars = svg.append('g')
								.attr('transform', `translate(${margin.left}, ${margin.top})`)
								.attr('width', innerWidth)
								.attr('height', innerHeight)
								.selectAll('rect')
								.data(barData)
								.enter()
								.append('a')
									.attr('href', d => d.link)
									.append('rect')
									.attr('x', d => xScale(xValue(d)))
									.attr('y', d => innerHeight - yScale(d.x))
									.attr('width', Math.min(xScale.rangeBand(), 50))
									.attr('height', d => yScale(d.x))
									.attr('fill', d => `#${d.color}`)
							
							bars.append('title')
								.attr('class', 'tooltip')
								.append('text')
								.text(d => `${d.scriptName.trim()}\nTime: ${d.x} sec\nStatus: ${d.status}`);
						  	
						}
						
						function getBarData(){
							var barData = [];
							var index = 0;
							for(var counter=1;;counter++){
								var obj = {};
								if(ifNotCounterExists(counter)) break;
								var status = getStatus(counter);
								if(status == "FAILURE_RETRY" || status == "ABORTED_RETRY" || status == "INTERNAL_ABORTED_RETRY") continue;
								obj.status = status;
								obj.scriptName = getScriptName(counter);
								if(!queryStringObject.compareIds) obj.x = getTimeTaken(counter)/1000;
								else obj.y = getTimeTaken(counter)/1000;
								obj.color = getBarColor(counter);
								obj.link = getLinkHref(counter);
								obj.index = index;
								barData.push(obj);

								index++;
							}
							return barData;
						}
						
						function renderCompareChart(containerDiv, filter){
							$_("chContainer").style.display = "block";
							var allIds = queryStringObject.compareIds.split(',');
							allIds.push(queryStringObject.id); //Getting all suite Ids to compare
							var graphObj = getGraphObject(allIds);
							var data = getDataPointsForCompare(graphObj, filter);
			     	 		
			     	 		var padding = {top: 40, right: 50, bottom: 40, left:50};
							var width = $_(containerDiv).offsetWidth - 5 - padding.left - padding.right;            
							var height = 350 - padding.top - padding.bottom;             
							var stack = d3.layout.stack();
							var counter = 0;
							var divisionFactor = 1;
							if(filter == "timeTaken") divisionFactor = 1000;
							
							var unit = "";
							let toolTipUnit = "";
							if(filter == "timeTaken") {
							   unit = " (secs)";
							   toolTipUnit = " secs";
							}
					
							var maxValue = d3.max(data, function(d) {
													return d3.max(d, function(d) {
														return d.y;
													});
												})
							
							var maxScripts = d3.max(data, function(d) {
													return d.length;
												})
												
							var xScale = d3.scale.linear()
										.range([0, width])
										.domain([0, maxScripts-1]);
							
							var yScale = d3.scale.linear()
								.domain([0, (maxValue + 5 + (divisionFactor -(maxValue%divisionFactor)))/divisionFactor])
								.range([height,0]);
								
							var xAxis = d3.svg.axis().scale(xScale).orient("bottom").ticks(0);
							var yAxis = d3.svg.axis().scale(yScale).orient("left").ticks(data.length);
							
							var svg = d3.select("#"+containerDiv)
									.append("svg")
									.attr("width", width + padding.left + padding.right)
									.attr("height", height + padding.top + padding.bottom)
									.attr("class", "chart")
									.style("padding-top", padding.top)
							
							var line = d3.svg.line()
								.x(function(d) { return xScale(d.index); })
								.y(function(d) { return yScale(d.y/divisionFactor); })
								.interpolate("monotone");
							
							svg.selectAll("path")
								.data(data)
								.enter()
								.append("path")
								.datum(function(d) { return d; })
								.attr("class", "line")
								.attr("transform","translate(" + (padding.left) + "," + 0 + ")")
								.style("stroke", function(d) { return "#" + d[0].color; })
								.style("opacity", function(d) {if(! d[0].suiteId) return 0; else return 1;})
								.attr("d", line);	
							
							var tooltip = d3.select("#" + containerDiv).append("div")	
									.attr("class", "d3-tooltip")				
									.style("opacity", 0);
									
							var svgDot = svg.selectAll(".svgDot")
										.data(data)
										.enter()
										.append("svg")
										.attr("class", "svgDot")
									
							svgDot.selectAll("dot")
									.data(function(d) { return d; })	
									.enter()
									.append("circle")
									.style("opacity", function(d) {if(! d.suiteId) return 0; else return 1;})
									.attr("r", 5)		
									.attr("cx", function(d) {return xScale(d.index); })		 
									.attr("cy", function(d) { return yScale(d.y/divisionFactor); })
									.attr("transform","translate(" + (padding.left) + "," + 0 + ")")
									.style("fill","gray")
									.on("mouseover", function(d) {
										var left = 30;
										if(d3.event.pageX < 400) left = 30;
										tooltip	.html(d.scriptName + ", " + d.y/divisionFactor + toolTipUnit)	
											.style("left", (d3.event.pageX - left) + "px")		
											.style("top", (d3.event.pageY - 30) + "px")
											.style("opacity", 1);
										})					
									.on("mouseout", function(d) {		
										tooltip.style("opacity", 0);	
									});
							
							svg.append("g")
								.attr("class","x axis")
								.attr("transform","translate(" + (padding.left ) +" ," + (height) + ")")
								.call(xAxis)
								.append("text")
									.attr("dy", 28)
									.attr("x", width/4)
									.style("font-weight", "bold")
									.text("Scripts");
		
							svg.append("g")
								.attr("class","y axis")
								.attr("transform","translate(" + padding.left + "," + 0 + ")")
								.call(yAxis)
								.append("text")
									.attr("x", -height*2/3)
									.attr("y", -padding.left*2/3)
									.style("font-weight", "bold")
									.attr("transform", "rotate(-90)")
									.text(filter + unit);
							
							var legend = d3.select("#" + containerDiv)
										.append("svg")
										.attr("y", 9)
										.attr("width", width)
										.attr("height", 20*data.length)
										.style("margin-top",-17)
										.style("margin-left",110)
										.selectAll("g")
											.data(data)
										.enter()
											.append("g")
											.attr("transform", function(d, i) { return "translate(0," + i * 25 + ")"; });
		
							legend.append("circle")
								.attr("r", 5)
								.attr("cx", 10)
								.attr("cy", 10)
								.style("fill", function(d) { return "#"+d[0].color })
								.style("opacity", function(d) {if(! d[0].suiteId) return 0; else return 1;});
		
							legend.append("text")
								.attr("x", 24)
								.attr("y", 9)
								.attr("dy", ".35em")
								.style("font-size", "12px")
								.text(function(d) { return d[0].suiteId });
						}
						
						if(!queryStringObject.compareIds){
						//	$_("comparsionSuite").style.display = "none";
							$_("statistics_view_header").style.display = "none";
							$_("radio_span").style.display = "none";
							$_("chContainer").style.display = "none";
							renderSingleBarChart("chartContainer"); //place single suite bar chart here
						} else {
							//Comparing suites
							 hideLinks();
			     	 		 renderCompareChart("chContainer", 'timeTaken');
			     	 		 
						}
						
						function hideLinks(){
							$_("singleSuite_navBar").style.display = "none";
							$_("comparsionSuite").style.display = "block";	
							var expandCell = document.getElementById("expandAll");
							var collapseCell = document.getElementById("collapseAll");
							expandCell.style.display = "none";
							collapseCell.style.display = "none";	
						}
						function compareLogs(){
							var ids = getCheckedLogs();
							if(ids.length == 0){
								alert("Please select at least a script to compare logs")
								return;
							}
							if(ids.length > 2){
								alert("Please select two scripts to compare logs")
								return;
							}
							if(ids.length == 1){
								location.href = "DBReports_compare?logFile1="+ids[0];			
								return;
							}
							location.href = "DBReports_compare?logFile1="+ids[0]+"&logFile2="+ids[1];
						}
						
						function arrangeRetriedScripts(){
							var scriptSummaryTable = document.getElementById("scriptSummaries");
							var scriptRows = scriptSummaryTable.querySelector("tbody tr");
							var scriptsPosMap = {};
							for(var i=1; i<scriptRows.length; i++){
								var launcherId = scriptRows[i].getAttribute("launcherId");
								if (launcherId in scriptsPosMap) {
									var script = scriptRows[0].parentNode.removeChild(scriptRows[i]);
									var position = scriptsPosMap[launcherId];
									scriptRows[0].parentNode.insertBefore(script, scriptRows[position]);
									for (var j in scriptsPosMap){
										var pos = scriptsPosMap[j];
										if (pos >= position) {
											scriptsPosMap[j] = pos+1;
										}
									}
								} else {
									if(_classList.contains(scriptRows[i], "FAILURE_RETRY") || _classList.contains(scriptRows[i], "ABORTED_RETRY") || _classList.contains(scriptRows[i], "INTERNAL_ABORTED_RETRY")){
										scriptsPosMap[launcherId] = (i+1);
									}									
								}
							}
						}
						
						function removeRetriedScripts(){
							var scriptSummaryTable = document.getElementById("scriptSummaries");
							var scriptRows = scriptSummaryTable.getElementsByTagName("TR");
							var j=0;
							var selected = [];
							for(var i=1; i<scriptRows.length; i++){
								if(_classList.contains(scriptRows[i], "FAILURE_RETRY") || _classList.contains(scriptRows[i], "ABORTED_RETRY") || _classList.contains(scriptRows[i], "INTERNAL_ABORTED_RETRY")){
									scriptRows[i].parentNode.removeChild(scriptRows[i]);
									i--;
								}
							}
						}
						
						function isEmpty(map) {
							for (var i in map) {
								return false;
							}
							return true;
						}
						
						var nonSelectedStatusValues = [], selectedStatusValues = [], allStatuses = [];
						var expandedNodesForFilter;
						var callCt = 0;
						var associativeStatuses = {
							ABORTED: [ "USER_ABORTED" ],
							FAILURE_RETRY: [ "ABORTED_RETRY", "INTERNAL_ABORTED_RETRY" ]
						};
						
						function applyOnExpand() {
						}
						
						function applyFilters2() {
							var scriptSummaryTable = document.getElementById("scriptSummaries");
							var scriptRows = scriptSummaryTable.getElementsByTagName("TR");
							var rootNode, rootTrNode;
							// rootNode = this;
							nonSelectedStatusValues = [];
							selectedStatusValues = [];
							allStatuses = [];
							var selectedValues = jQuery('#statusCombo').combo('getValues');
							var selectedIntStatuses = jQuery('#intermediateStatusCombo').combo('getValues');
							for (var i=0; i<statusData.length; i++) {
								var statusValue = statusData[i].id;
								if($.inArray(statusValue, selectedValues) == -1){
									nonSelectedStatusValues.push(statusValue);
									if (statusValue in associativeStatuses) {
										for (var j=0; j<associativeStatuses[statusValue].length; j++) {
											nonSelectedStatusValues.push(associativeStatuses[statusValue][j]);
										}
									}
								} else {
									selectedStatusValues.push(statusValue);
								}
								allStatuses.push(statusValue);
							}
							
							if (scriptRows && nonSelectedStatusValues.length >= 0) {
								if (!rootNode || !rootNode.id) {
									for (var i = 0; i < scriptRows.length; i++) {
										if ((scriptRows[i].getAttribute("rowType") === "suite" 
												&& scriptRows[i].getAttribute("data-tt-parent-id") === "null")) {
											rootTrNode = scriptRows[i];
											try {
												rootNode = $("#scriptSummaries")
													.treetable("node", rootTrNode.getAttribute("data-tt-id"));
											} catch(e) {
												rootNode = null;
											}
											break;
										}
									}
								}
								
								var processRows = function () {
									var statusesToHide = new Array();
									statusesToHide = statusesToHide.concat(nonSelectedStatusValues);
									for (var i = 0; i < scriptRows.length; i++) {
										if (statusesToHide.length == 0 && scriptRows[i].getAttribute("rowType") === "suite") {
											scriptRows[i].style.display = "none";
										} else {
											scriptRows[i].style.display = "table-row";
										}
										for (var j = 0; j < statusesToHide.length; j++) {
											if(_classList.contains(scriptRows[i],statusesToHide[j]) 
												|| scriptRows[i].getAttribute("rowType") === "suite") {
												scriptRows[i].style.display = "none";
											}

											var intermediateStatusCell = scriptRows[i].querySelector(".intemediateStatusCell");
											if (intermediateStatusCell) {
												var intermediateStatuses = intermediateStatusCell.innerHTML;
												if(!shouldShowIntStatsRow(jQuery("#intermediateStatusCombo").combo('getValues'), intermediateStatuses))
													scriptRows[i].style.display = "none";
											}
										}
									}
								};
								
								if (!rootNode) {
									processRows();
									return;
								}
								
								var checkIfNodesAreVisible = function (root) {
									var children = root.children;
									var result = true;
									for (var i = 0; i < children.length; i++) {
										result = result && checkIfNodesAreVisible(children[i]);
									}
									if (!_classList.contains(root.row.context, "leaf")) {
										return result;
									}
									for (var j = 0; j < nonSelectedStatusValues.length; j++) {
										// returns true if the current node is going to be hidden
										if(_classList.contains(root.row.context, nonSelectedStatusValues[j])) {
											return true;
										}
									}
									return false;
								};
								
								var processNode = function (node) {
									var ifBranchAndInvisible = false;
									if (_classList.contains(node.row.context, "branch")) {
										node.row.context.style.display = "table-row";
										// check for children those are visible
										// if not, then hide this node
										ifBranchAndInvisible = checkIfNodesAreVisible(node);
										if (ifBranchAndInvisible && _classList.contains(node.row.context, "collapsed")) {
											node.row.context.style.display = "none";
											return;
										}
									}
								
									// check if a node is branch (suite row) and is collapsed
									// then dont display the children
									if (_classList.contains(node.row.context, "branch")
										&& _classList.contains(node.row.context, "collapsed")
									) {
										return;
									}
									var uncheckedMatch = false;
									for (var j = 0; j < nonSelectedStatusValues.length; j++) {
										if (_classList.contains(node.row.context, nonSelectedStatusValues[j])) {
											uncheckedMatch = true;
											break;
										}
									}
									var intermediateStatusCell = node.row[0].getElementsByClassName("intemediateStatusCell")[0];
									if(intermediateStatusCell){
										intermediateStatuses = intermediateStatusCell.innerHTML;
										if(!shouldShowIntStatsRow(jQuery("#intermediateStatusCombo").combo('getValues'), intermediateStatuses)){
											uncheckedMatch = true;
										}
									}
									
									// hide only if there is a filter and the node is not a branch (suite row)
									if (uncheckedMatch 
										&& node.row.context.getAttribute("rowType") !== "suite") {
										node.row.context.style.display = "none";
									// show a leaf only if it is not collapsed
									} else if (node && !_classList.contains(node.row.context, "collapsed")) {
										node.row.context.style.display = "table-row";
									}
									if (ifBranchAndInvisible) {
										node.row.context.style.display = "none";
									}
									var children = node.children;
									for (var i = 0; i < children.length; i++) {
										processNode(children[i]);
									}
								};
								processNode(rootNode);
							}
							correctSuiteRowPaddings();
						}
						
						function uncheckAllReportRows() {
							var checkboxes = document.querySelectorAll('input[name*="cb"]');
							for (var i = 0; i < checkboxes.length; i++) {
								// remove check related attribs, set indeterminate to false, uncheck
								checkboxes[i].removeAttribute("data-children-checked");
								checkboxes[i].indeterminate = false;
								checkboxes[i].checked = false;
							}
						}
						
						function showHideRows() {
							uncheckAllReportRows();
							expandCollapseAll(true);
							applyFilters2();
						}
						
						function shouldShowIntStatsRow(selectedValues, intermediateStatuses){
							var intermediateStatusesArr = intermediateStatuses.split(",");
							for(var i = 0; i<intermediateStatusesArr.length; i++){
								if(selectedValues.indexOf(intermediateStatusesArr[i].trim()) != -1){
									return true;
								}
							}
							return false;
						}
						
						function deSelectFromPersistData() {
							var selectedValues = jQuery('#statusCombo').combo('getValues');
							for (var i = 0; i < nonSelectedStatusValues.length; i++) {
								var nonSelectedStatus = nonSelectedStatusValues[i];
								var nonSelectedStatusIx = $.inArray(nonSelectedStatus, selectedValues);
								if(nonSelectedStatusIx != -1){
									selectedValues.splice(nonSelectedStatusIx, 1);
								}
							}
							if($.inArray("FAILURE_RETRY", nonSelectedStatusValues) == -1) selectedValues.push("FAILURE_RETRY");
							jQuery('#statusCombo').combobox('setValues', selectedValues);
						}
				
						function expandCollapseAll(expand) {
							if(!$("#scriptSummaries").data().treetable) return;
							if (expand) {
								$("#scriptSummaries").data("treetable").expandAll()
							} else {
								$("#scriptSummaries").data("treetable").collapseAll();
							}
						}
						
						function inArray(ar, el) {
							for (var i=0; i<ar.length; i++) {
								if (ar[i] == el) return true;
							}
							return false;
						}
						
						function closePopUp() {
						   document.getElementById("downloadFileType").style.display = "none";
						   document.querySelector('.download-mask').style.display = "none";
						   document.body.classList.remove('modal-open');
						}
						
						function downloadScriptsArchive(){
							checkedIds = getCheckedScripts();
							if(checkedIds.length < 1){
								alert("Select atleast one file.");
								return;
							}
					        document.getElementById("downloadFileType").style.display = "block";
							document.querySelector(".download-mask").style.display = "block";
							document.body.classList.add('modal-open');
						}
						function downloadScriptsArchiveAs() {
							let fileType = "";

							var options = [...document.getElementsByName("fileType")];
							fileType = options.find(option => option.checked)?.value;

							if(fileType == ""){
								alert("Select file type.");
								return;
							}
							var idFull = checkedIds.join(",");
							var url = "DBReports_downloadScriptsArchive?id=" + encodeURIComponent(idFull) + "&suiteReportId=" + encodeURIComponent(mainSuiteIds.join(",")) + "&suiteIds=" + encodeURIComponent(subSuiteIds.join(",")) + "&type=" + fileType; 
							if(fileType == "artifact") url += "&suffixEnabled=" + suffixEnabled;
							location.href = url;
							document.getElementById("downloadFileType").style.display = "none";
							document.querySelector(".download-mask").style.display = "none";
							document.body.classList.remove('modal-open');
						}
						
						function exportToExcel(){
							var ids = getSuites();
							var compareIds=null; //ids.slice(1).join(',')
							var url = "DBReports_suiteReport?id="+ids[0]+"&compareIds="+compareIds+"&type=excel&download=true";
							location.href = url;
						}
						
						function createCookie(name,value,days){
							if (days) {
								var date = new Date();
								date.setTime(date.getTime()+(days*24*60*60*1000));
								var expires = "; expires="+date.toGMTString();
							}
							else var expires = "";
							document.cookie = name+"="+value+expires+"; path=/";
						}
						
						function onResize(){
							if(!queryStringObject.compareIds) d3.select(".chart").attr("width", document.getElementById("chartContainer").offsetWidth-50);
							else d3.select(".chart").attr("width", document.getElementById("chContainer").offsetWidth-50);
						}
						
						function getLevelMap() {
							var parentMap = {}, levelMap = {}
							var rows = [...document.querySelectorAll('table#scriptSummaries > tbody > tr')];				
							if (rows && rows.length) {
								rows.forEach((row, idx) => {
									if (row.classList.contains("SUCCESS") && row.querySelector('.scriptargs')) {
										row.querySelector(".scriptargs").style.display = 'none';
									}
									var thisId = row.getAttribute("data-tt-id");
									var parentId = row.getAttribute("data-tt-parent-id");
									parentMap[thisId] = parentId;
								})
								
								Object.keys(parentMap).forEach(rowId => {
									var level = 0;
									var parent = parentMap[rowId]
									while(parent != 'null') {
										level++;
										parent = parentMap[parent];
									}
									levelMap[rowId] = level;
								})
							}

							return levelMap;
						}

						function correctSuiteRowPaddings() {
							var pLeft = 19;
							var levelMap = getLevelMap();

							Object.keys(levelMap).forEach(rowId => {
								var row = document.querySelector("tr[data-tt-id='"+ rowId +"']");
								var indenterSpan = row?.querySelector('span.indenter');
								if (indenterSpan) {
									var padding = pLeft * levelMap[rowId] + 7;
									indenterSpan.style.paddingLeft = padding;
								}
							})
						}

						function onLoad(){
							splitStartAndEndTimeColumns();
							formatTimeTakenColumn();

							if(useDBURL == "true"){
								setDownloadReportTypeOption();
								var autoRefreshCheckbox = document.getElementById('auto_refresh');
								if(autoRefreshCheckbox){
							        var cookieValueForAutoReferesh = readCookie("auto_refresh");
							        if(cookieValueForAutoReferesh == "true"){
							        	autoRefreshCheckbox.checked = true;
							        	autoRefreshCheckbox.title = "Disable Auto Refresh";
										enableDisableAutoRefresh(autoRefreshCheckbox);
							        } else{
							        	autoRefreshCheckbox.checked = false;
							        	autoRefreshCheckbox.title = "Enable Auto Refresh";
										enableDisableAutoRefresh(autoRefreshCheckbox);
							        }
						        }
					        }
					        
					        if(!isSuite(suiteName) || mainSuiteCount > 1) {
					        	sortTable();
						        var scriptSummaryTable = document.getElementById("scriptSummaries");
								var suiteRows = scriptSummaryTable.querySelectorAll("[rowtype='suite']");
								for(var i=0; i<suiteRows.length;i++){
									if(!isSuite(suiteRows[i].getElementsByTagName('a')[0].innerHTML)) suiteRows[i].style.display='none';//remove();
								}
							} else {
								$("#scriptSummaries").treetable({expandable: true, onNodeExpand: applyFilters2, onNodeCollapse: function () {} });
								readCookieAndExpandNodes();
								removeSuiteRowIfNoChild();
							}
							if(queryStringObject){
								if(queryStringObject["status"]){
									jQuery('#statusCombo').combobox('setValues', queryStringObject["status"]);
								}
								if(queryStringObject["intermediateStatus"]){
									jQuery('#intermediateStatusCombo').combobox('setValues', queryStringObject["intermediateStatus"]);
								}
							}
							nonSelectedStatusValues.push("FAILURE_RETRY");
							if (nonSelectedStatusValues.length > 0) {
								deSelectFromPersistData();
								applyFilters2(true);
								// expandall nodes
								//expandCollapseAll(true);
							}
							if (useDBURL == "true") showLogoutIfUserLoggedIn();
							else fixPaddingsForOfflineReport();

							if (isSuite(suiteName) && mainSuiteCount<=1) {
								readCookieAndExpandNodes();
							}

							document.addEventListener('keydown', e => {
								if (e.keyCode == 27) {
									closePopUp();
								}
							})

							var colspan = document.querySelector("tr[rowtype='script']").children.length;
							[...document.querySelectorAll('tr[rowtype="suite"] td.last')].forEach(row => {
								row.colSpan = colspan-2;
							})
						}
						
						function sortTable(){
							var rows = $('#scriptSummaries tbody  tr').get();
							rows.sort(function(a, b) {
								//compare script rows by name
								var A = $(a).children('td').eq(0).find('a').text().toUpperCase();
								var B = $(b).children('td').eq(0).find('a').text().toUpperCase();
								
								if(A < B) {
									return -1;
								} else if(A > B) {
									return 1;
								} else {
									//if names are same then, compare script rows by start time
									A = new Date($(a).children('td').eq(10).text()).getTime();
									B = new Date($(b).children('td').eq(10).text()).getTime();
									if(A > B) {
										return -1;
									} else if(A < B) {
										return 1;
									} else {
										return 0;
									}
								}
							});
							$.each(rows, function(index, row) {
								$('#scriptSummaries').children('tbody').append(row);
							});
						}
						
						//function xremoveSuiteRowIfNoChild() {
						//	var scriptSummaryTable = document.getElementById("scriptSummaries");
						//	var suiteRows = scriptSummaryTable.querySelectorAll("[rowtype='suite']");
						//	for(var i=0; i<suiteRows.length;i++){
						//		if(_classList.contains(suiteRows[i], "leaf")) suiteRows[i].remove();
						//	}
					  //	}
						
						function countChildScripts(suiteId,count)
						 {   var countScript=count;
							 var scriptSummaryTable = document.getElementById("scriptSummaries");
							 var childSuiteRows=scriptSummaryTable.querySelectorAll("[data-tt-parent-id='"+suiteId+"'][rowtype='suite']");
							 var childRows=scriptSummaryTable.querySelectorAll("[data-tt-parent-id='"+suiteId+"'][rowtype='script']");
							 countScript+=childRows.length;
							 for(var k=0; k<childSuiteRows.length;k++){
							   	    var innerSuiteId=childSuiteRows[k].getAttribute("data-tt-id");
							 		return countChildScripts(innerSuiteId,countScript);
								}
							return countScript;
						}
						
						
						function removeSuiteRowIfNoChild() {
							var scriptSummaryTable = document.getElementById("scriptSummaries");
							var suiteRows = scriptSummaryTable.querySelectorAll("[rowtype='suite']");
							for(var i=suiteRows.length-1; i>=0;i--){
							    var count=0;
								if(_classList.contains(suiteRows[i], "leaf")) suiteRows[i].parentNode.removeChild(suiteRows[i]);
								var suiteId=suiteRows[i].getAttribute("data-tt-id");
							
								var count=countChildScripts(suiteId,0);
								if(count==0 && suiteRows[i].parentNode) suiteRows[i].parentNode.removeChild(suiteRows[i]);
							}
					  }
						

				
						function setDownloadReportTypeOption() {
							var reportTypes = getR_info();
							reportTypes.push('artifact');
						    var x = document.querySelector("#downloadFileType .download-options");
							x.innerHTML = "";
						    for(i=0; i<reportTypes.length; i++){
							    if(reportTypes[i]!="sample"){
							    	var div = document.createElement("div");
								    div.innerHTML = '<div class="popUpContainer">' + 
										'<label for="' + reportTypes[i] + '"><span class="flex-row">' +
											reportTypes[i] +
											'<input type="radio" name="fileType" id="' + reportTypes[i] + '" value="' + reportTypes[i] + '"/>' +
										'</span></label>'
									'</div>';
									x.appendChild(div);
								}
						    }
						}
						
						function getR_info(){
							var	getReports_info = eval("(" + sahiSendToServer("/_s_/dyn/pro/DBReports_getAllReportsTypes") + ")");
						  	return getReports_info;
						}
						
						function onUnload(){
							var count = 0;
							var firstElement;
							for(firstElement in cookieHashMap){
								break;
							}
							for(var j in cookieHashMap){
								count++;
							}
							if(count == 10){
								delete cookieHashMap[firstElement];
							}
							cookieHashMap[suiteReportID] = getArrayJson(nonSelectedStatusValues);
							var cookieValue = getJSON(cookieHashMap);
							createCookie("nonSelectedStatuses", cookieValue, 1);
							
							var expandedRows = document.getElementsByClassName('expanded branch');
							var expandedNodes = [];
							for(var i=0; i<expandedRows.length; i++) {
								var dataId = expandedRows[i].getAttribute("data-tt-id");
								expandedNodes.push(dataId);
							}
							nodeHashMap[suiteReportID] = expandedNodes;
							createCookie("expandedNodes", JSON.stringify(nodeHashMap), 1);
						}
						
						function getArrayJson(arr) {
							var strbuf = [];
							strbuf.push("[");
							strbuf.push(" ");
							for (var i = 0; i < arr.length; i++) {
								strbuf.push(' "');
								strbuf.push(arr[i]);
								strbuf.push('"');
								strbuf.push(',');
							}
							strbuf.pop();
							strbuf.push("]");
							return strbuf.join('');
						}
						
						function getJSON(o) {
							var s = "{";
							for (var i in o) {
								s += "'" + i + "':" + (Object.prototype.toString.call(o[i]).indexOf("Array") != -1 ? getArrayJson(o[i]) : o[i]) + ","
							}
							s = s.substring(0, s.length-1) + "}";
							return s;
						}
						
						function isAllCurrentCheckboxChecked(){
							var els = document.getElementsByTagName("INPUT");
							for (var i=0; i<els.length; i++) {
								var el = els[i];
								if (el.type == "checkbox") {
									if(el.parentNode.parentNode.style.display != "none" && !el.checked){
										return false;
									}
								}
							}
							return true;
						}
						
						function getCheckedLogs(){
							var scriptSummaryTable = document.getElementById("scriptSummaries");
							var els = scriptSummaryTable.getElementsByTagName("input");
							var ids=[];
							for(var i = 0; i<els.length; i++){
								if(els[i].type == "checkbox" && els[i].checked && els[i].getAttribute('checkboxtype') == 'script') ids.push(els[i].value);
							}
							return ids;
						}
						
						function changeGraph(value){
			     	 		 $("#chContainer").empty();
			     	 		 renderCompareChart("chContainer", value);
						}
				
						function readCookieAndExpandNodes() {
							var scriptargs = document.getElementsByClassName('scriptargs');
							if (scriptargs && scriptargs.length > 0) {
								//scriptargs[0].style.display = 'none';
							}

							var parentMap = {}, levelMap = {}
							var rows = [...document.querySelectorAll('table#scriptSummaries > tbody > tr')];				
							if (rows && rows.length) {
								rows.forEach((row, idx) => {
									if (row.classList.contains("SUCCESS") && row.querySelector('.scriptargs')) {
										row.querySelector(".scriptargs").style.display = 'none';
									}
									var thisId = row.getAttribute("data-tt-id");
									var parentId = row.getAttribute("data-tt-parent-id");
									parentMap[thisId] = parentId;
								})
								
								Object.keys(parentMap).forEach(rowId => {
									var level = 0;
									var parent = parentMap[rowId]
									while(parent != 'null') {
										level++;
										parent = parentMap[parent];
									}
									levelMap[rowId] = level;
								})
							}

							Object.keys(levelMap).forEach(rowId => {
								var pLeft = 19;
								var row = document.querySelector("tr[data-tt-id='" + rowId + "']");
								if (row) {
									if(row.getAttribute('rowtype') == 'script') {
										var indenterSpan = row.querySelector('td.script-name-cell > span.indenter');
										if (indenterSpan) {
											indenterSpan.style.display = 'none';
										}

										var nameSpan = row.querySelector('td.script-name-cell > span.flex-row');
										var padding = 0;
										if (useDBURL == 'true') {
											padding = 54;
											padding = `${padding + ((levelMap[rowId] - 1) * pLeft)}px`;
										}
										else {
											nameSpan = row.querySelector('td.script-name-cell > span.flex-column');
											padding = 45;
											padding = `${padding + ((levelMap[rowId] - 1) * pLeft)}px`;
										}
										
										if (nameSpan) {
											nameSpan.style.setProperty('padding-left', padding, 'important');
										}

										var scriptArgs = row.querySelector('td.script-name-cell > .scriptargs');
										if (scriptArgs) {
											if (useDBURL == 'true') padding = 78;
											else padding = 25;
											padding = `${((levelMap[rowId] - 1) * pLeft) + padding}px`;
											scriptArgs.style.setProperty('padding-left', padding, 'important');
										}
									}

									else if (row.getAttribute('rowtype') == 'suite') {
										var indenterSpan = row.querySelector('span.indenter');
										if (indenterSpan) {
											padding = levelMap[rowId]*pLeft + 7;
											indenterSpan.style.paddingLeft = padding; 
											if (useDBURL != "true") {
												//var margin = levelMap[rowId] * (11-pLeft);
												//indenterSpan.style.marginLeft = margin + 'px';

												var margin = (11-pLeft);
												indenterSpan.style.marginLeft = margin + 'px';
											}
										}
									}
								}
							})
							
							$("#scriptSummaries").data("treetable").collapseAll();
							var cookieValue = readCookie("expandedNodes");
							if(cookieValue){
								nodeHashMap = eval("("+cookieValue+")");
								var expandedNodes = nodeHashMap[suiteReportID];
								if (expandedNodes != undefined && expandedNodes.length > 0){
									for(var i=0; i<expandedNodes.length; i++) {
										$("#scriptSummaries").treetable("expandNode", expandedNodes[i]);
									}
									expandedNodesForFilter = nodeHashMap[suiteReportID];
									delete nodeHashMap[suiteReportID];
								} else {
									$("#scriptSummaries").treetable("expandNode", suiteReportID);
								}
							} else {
								$("#scriptSummaries").treetable("expandNode", suiteReportID);
							}
						}
			
						var linkSuiteReports = document.getElementById("linksuitereports");
						if(linkSuiteReports != null){
							linkSuiteReports.addEventListener("click",function(evt) {
								if(evt.target.baseURI!=null && evt.target.baseURI.search("/retry/")>-1) {
									evt.target.href="../index.html"
									return false;
								}
							});
						}
								
						var linkShowRetryLogs = document.getElementById("linkshowretrylogs");
						if(linkShowRetryLogs != null){
							linkShowRetryLogs.addEventListener("click",function(evt) {
								if(evt.target.baseURI!=null && evt.target.baseURI.search("/retry/")>-1) {
									evt.target.href="index.html"
									return false;
								}
							});
						}
						]]>
					</script>
				</table>
				</div>
			
				<span id="go-to-top" title="Scroll to Top"></span>
				<script><![CDATA[
					document.addEventListener('scroll', () => {
						const rootElement = document.body;
						const goToTopBtn = document.getElementById('go-to-top');
						let scrollTotal = rootElement.scrollHeight - rootElement.clientHeight;
						let scrollPct = rootElement.scrollTop/scrollTotal;
						if(document.body.scrollTop < 1.5*rootElement.clientHeight) {
							goToTopBtn.style.display = 'none';
						} else {
							goToTopBtn.style.display = 'inline-block';
						}
					});
			
					document.querySelector('#go-to-top')
						.addEventListener('click', () => {
							var rootElement = document.body;
							rootElement.scrollTo({
								top: 0,
								behavior: "smooth"
							})
						});
				]]></script>
			</body>
		</html>
	</xsl:template>

	<xsl:template match="suite">
		<xsl:param name="suiteId" select="suiteSummary/SUITEREPORTID" />
		<xsl:param name="suiteName" select="suiteSummary/SUITENAME" />
		<xsl:param name="suiteInfo" select="suiteSummary/SUITEINFO" />
		<xsl:param name="parentSuiteId" select="suiteSummary/PARENTSUITEID" />
		<xsl:param name="className" select="suiteSummary/SUITESTATUS" />
		
		<tr data-tt-id="{$suiteId}" class="{$className}" data-tt-parent-id="{$parentSuiteId}" rowtype="suite" style="background:white">
			<xsl:attribute name="style">
				<xsl:choose>
					<xsl:when test="$mainSuiteCount > 1">
						<xsl:text>display: none;</xsl:text>
					</xsl:when>
				</xsl:choose>
			</xsl:attribute>
			<td id="{$suiteId}">
				<xsl:choose>
					<xsl:when test="$useDBURL = 'true'">
						<span class="flex-row" style="display: inline-flex; gap: 10px; padding-left: 0.25em;">
							<input name="cbs" checkboxtype="suite" type="checkbox" value="{$suiteId}" onclick="onCheckClick(this)"/>
							<a class="no-link" style="color:#092572;font-weight:600;padding-left:5px;" title="{$suiteInfo}"><xsl:value-of select="$suiteName" /></a>
							
						</span>
					</xsl:when>
					<xsl:otherwise>
						<span class='flex-row' style="display: inline-flex; gap: 10px; padding-left: 0.25em;vertical-align: super;">
							<a class="no-link" style="color:#092572;font-weight:600; vertical-align: middle;" title="{$suiteInfo}"><xsl:value-of select="$suiteName" /></a>
							<!-- <span class='flex-row status-icon {$className}' style="margin-left: 100px;">
								<xsl:value-of select="translate($className, $uppercase, $lowercase)" />
							</span> -->
						</span>
					</xsl:otherwise>
				</xsl:choose>
			</td>
			<td class='status' style="margin: auto; text-align: left;">
				<span class='flex-row status-icon {$className}' style="margin:0;">
					<xsl:value-of select="translate($className, $uppercase, $lowercase)" />
				</span>
			</td>
			<td colspan="14" class="last"></td>
		</tr>
		<xsl:apply-templates select="scriptSummaries/summary" >
			<!-- Uncomment below line to sort by script name (ordered as in suite file) -->
			<!-- <xsl:sort select="SCRIPTNAME" /> -->
		</xsl:apply-templates>
		<xsl:apply-templates select="suite" />
	</xsl:template>


	<xsl:template match="scriptSummaries/summary">
		<xsl:param name="scriptId" select="SCRIPTREPORTID" />
		<xsl:param name="pId" select="SUITEID" />
		<xsl:param name="className" select="scriptstatus|SCRIPTSTATUS" />
		<xsl:param name="steps" select="steps|TOTALSTEPS" />
		<xsl:param name="failures" select="failures|FAILURES" />
		<xsl:param name="errors" select="errors|ERRORS" />
		<xsl:param name="tccount" select="TCCOUNT" />
		<xsl:param name="tcpassed" select="TCPASSED" />
		<xsl:param name="tcfailed" select="TCFAILED" />
		<xsl:param name="load" select="loadcount|LOADCOUNT" />
		<xsl:param name="scriptstatus" select="scriptstatus|SCRIPTSTATUS" />
		<xsl:param name="suiteId" select="suiteReportId|SUITEREPORTID" />
		<xsl:param name="suiteInfo" select="suiteinfo|SUITEINFO"/>
		<xsl:param name="suitename" select="suitename|SUITENAME"/>
		<xsl:param name="parentsuiteid" select="suiteid|SUITEID"/>
		<xsl:param name="starturl" select="starturl|STARTURL"/>
		<xsl:param name="scriptargs" select="scriptargs|SCRIPTARGS"/>
		<xsl:param name="screenShot" select="SCREENSHOT" />
		<xsl:param name="artifact" select="ARTIFACT" />
		<xsl:param name="output" select="OUTPUT" />
		<xsl:param name="launcherId" select="launcherId|LAUNCHERID" />
		<xsl:param name="position" select="util:position()" />
		
		<xsl:variable name="parentSuiteId">
			<xsl:choose>
				<xsl:when test="not(SUITEID)"><xsl:value-of select="$suiteId" /></xsl:when>
	 			<xsl:otherwise><xsl:value-of select="$pId" /></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="args">
			<xsl:choose>
				<xsl:when test="$scriptargs != '' and $scriptargs != 'null'"><xsl:value-of select="$scriptargs" /></xsl:when>
	 			<xsl:otherwise></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<script>
		var suffixEnabled = <xsl:value-of select="util:artifactSuffixEnabled()" />;
		</script>

		<tr id='status-{$position}' class="{$className}" data-status="{$className}" data-tt-id="{$scriptId}" data-tt-parent-id="{$parentSuiteId}" rowtype="script" launcherId="{$launcherId}">
			<td id="{$suiteId}" class="script-name-cell" style="white-space: nowrap;">
				<xsl:choose>
					<xsl:when test="$useDBURL = 'true'">
						<span class="flex-row" style="display: inline-flex; gap: 5px;">
							<input name="cb_{$position}" checkboxtype="script" type="checkbox" value="{$scriptId}" onclick="onCheckClick(this)"/>
							<span class='flex-column' style='align-items: flex-start; padding-left: 10px;'>
								<a id="script-{$position}" style="font-weight: 600; color: #092572;" title="{$args}" class="SCRIPT" href="/_s_/dyn/pro/DBReports_scriptReport?id={$scriptId}">
									<xsl:attribute name="title">
										<xsl:value-of select="scriptName|SCRIPTNAME" />
									</xsl:attribute>
									<xsl:text>
										<xsl:value-of select="scriptName|SCRIPTNAME" />
									</xsl:text>
								</a>
								<div id="starturl-{$position}" class='starturl' style="max-width:30ch;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;color:#000;padding-bottom: 1px;" title="Start URL: {$starturl}">
									<xsl:value-of select="$starturl" />
								</div>
							</span>
						</span>
					</xsl:when>
					<xsl:otherwise>
						<span class='flex-column' style='align-items: flex-start; padding-left: 10px;'>
							<a id="script-{$position}" style="font-weight: 600; color: #092572;" class="SCRIPT" href="{$scriptId}.html">
								<xsl:attribute name="title">
									<xsl:value-of select="scriptName|SCRIPTNAME" />
								</xsl:attribute>
								<xsl:text>
									<xsl:value-of select="scriptName|SCRIPTNAME" />
								</xsl:text>
							</a>
							<div id="starturl-{$position}" class='starturl' style="width:30ch;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;" title="{$starturl}">
								<xsl:value-of select="$starturl" />
							</div>
						</span>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:if test="$scriptargs != '' and $scriptargs != 'null'">
					<div class="scriptargs"><pre style="color:gray;margin-left:20px"><xsl:value-of select="scriptargs|SCRIPTARGS" /></pre></div>
				</xsl:if>
			</td>
			<td style="text-align: left;">
				<span class="flex-row status-icon {$className}" style="margin: 0;">
					<xsl:value-of select="translate(scriptstatus|SCRIPTSTATUS, $uppercase, $lowercase)" />
			  </span>
			  <span style="display: none;" class="$className">
				<xsl:value-of select="$className" />
			  </span>
			</td>
			<td id="failures-{$position}" class="failures-count right-align">
				<span>
					<xsl:if test="failures|FAILURES != 'null'">
						<xsl:value-of select="failures|FAILURES" />
					</xsl:if>
					<xsl:if test="failures|FAILURES = 'null'">
						0
					</xsl:if>
				</span>
			</td>
			<td id="errors-{$position}" class="errors-count right-align">
				<span>
					<xsl:if test="errors|ERRORS != 'null'">
						<xsl:value-of select="errors|ERRORS" />
					</xsl:if>
					<xsl:if test="errors|ERRORS = 'null'">
						0
					</xsl:if>
				</span>
			</td>
			<td class="success-pct right-align">
				<span>
					<xsl:choose>
						<xsl:when test="$steps &gt; 0">
							<xsl:value-of
								select="round(($steps - $failures - $errors) div $steps * 100)" />
							%
						</xsl:when>
						<xsl:when test="$steps = 'null'">
							0%
						</xsl:when>
						<xsl:otherwise>
							0%
						</xsl:otherwise>
					</xsl:choose>
				</span>
			</td>					
			<td id="totalsteps-{$position}" class="total-count right-align">
				<span>
					<xsl:if test="steps|TOTALSTEPS != 'null'">
						<xsl:value-of select="steps|TOTALSTEPS" />
					</xsl:if>
					<xsl:if test="steps|TOTALSTEPS = 'null'">
						0
					</xsl:if>
				</span>
			</td>
			<td id="tcfail-{$position}" class="tc-failures-count right-align">
				<span>
					<xsl:if test="TCFAILED != 'null'">
						<xsl:value-of select="TCFAILED" />
					</xsl:if>
					<xsl:if test="TCFAILED = 'null'">
						0
					</xsl:if>
				</span>
			</td>
			<td id="tcpass-{$position}" class="tc-passed-count right-align">
				<span>
					<xsl:if test="TCPASSED != 'null'">
						<xsl:value-of select="TCPASSED" />
					</xsl:if>
					<xsl:if test="TCPASSED = 'null'">
						0
					</xsl:if>
				</span>
			</td>
			<td class="tc-success-pct right-align">
				<span>
					<xsl:choose>
						<xsl:when test="$tccount &gt; 0">
							<xsl:value-of
								select="round(($tcpassed) div $tccount * 100)" />
							%
						</xsl:when>
						<xsl:when test="$tccount = 'null'">	
							0%
						</xsl:when>
						<xsl:otherwise>
							0%
						</xsl:otherwise>
					</xsl:choose>
				</span>
			</td>
			<td id="tccount-{$position}" class="tc-total-count right-align">
				<span>
					<xsl:if test="TCCOUNT != 'null'">
						<xsl:value-of select="TCCOUNT" />
					</xsl:if>
					<xsl:if test="TCCOUNT = 'null'">
						0
					</xsl:if>
				</span>
			</td>
			<td class="intemediateStatusCell">
				<xsl:param name="intermediateStatus" select="scriptintermediatestatuses|SCRIPTINTERMEDIATESTATUSES" />
				<xsl:choose>
					<xsl:when test="$intermediateStatus != '' and $intermediateStatus != 'null'">
		           		<xsl:value-of select="scriptintermediatestatuses|SCRIPTINTERMEDIATESTATUSES" />
		       		</xsl:when>
		        	<xsl:otherwise>NA</xsl:otherwise>
		        </xsl:choose>
			</td>
			<td id="StartTime" class="date-time" style="white-space:nowrap">
				<xsl:choose>
					<xsl:when test="STARTTIME != 'null'">
						<xsl:attribute name="data-text">
							<xsl:value-of select="util:humanTime(STARTTIME)" />
						</xsl:attribute>
					</xsl:when>
				</xsl:choose>
			</td>			
			<td style="white-space:nowrap" class="right-align">
				<xsl:if test="timeTaken|TIMETAKEN != 'null'">
					<span class='time-taken'>	
						<xsl:attribute name="data-text">
							<xsl:value-of select="util:prettyTimeMoreThan24Hours(timeTaken|TIMETAKEN)" />
						</xsl:attribute>
					</span>
					<span style="display:none" id="timetaken-{$position}"><xsl:value-of select="timeTaken|TIMETAKEN" /></span>
				</xsl:if>
			</td>
			<td class="right-align">
				<xsl:value-of select="loadcount|LOADCOUNT" />
			</td>
			<td>
				<xsl:if test="NODEHOST != 'null' and NODEHOST != ''">
					<xsl:value-of select="nodeHost|NODEHOST" />:<xsl:value-of select="nodePort|NODEPORT" />
				</xsl:if>
			</td>
			<!--Retrieve custom field value-->
			<!-- <td class='custom-row'>
				<xsl:if test="$suiteInfo != 'null'">
					<pre><xsl:value-of select="util:fetchInfo($suiteInfo, 'customField')" /></pre>
				</xsl:if>
			</td> -->
		</tr>
	</xsl:template>
</xsl:stylesheet>