<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:util="in.co.sahi.util.XSLUtils"
	version="1.0">
	<xsl:output method="html" indent="yes" />
	<xsl:param name="useDBURL" select="false" />
	<xsl:param name="inlineJS" select="false" />

	<xsl:variable name="lowercase" select='"abcdefghijklmnopqrstuvwxyz "' />
	<xsl:variable name="uppercase" select='"ABCDEFGHIJKLMNOPQRSTUVWXYZ_"' />

	<xsl:template match="suites">
		<html>
			<head>
				<meta http-equiv="content-type" content="text/html; charset=UTF-8" />

				<xsl:value-of select="document('jquery.treetable.dependency')" disable-output-escaping="yes" />
				<xsl:choose>
					<xsl:when test="$useDBURL = 'true'">
						<link rel="shortcut icon" href="/_s_/spr/images/favicon.ico" type="image/png"/>
						<script type="text/javascript" src="/_s_/spr/util.js"></script>
						<script type="text/javascript" src="/_s_/spr/login/logout.js"></script>
						<script type="text/javascript" src="/_s_/spr/ext/easyui/jquery.easyui.min.js"></script>
						<script type="text/javascript" src="/_s_/spr/classlist_wrapper.js"></script>
						
						<script type="text/javascript"> 
						   $(window).load(function () {
						      if(sahiIsIE()){
						         let bannerId = document.getElementById('banner');
						         bannerId.style.display = 'inline-flex';
						      }
						   });
						</script>
						<link rel="stylesheet" type="text/css" href="/_s_/spr/ext/easyui/themes/gray/easyui.css" />
						<link rel="stylesheet" type="text/css" href="/_s_/spr/css/reports_styles.css" />
						
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="not($inlineJS = 'true')">
							<script src="common.js"></script>
						</xsl:if>
						<link href="common.css" rel="stylesheet" type="text/css" />
						<link href="styles.css" rel="stylesheet" type="text/css" />
					</xsl:otherwise>
				</xsl:choose>
				<xsl:if test="$inlineJS='true'">
					<xsl:value-of select="document('classlist_wrapper.js.dependency')" disable-output-escaping="yes" />
					<xsl:value-of select="document('easyui.min.js.dependency')" disable-output-escaping="yes" />
				</xsl:if>

				<style><![CDATA[
					.flex-row {
						display: flex;
						flex-direction: row;
						gap: 10px;
						align-items: center;
					}

					.flex-column {
						display: flex;
						flex-direction: column;
						gap: 10px;
						align-items: center;
					}

					body{
						display:table;
						min-width: 100%;
						width: max-content;
					}

					h1.title {
						font-family: Arial, Helvetica, sans-serif;
						line-height: 24px;
						font-size: 20px;
						color: #253F89;
					}

					.suite-summary {
						width: max(30vw, 600px);
						min-width: 450px;
						max-width: max(30vw, 600px);
						border: 0.5px solid #ccc;
						border-radius: 10px;
						padding: 10px;
					}

					.suite-name {
						justify-content: space-between;
						padding-top: 10px;
						padding-left: 5px;
						padding-right: 20px;

						font-size: 16px;
						line-height: 20px;
					}

					.suite-name > span > span {
						opacity: 0.7;
						font-weight: bold;
						padding-right: 10px;
						font-size: 16px;
						white-space: nowrap;
					}

					.suite-name a {
						opacity: 1;
						font-weight: bold;
						color: #000;
						font-size: 16px;

						max-width: 300px;
						overflow-wrap: break-word;
						display: inline-block;
					}

					.suite-details {
						margin-top: 25px;
						align-items: stretch;
						gap: 30px;
					}

					.suite-detail-group {
						align-self: flex-start;
						padding: 5px 10px 10px 10px;

						display: flex;
						flex-direction: row;
						width: 100%;
					}

					.suite-details-right .suite-detail-group{
						gap: 5px;
					}

					.suite-details-right-title {
						margin-left: 15%;
					}

					.suite-details-right-title h2 {
						font-size: 16px;
					}

					.suite-info {
						margin-top: 20px;
						margin-bottom: 10px;
					}

					.nodes-info {
						margin-bottom: 35px;
					}
					
					.suite-info a,
					.nodes-info a {
						color: blue;
					}

					.suite-detail-group {
						font-size: 16px;
						line-height: 19px;
					}

					.suite-detail-item-title {
						font-weight: bold;
						opacity: 0.7;
						flex-basis: 80%;
					}

					.suite-details-left .suite-detail-item-title {
						flex-basis: 60%;
					}

					.suite-detail-item-value {
						flex-basis: 100%;
						font-weight: 600;
					}

					.suite-details-right > .suite-detail-group {
						margin-left: 20px;
					}

					.suite-details-right > .suite-detail-group:last-child {
						align-items: center;
					}

					.suite-details-right > .suite-detail-group:last-child > .suite-detail-item-title {
						flex-basis: 0;
					}

					.suite-detail-item-value,
					.suite-detail-item-title {
						font-size: 14px !important;
					}

					.suite-details-right .suite-detail-item-value > span:last-child:not(.status-icon) {
						font-size: 12px;
						padding-left: 8px
					}

					.suite-details-right .suite-detail-item-value > span:first-child:not(.status-icon) {
						display: inline-block;
						width: 3ch;
						text-align: right;
						font-size: 14px;
					}

					.suite-details-left, 
					.suite-details-right {
						flex-basis: 100%;
					}

					.date-time span, 
					.time-taken {
						font-size: 14px;
						font-weight: normal;
						align-items: flex-start;
					}

					.suite-summary .date-time span,
					.suite-summary .time-taken {
						font-weight: bold;
					}

					.date-time > span >span:last-child {
						font-size: 12px;
						font-weight: 500;
						color: #4E4E4E;
					}

					#suiteInfo {
						padding: 10px;
						border: 1px solid black;
						border-radius: 10px;
						background-color: white;
						width: fit-content;
					}

					#suiteInfo, 
					#nodesInfo {
						margin-top: 20px;
						margin-left: 30px;
					}

					#suiteInfoLink, 
					#nodesInfoLink {
						color: #000;
						text-decoration: none;

						font-size: 15px;
						line-height: 19px;
						font-weight: bold; 
						gap: 0;
						display: inline-flex;
					}

					#suiteInfoLink::before,
					#nodesInfoLink::before {
						content: '';
						display: inline-block;

						height: 20px;
						width: 20px;

						margin-right: 10px;
						transform: rotate(-90deg);
						transition: transform 200ms ease-in-out;
					}

					#suiteInfoLink.expanded::before,
					#nodesInfoLink.expanded::before {
						transform: rotate(0deg);
						transition: transform 200ms ease-in-out;
					}

					.logo-header {
						position: fixed;
						left: 0;
						top: 0;
						z-index: 2;
						height: 50px;
						background-color: #253F89;
					}

					#sahi-logo {
						display: inline-block;
						width: 110px;
						height: 50px;
						margin: 0;
						padding: 0;
					}

					table, th, td {
						border: none;
						border-spacing: 0;
						border-collapse: collapse;
					}

					.table-header {
						width: 100%;
					}

					.table-header th {
						background-color: #E2EAFF !important;
						border: 0.5px solid #ccc !important;
						
						color: #000 !important;
						font-family: Arial, Helvetica, sans-serif;
						font-weight: bold !important;

						padding: 11px 15px 11px 10px !important;

						text-align: center !important; 
						white-space: nowrap !important;
					}

					/* use this class on table data rows only */
					.table-data td {
						border: 0.5px solid #ccc !important;
						color: #000 !important;
						font-family: Arial, Helvetica, sans-serif;

						padding: 11px 15px 11px 10px !important;
						min-width: 100px !important;

						text-align: left !important;
					}

					.table-data td.script-name-cell {
						text-align: left !important;
					}

					.table-data td:nth-child(n+2) {
						text-align: left !important;
					}

					.table-data td.right-align {
						text-align: right !important;
					}

					.intermediateStatusCell {
						font-weight: bold;
					}

					.status-icon {
						border: 1.5px solid black;
						border-radius: 15px;

						font-weight: bold;
						padding: 8px 12px !important;
						width: fit-content;

						margin: auto;
						text-transform: capitalize;
					}

					.status-icon::before {
						content: '';
						display: inline-block;

						width: 16px;
						height: 16px;

						background-size: contain;
						background-repeat: no-repeat;

					}

					table a {
						text-decoration: none !important;
						color: #092572 !important;
						font-weight: bold !important;
					}

					a{text-decoration:none;color:black;}
					a.INFO{color:black}
					a.START,a.STOP{color:black;font-weight:bold;}
					div.INFO{background-color:white !important;}
					div.SUCCESS{background-color:green !important;color:white !important;}
					div.FAILURE,div.ERROR{background-color:red !important;color:white !important;}
					a.CUSTOM,
					a.CUSTOM2, a.CUSTOM4{color:black}
					div.CUSTOM{background-color:yellow;}
					div.CUSTOM1{background-color:orange;}
					div.CUSTOM2{background-color:#EFEFEF;}
					div.CUSTOM3{background-color:green;}
					div.CUSTOM4{background-color:violet;}
					div.CUSTOM5{background-color:indigo;}
					a.SCRIPT{text-decoration:underline;}
					span.extra{color:#CCC;}
					div.SKIPPED{background-color:#eed;}
					a.SKIPPED{color:gray;}

					table.suite_summary {border:1px solid orange; margin-bottom:30px;background-color:#fff;}
					table.suite_summary td {vertical-align:top;padding:3px;text-align:left;}
					table.suite_summary_part {border:0px;}
					table.suite_summary_part *{border:0px;spacing:0px;}
					
					body *{font-family: Arial, Helvetica, sans-serif;font-size:10pt;}
					body {margin:0; background-color:white;}

					#navbar a:not(.nav-sahi-logo) {
						color: #D3D3D3;
						text-decoration: none;
						font-size: 14px;
						white-space: nowrap;
						font-weight: 700;
					}
					#navbar a.selected {
						font-weight: 700;
						background-color: white;
						padding: 13px 25px 0 25px;
						border-bottom: none;
						margin-bottom: -1px;
						height: 65%;
						color: #253F89;
						border-radius: 5px 5px 0px 0px;
					}
					#navbar > div:last-child {
						gap: 10px;
					}
					#navbar{
						position: sticky;
						left: 0;

						height:50px;
						width: 100%;
						min-width: 1200px;
						max-width: 98.5vw;
						
						margin-left: 0;
						padding: 0;

						gap: 20px;
						align-items: flex-end;
						justify-content: space-between;
					}

					#navbar > .left-nav {
						padding: 0 0 0 35px;
						gap: 10px;
						height: 100%;
						align-items: flex-end;
					}

					#navbar > .right-nav {
						margin-right: 10px;
						align-self: center;
					}

					.navbar-container {
						position: sticky;
						top: 0px;
						z-index: 2;

						margin: 0;
						padding: 0;
						width: 100%;
						min-width: 100vw;

						background-color: #253F89;
					}

					.container {
						padding-left: 60px;
						padding-right: 20px;
						margin-top: 25px;
					}

					.table-header .flex-column {
						gap: 2px;
					}

					table.treetable tr.branch {
						background-color: white !important;
					}

					span.indenter {
						margin-right: 8px !important;
						margin-left: 2px !important;
					}

					span.indenter:empty {
						padding: 0 !important;
						margin: 0 !important;
						display: none !important;
					}

					table.treetable tr span.indenter a {
						background-image: url("data:image/svg+xml,%3Csvg width='20' height='20' viewBox='0 0 20 20' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath d='M15.5916 6.84167C15.5141 6.76356 15.4219 6.70156 15.3204 6.65926C15.2188 6.61695 15.1099 6.59517 14.9999 6.59517C14.8899 6.59517 14.781 6.61695 14.6794 6.65926C14.5779 6.70156 14.4857 6.76356 14.4082 6.84167L10.5916 10.6583C10.5141 10.7364 10.4219 10.7984 10.3204 10.8407C10.2188 10.883 10.1099 10.9048 9.99989 10.9048C9.88988 10.9048 9.78096 10.883 9.67941 10.8407C9.57786 10.7984 9.48569 10.7364 9.40822 10.6583L5.59155 6.84167C5.51409 6.76356 5.42192 6.70156 5.32037 6.65926C5.21882 6.61695 5.1099 6.59517 4.99989 6.59517C4.88988 6.59517 4.78096 6.61695 4.67941 6.65926C4.57786 6.70156 4.48569 6.76356 4.40822 6.84167C4.25301 6.9978 4.16589 7.20901 4.16589 7.42917C4.16589 7.64932 4.25301 7.86053 4.40822 8.01666L8.23322 11.8417C8.70197 12.3098 9.33739 12.5728 9.99989 12.5728C10.6624 12.5728 11.2978 12.3098 11.7666 11.8417L15.5916 8.01666C15.7468 7.86053 15.8339 7.64932 15.8339 7.42917C15.8339 7.20901 15.7468 6.9978 15.5916 6.84167V6.84167Z' fill='%23374957'/%3E%3C/svg%3E") !important;
						background-size: contain;
						background-repeat: no-repeat;

						transform: rotate(0deg);
						transition: transform 300ms ease-in;
						width: 18px !important;
						height: 18px
					}

					table.treetable tr.collapsed span.indenter a {
						transform: rotate(-90deg);
					}

					.table-buttons {
						margin-bottom: 15px;
						margin-left: 10px;
					}

					.testcase-info {
						margin-right: 40px;
						font-weight: 600;
						font-size: 14px;
						color: black;
						font-size: 18px;
						font-weight: 700;
					}

					.table-buttons a {
						cursor: pointer;
						color: #4e4e4e;
						padding-right: 20px;
						font-weight: bold;
					}
					
					/* #tcSummariesHeader span, #tcSummariesHeader a{
						height: 15px !important;
						padding: 0.5px !important;
					} */

					.input-group {
						padding: 10px 10px;
						border: 1px solid #ccc;
						border-radius: 10px;
						width: fit-content;
						font-weight: normal;
						color: #4e4e4e;
					}

					.input-group, 
					.input-group * {
						cursor: pointer;
					}

					#showFailedCheckbox {
						display: inline-block;
					}

					.input-group input[type="checkbox"],
					.auto-refresh input[type="checkbox"] {
						appearance: none;

						background-color: #fff;
						margin: 0;

						font: inherit;
						color: white;
						width: 18px;
						height: 18px;
						border: 2px solid #46474aa3;
						border-radius: 3px;

						display: grid;
						place-content: center;
					}

					.input-group input[type="checkbox"]::before,
					.auto-refresh input[type="checkbox"]::before {
						content: '';
						display: inline-block;
						width: 16px;
						height: 15px;
						box-shadow: inset 14px 14px #fff;

						transform: scale(0);
						transition: transform 120ms ease-in-out;
						transform-origin: bottom left;
						clip-path: polygon(13% 45%, 37% 65%, 83% 1%, 99% 14%, 39% 98%, 0 64%);
					}

					.input-group input[type="checkbox"]:checked,
					.auto-refresh input[type="checkbox"]:checked {
						background-color: #092572;
					}

					.input-group input[type="checkbox"]:checked::before,
					.auto-refresh input[type="checkbox"]:checked::before {
						/* background-color: #092572; */
						transform: scale(1);
					}

					.input-group:has(input[type="checkbox"]:checked) label {
						color: #092572;
					}

					.input-group:has(input[type="checkbox"]:checked) {
						border-color: #092572;
					}

					.icon-group {
						padding: 10px;
						border: 1px solid #4e4e4e;
						border-radius: 15px;
						color: #4e4e4e;
					}

					.icon-group::before {
						content: '';
						display: inline-block;

						width: 16px;
						height: 16px;
						
						background-image: url('/_s_/spr/images/fi-sr-refresh.svg');
						background-size: contain;
						background-repeat: no-repeat;
					}

					.icon-group input[type="checkbox"] {
						display: none;
					}

					.textbox.combo {
						padding-left: 0;
						padding-top: 0;
						border-radius: 1px;
					}

					.combo .textbox-addon {
						display: flex;
						flex-direction: column;
						justify-content: center;
						height: 100%;
					}

					.combo .textbox-addon a {
						background-image: url("data:image/svg+xml,%3Csvg width='20' height='20' viewBox='0 0 20 20' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath d='M15.5916 6.84167C15.5141 6.76356 15.4219 6.70156 15.3204 6.65926C15.2188 6.61695 15.1099 6.59517 14.9999 6.59517C14.8899 6.59517 14.781 6.61695 14.6794 6.65926C14.5779 6.70156 14.4857 6.76356 14.4082 6.84167L10.5916 10.6583C10.5141 10.7364 10.4219 10.7984 10.3204 10.8407C10.2188 10.883 10.1099 10.9048 9.99989 10.9048C9.88988 10.9048 9.78096 10.883 9.67941 10.8407C9.57786 10.7984 9.48569 10.7364 9.40822 10.6583L5.59155 6.84167C5.51409 6.76356 5.42192 6.70156 5.32037 6.65926C5.21882 6.61695 5.1099 6.59517 4.99989 6.59517C4.88988 6.59517 4.78096 6.61695 4.67941 6.65926C4.57786 6.70156 4.48569 6.76356 4.40822 6.84167C4.25301 6.9978 4.16589 7.20901 4.16589 7.42917C4.16589 7.64932 4.25301 7.86053 4.40822 8.01666L8.23322 11.8417C8.70197 12.3098 9.33739 12.5728 9.99989 12.5728C10.6624 12.5728 11.2978 12.3098 11.7666 11.8417L15.5916 8.01666C15.7468 7.86053 15.8339 7.64932 15.8339 7.42917C15.8339 7.20901 15.7468 6.9978 15.5916 6.84167V6.84167Z' fill='%23374957'/%3E%3C/svg%3E");
						background-size: contain;
						background-repeat: no-repeat;

						width: 18px !important;
						height: 18px !important;
					}

					.combo input[type="text"] {
						padding: 0;
						width: 100% !important;
						height: 100% !important;
						padding-left: 5px;
						padding-top: 2px !important;
						padding-bottom: 2px !important;
					}

					table.treetable th span {
						padding: 0 !important;
					}

					.auto-refresh * {
						cursor: pointer;
					}

					tr[rowtype]:not(.leaf) span.flex-row {
						display: inline-flex;
						padding: 0;
					}

					tr[rowtype]:not(.leaf) span.status-icon {
						margin-left: 15px;
					}

					tr[rowtype]:not(.leaf) td.status,
					tr[rowtype]:not(.leaf) td:last-child {
						border-left: none !important;
					}

					tr[rowtype]:not(.leaf) td:first-child,
					tr[rowtype]:not(.leaf) td.status {
						border-right: none !important;
					}

					tr[rowtype]:not(.leaf) td:first-child > span {
						vertical-align: middle;
					}

					tr[rowtype]:not(.leaf) td:first-child .flex-row span {
						padding: 0;
						padding-bottom: 2px;
					}

					tr[rowtype] td.status {
						text-align: center !important;
					}

					tr[rowtype] td.status span.status-icon {
						margin: auto;
					}

					td.tc-description span {
						padding: 0;
						padding-bottom: 2px;
					}

					tr[rowtype='script'].bg-gray {
						background-color: #f9f9f9;
					}

					.auto-refresh {
						font-family: Arial, Helvetica, sans-serif;
						padding: 8px 10px;
						border: 1px solid #ccc;
						border-radius: 10px;
					}

					.auto-refresh span {
						font-size: 14px;
						color: #4E4E4E;
						font-weight: 500;
						white-space: nowrap;
					}

					.auto-refresh::after {
						content: '';
						display: inline-block;

						width: 16px;
						height: 16px;
						
						background-image: url('/_s_/spr/images/fi-rr-refresh.svg');
						background-size: contain;
						background-repeat: no-repeat;
					}

					.auto-refresh.checked {
						border-color: #253F89;
						border-width: 2px;
						padding: 7px 9px;
					}

					.auto-refresh.checked::after {
						background-image: url('/_s_/spr/images/fi-rr-refresh-active.svg');
					}

					.auto-refresh.checked span {
						color: #253F89;
					}

					a:not(.no-link):hover {
						text-decoration: underline !important;
					}
					#navbar a:hover {
						text-decoration: none !important;
					}					
					#navbar > .left-nav a:not(.selected, .nav-sahi-logo) {
						padding: 11px 24px 11px 24px;
					    margin-bottom: 3px;
					    border-radius: 5px;
				    }
					#navbar > .left-nav a:not(.selected, .nav-sahi-logo):hover {
						background-color: #E2EAFF;
						color: #253F89;
					}
					.indenter a:hover {
						text-decoration: none !important;
					}

					.script-name span {
						display: inline-block;
						max-width: 40ch;
						overflow: hidden;
						text-overflow: ellipsis;
						white-space: nowrap;
					}
					.script-name span:hover {
						text-decoration: underline;
					}
					.logo-header .container {
						--darker: #f8f8f8;
						box-sizing: border-box;
						display: flex;
						flex-direction: row;
						align-items: center;
						gap: 8px;
						cursor: pointer;
						padding: 8px 16px;
						background: #FFFFFF;
						border: 1px solid #4E4E4E;
						border-radius: 15px;
					    background: transparent;
					    border-color: #FFF;
					    margin: 0;
					}
					.container img {
					    height: 16px;
					    width: 16px;
					}
					.logo-header .container span {
					    color: #FFF;
					}
					#jsCodeCoverage {
					 	height: 61%;
					}

					.tc-description span {
						display: inline-block;
						max-width: 500px;
						overflow: hidden;
						white-space: break-spaces;
						overflow-wrap: anywhere;
					}
					#banner {
					   position: fixed;
					   display:none;
					   top: 0; left: 25%;
					   border-left: 8px solid #E62E2D;
					   border-radius: 10px;
					   background-color: #FFE6E5;
					   z-index: 100;width: 630px;
					   box-shadow: 0px 4px 14px 0px #5f5f5f;
					}
					#banner img {margin-top: 15px; margin-left: 10px; height: 40px}
					.warn { margin: 12px; line-height: 24px }
					.warn span, .warn strong {font-size: 16px}
					#warn {color: red}
			]]></style>
				<title><xsl:value-of select="suite/suiteSummary/SUITENAME"/></title>
			</head>

			<body onunload="onUnload()" onload="onLoad()">
				<script><![CDATA[
					// functions for formatting the date and time columns
					function splitDateTime(datetime) {
						var ix = datetime.search(/\d+:\d+:\d+/);
						if (ix < 0) return null;
						var date = datetime.substr(0, ix-1), time = datetime.substr(ix);
						return [date, time.toUpperCase()];
					}

					function splitStartAndEndTimeColumns() {
						var dateTimes = document.querySelectorAll('.date-time');
						var dateTimeRegex = /[a-zA-Z]{3} \d+, \d{4} \d+:\d+:\d+ [a-zA-Z]{2}/;

						var dateTimeHTML = el => {
							var datetime = el.dataset.text;
							if (!datetime || !datetime.match(dateTimeRegex)) {
								el.innerHTML = datetime;
								return;
							}

							var parts = splitDateTime(datetime);
							if (parts)
								el.innerHTML = "<span class='flex-column'>" + parts.map(x => "<span>" + x + "</span>").join("") + "</span>";
						}

						dateTimes.forEach(dateTimeHTML);
					}

					function formatTimeTakenColumn() {
						const timeRegex = /\d+:\d+:\d+ \d+/
						const timeSplitRegex = /:|\s/
						document.querySelectorAll('.time-taken').forEach(el => {
							const elText = el.dataset.text;
							if (elText.match(timeRegex)) {
								const arr = elText.split(timeSplitRegex)
								let formattedTime = [];
								
								if (!arr[0].match(/^0+$/)) 
									formattedTime.push(arr[0].padStart(2,0));
								formattedTime.push(arr[1].padStart(2,0));
								formattedTime.push(arr[2].padStart(2,0));
								let ms = arr[3].padStart(3,0);
								
								if (!formattedTime) formattedTime = '00:00.000';
								else formattedTime = formattedTime.join(':');
								formattedTime += "."+ms;
								el.innerHTML = formattedTime;
							}
						})
					}	
				]]></script>
				<xsl:apply-templates select="suite/suiteSummary"/>
				<xsl:param name="tcCount" select="suite/suiteSummary/TCCOUNT" />
				<xsl:if test="number($tcCount)">
					<div class='container'>
						<div class='table-buttons'>
							<span class="testcase-info">Testcases Info</span>
							<a id="expandAllButton" onclick="expandCollapseAll(true)">Expand All</a>
							<a id="collapseAllButton" onclick="expandCollapseAll(false)">Collapse All</a>
							
							<span id='showFailedCheckbox'>
								<span class='input-group flex-row'>
									<input style="vertical-align:middle;margin-top: 2px" type="checkbox" title="Show failed" id="showHideFailButton" 
										onchange="showHideFailure(this.checked);"></input>
									<label style="display: inline-block;margin-top: 2.5px"
									for="showHideFailButton" id="label_showAllOrFail">Show Failed</label>	
								</span>
							</span>
						</div>	
						<table class="testCaseSummaries treetable" id="testCaseSummaries" style="width: auto !important;min-width:800px">
							<thead>
								<tr id="tcSummariesHeader" class="table-header">
									<th style="text-align: left !important; padding-left: 20px !important;">Test Case Id</th>
									<th>
										<div class='flex-column'>
											<span style="white-space:nowrap;display:inline-block">Final Status</span><br />
											<input id="statusCombo" class="easyui-combobox" data-options="data:statusData,
												onChange:showHideRows,
												valueField:'id',
												textField:'text',
												value:scriptStatuses,
												multiple:true,
												editable:false,
												panelHeight:'auto'
												"
												style="height: 24px;">
											</input>
										</div>
									</th>
									<th>Description</th>
									<th>Time Taken</th>
									<th>
										<div class='flex-column'>
											<span style="white-space:nowrap;display:inline-block">Intermediate Statuses</span><br />
											<input id="intermediateStatusCombo" class="easyui-combobox" data-options="data:intermediateStatusData,
												onChange:showHideRows,
												valueField:'id',
												textField:'text',
												value:scriptIntermediateStatuses,
												multiple:true,
												editable:false,
												panelHeight:'auto'
											"
											style="height: 24px;"></input>
										</div>
									</th>
								</tr>
							</thead>
							<xsl:apply-templates select="suite" />
						</table>
					</div>
				</xsl:if>	
				<span id="go-to-top" title="Scroll to Top"></span>
				<script><![CDATA[
					document.addEventListener('scroll', () => {
						const rootElement = document.body;
						const goToTopBtn = document.getElementById('go-to-top');
						let scrollTotal = rootElement.scrollHeight - rootElement.clientHeight;
						let scrollPct = rootElement.scrollTop/scrollTotal;
						if(document.body.scrollTop < 1.5*rootElement.clientHeight) {
							goToTopBtn.style.display = 'none';
						} else {
							goToTopBtn.style.display = 'inline-block';
						}
					});
			
					document.querySelector('#go-to-top')
						.addEventListener('click', () => {
							var rootElement = document.body;
							rootElement.scrollTo({
								top: 0,
								behavior: "smooth"
							})
						});
				]]></script>				
			</body>
		</html>
	</xsl:template>

	<xsl:template match="suiteSummary">
		<xsl:param name="suiteId" select="suiteReportId|SUITEREPORTID" />
		<xsl:param name="className" select="suitestatus|SUITESTATUS" />
		<xsl:param name="suitePath" select="suitePath|SUITEPATH" />
		<xsl:param name="startTime" select="startTime|STARTTIME" />
		<xsl:param name="endTime" select="endTime|ENDTIME" />
		<xsl:param name="timeTaken" select="timeTaken|TIMETAKEN" />
		<xsl:param name="suiteInfo" select="suiteinfo|SUITEINFO" />
		<xsl:param name="suiteName" select="suiteName|SUITENAME" />
		<xsl:param name="browserType" select="BROWSERTYPE" />
		<xsl:param name="androidDevice" select="ANDROIDDEVICE" />
		<xsl:param name="iOSDevice" select="IOSDEVICE" />
		<xsl:param name="retriedsuitereportid" select="util:fetchInfo($suiteInfo, 'retriedSuiteReportId')" />
		<xsl:param name="firstrunsuitereportid" select="util:fetchInfo($suiteInfo, 'firstRunSuiteReportId')" />
		<xsl:param name="healedCount" select="TCPASSEDHEALED" />
		<xsl:param name="failedHealedCount" select="TCFAILEDHEALED" />
		<xsl:param name="errorHealedCount" select="TCERRORHEALED" />
		<xsl:param name="abortedHealedCount" select="TCABORTEDHEALED" />
		<xsl:param name="abortedTimeoutHealedCount" select="TCABORTEDTIMEOUTHEALED" />
		<xsl:param name="tcSkippedCount" select="tcskipped|TCSKIPPED" />
		<xsl:param name="tcNotSupportedCount" select="tcnotsupported|TCNOTSUPPORTED" />
					
		<xsl:param name="gitScriptPath" select="util:fetchInfo($suiteInfo, 'gitScriptPath')" />
		<xsl:param name="copiedScriptPath" select="util:fetchInfo($suiteInfo, 'copiedScriptsPath')" />
		<xsl:param name="suitePathGit" select="util:replaceSuitePathForGit($suitePath, $copiedScriptPath, $gitScriptPath)" />
		<xsl:param name="commitId" select="util:fetchInfo($suiteInfo, 'commitId')"/>
		<xsl:variable name="commitIdURI">
	        <xsl:choose>
	            <xsl:when test="$commitId !=''">
	            <xsl:value-of select="concat('&amp;commitId=',$commitId)"/>
	        </xsl:when>
	        <xsl:otherwise>
	            <xsl:value-of select="''"/>
	        </xsl:otherwise>
	        </xsl:choose>
	    </xsl:variable>

		<xsl:choose>
			<xsl:when test="$useDBURL = 'true'">
 				   <div id="banner"> 
 				       <div>
 				          <img src="/_s_/spr/images/caution_Icon_red.svg"/> 
 				       </div> 
 				       <div class="warn"> 
 				         <span id="warn">This Browser is not compatible. </span> 
 				         <span>Kindly switch to any modern browsers like 
 				           <strong>Google Chrome, Mozilla Firefox, Microsoft Edge, </strong><span>etc.</span> 
 				         </span> 
 				       </div> 
 				   </div> 
				<div class='navbar-container flex-row'>
					<div id='navbar' class='navbar flex-row logo-header'>
						<div class='flex-row left-nav'>
							<a class="nav-sahi-logo" onclick="window.location.href='/_s_/dyn/pro/DBReports';" style="cursor: pointer;"><span id="sahi-logo" class='bg-sahi-logo'></span></a>
							<a href='/_s_/dyn/pro/DBReports'>Suites</a> 
							<div style="display:none" id="parentSuite">
								<a id="parentSuiteLink" href='/_s_/dyn/pro/DBReports_suiteReport'>Parent Suite Report</a> 
							</div>
							<xsl:choose>
								<xsl:when test="$firstrunsuitereportid != 'null' and $firstrunsuitereportid != ''">
									<a class="navLink" href='/_s_/dyn/pro/DBReports_suiteReport?id={$firstrunsuitereportid}'>Suite Report</a> 
								</xsl:when>			
								<xsl:otherwise>
									<a class="navLink" href='/_s_/dyn/pro/DBReports_suiteReport?id={$suiteId}'>Suite Report</a> 
								</xsl:otherwise>
							</xsl:choose>
							<a class="navLink selected" href='/_s_/dyn/pro/DBReports_testCaseReport?id={$suiteId}'>Test Cases Report</a> 
							<xsl:if test="(contains($suiteName, '.csv')) and not(contains($suiteName, '.dd.csv')) and not(contains($suiteName, '.s.csv'))">
								<a class="navLink" href='/_s_/dyn/pro/DBReports_csvTestCasesReport?id={$suiteId}'>Test Cases Report Summary</a>
							</xsl:if>
							<xsl:if test="$retriedsuitereportid != 'null' and $retriedsuitereportid != ''">
								<a href='/_s_/dyn/pro/DBReports_suiteReport?id={$retriedsuitereportid}' id="linkshowretrylogs">Show retry logs</a>
							</xsl:if>
							<span id="jsCodeCoverage">
								<a href='/_s_/dyn/pro/JSCodeCoverage?suiteReportId={$suiteId}'> JS Code Coverage Report </a>
							</span>
							<a id="suiteAnalysisLink" class="navLink" href='/_s_/dyn/pro/DBReports_failureReport?id={$suiteId}'>Suite Analysis</a>
						</div>
						<div class='flex-row right-nav'>
							<a href='/_s_/dyn/pro/DBReports_testCaseReport?id={$suiteId}&amp;type=excel&amp;download=true'>
								<img border="0" src="/_s_/spr/images/excel.png" title="Export to Excel" width="25" height="25" />
							</a>
							<span class="container" onclick="logout()" id="logout" style="display:none;">
								<img src="/_s_/spr/images/fi-rr-log-out.svg"/>
								<a href="#" title="Log out" onclick="logout()">Log out</a>
							</span>
						</div>
					</div>
				</div>
			</xsl:when>
			<xsl:otherwise>
				<div class='navbar-container'>
					<div id='navbar' class='flex-row logo-header'>
						<div class='left-nav flex-row'>
							<span id="sahi-logo" class='bg-sahi-logo'></span>
							<a href='index.html' id="linksuitereports">Suite Report</a>
							<a href='testcase_summary.html' class='selected'>Test Cases Report</a>
							<xsl:if test="(contains($suiteName, '.csv')) and not(contains($suiteName, '.dd.csv')) and not(contains($suiteName, '.s.csv'))">
								<a href='results.csv'>Test Cases Report Summary</a>
							</xsl:if>
							<xsl:variable name="failed" select="number(failedcount|FAILEDCOUNT)" />
							<xsl:variable name="errorCount" select="number(errorcount|ERRORCOUNT)" />
							<xsl:variable name="abortedCount" select="number(abortedcount|ABORTEDCOUNT)" />
							<xsl:variable name="notSupportedCount" select="number(notsupportedcount|NOTSUPPORTEDCOUNT)" />
							<xsl:variable name="abortedTimeoutCount" select="number(abortedtimeoutcount|ABORTEDTIMEOUTCOUNT)" />
							<xsl:if test="(number($failed) != 0 or number($errorCount) != 0 or number($abortedCount) != 0 or number($notSupportedCount) != 0 or number($abortedTimeoutCount) != 0) and $retriedsuitereportid != 'null' and $retriedsuitereportid != ''">
								<a href="retry/index.html" id="linkshowretrylogs">Show retry logs</a>
							</xsl:if>
							<a href='js_code_coverage_summary.html'>JS Code Coverage Report</a>
							<a href='suite_analysis_summary.html'>Suite Analysis</a>
						</div>
					</div>
				</div>
			</xsl:otherwise>
		</xsl:choose>
		<div class='container'>
			<h1 class='title'><xsl:value-of select="$suiteName" /></h1>
			<div class="suite-summary">
				<div class='suite-name flex-row'>
					<span class="flex-row" style="gap: 0; align-items: flex-start; padding-left: 5px;">
						<span>Suite Name:</span>
						<xsl:if test="$useDBURL = 'true'">
							<a href="/_s_/dyn/Log_highlight?href={$suitePathGit}{$commitIdURI}">
								<xsl:value-of select="$suiteName" />
							</a> 
						</xsl:if>
						<xsl:if test="not($useDBURL = 'true')">
							<a><xsl:value-of select="$suiteName" /></a>
						</xsl:if>
					</span>
					<xsl:if test="$useDBURL = 'true'">
						<label for="auto_refresh">
							<span class='auto-refresh flex-row'>
									<input title="Disable Auto Refresh" type="checkbox" id="auto_refresh" onchange="enableDisableAutoRefresh(this)"/>
									<span>Auto Refresh</span>
							</span>
						</label>
					</xsl:if>
				</div>
				<div class='suite-details flex-row'>
					<div class='suite-details-left flex-column'>
						
						<xsl:if test="$browserType != 'null' and $browserType != '' and $browserType != 'undefined'">
							<div class='suite-detail-group'>
								<span class='suite-detail-item-title'>Browser Type: </span>
								<span class='suite-detail-item-value'>
									<xsl:value-of select="$browserType" />
								</span>
							</div>
						</xsl:if>

						<xsl:if test="$androidDevice != 'null' and $androidDevice != '' and $androidDevice != 'undefined'">
							<div class='suite-detail-group'>
								<span class='suite-detail-item-title'>Android Device: </span>
								<span class='suite-detail-item-value'>
									<xsl:value-of select="$androidDevice" />
								</span>
							</div>
						</xsl:if>

						<xsl:if test="$iOSDevice != 'null' and $iOSDevice != '' and $iOSDevice != 'undefined'">
							<div class='suite-detail-group'>
								<span class='suite-detail-item-title'>iOS Device: </span>
								<span class='suite-detail-item-value'>
									<xsl:value-of select="$iOSDevice" />
								</span>
							</div>
						</xsl:if>

						<div class='suite-detail-group'>
							<span class='suite-detail-item-title'>Start Time: </span>
							<span class='suite-detail-item-value date-time start-time'>
								<xsl:attribute name="data-text">
									<xsl:value-of select="util:humanTime($startTime)" />
								</xsl:attribute>
							</span>
						</div>

						<div class='suite-detail-group'>
							<span class='suite-detail-item-title'>End Time: </span>
							<span class='suite-detail-item-value date-time end-time'>
								<xsl:attribute name="data-text">
									<xsl:value-of select="util:humanTime($endTime)" />
								</xsl:attribute>
							</span>
						</div>

						<div class='suite-detail-group'>
							<span class='suite-detail-item-title'>Time Taken: </span>
							<span class='suite-detail-item-value time-taken'>
								<xsl:attribute name="data-text">
									<xsl:copy-of select="util:prettyTimeMoreThan24Hours($timeTaken)" />
								</xsl:attribute>
							</span>
						</div>
					</div>

					<div class='suite-details-right'>
						<div class='suite-details-right-title'>
							<h2>Test Cases</h2>
						</div>
						<div class='flex-column' style="gap: 0;">
							<div class='suite-detail-group'>
								<span class='suite-detail-item-title'>Passed: </span>
								<span class='suite-detail-item-value'>
									<span>
										<xsl:if test="number(tcpassed|TCPASSED)"><xsl:value-of select="tcpassed|TCPASSED"/></xsl:if> 
										<xsl:if test="not(number(tcpassed|TCPASSED))">0</xsl:if>
									</span> 
									<span>
										<xsl:if test="number($healedCount)">
											(<xsl:value-of select="$healedCount" /> HEALED)
										</xsl:if>
									</span>
								</span>
							</div>

							<div class='suite-detail-group'>
								<span class='suite-detail-item-title'>Failed: </span>
								<span class='suite-detail-item-value'>
									<span>
										<xsl:if test="number(tcfailed|TCFAILED)"><xsl:value-of select="tcfailed|TCFAILED"/></xsl:if> 
										<xsl:if test="not(number(tcfailed|TCFAILED))">0</xsl:if> 
									</span>
									<span>
										<xsl:if test="number($failedHealedCount)">
											(<xsl:value-of select="$failedHealedCount" /> HEALED)
										</xsl:if>
									</span>
								</span>
							</div>

							<div class='suite-detail-group'>
								<span class='suite-detail-item-title'>Errored: </span>
								<span class='suite-detail-item-value'>
									<span>
										<xsl:if test="number(tcerror|TCERROR)"><xsl:value-of select="tcerror|TCERROR"/></xsl:if>
										<xsl:if test="not(number(tcerror|TCERROR))">0</xsl:if>
									</span>
									<span>
										<xsl:if test="number($errorHealedCount)">
											(<xsl:value-of select="$errorHealedCount" /> HEALED)
										</xsl:if>
									</span>
								</span>
							</div>

							<div class='suite-detail-group'>
								<span class='suite-detail-item-title'>Skipped: </span>
								<span class='suite-detail-item-value'>
									<span>
										<xsl:if test="number($tcSkippedCount)"><xsl:value-of select="tcskipped|TCSKIPPED"/></xsl:if>
										<xsl:if test="not(number($tcSkippedCount))">0</xsl:if>
									</span>
									<span></span>
								</span>
							</div>

							<div class='suite-detail-group'>
								<span class='suite-detail-item-title'>Aborted: </span>
								<span class='suite-detail-item-value'>
									<span>
										<xsl:if test="number(tcaborted|TCABORTED)"><xsl:value-of select="tcaborted|TCABORTED"/></xsl:if>
										<xsl:if test="not(number(tcaborted|TCABORTED))">0</xsl:if>
									</span>
									<span>
										<xsl:if test="number($abortedHealedCount)">
											(<xsl:value-of select="$abortedHealedCount" /> HEALED)
										</xsl:if>
									</span> 
								</span>
							</div>

							<div class='suite-detail-group'>
								<span class='suite-detail-item-title'>Aborted Timeout: </span>
								<span class='suite-detail-item-value'>
									<span>
										<xsl:if test="number(tcabortedtimeout|TCABORTEDTIMEOUT)"><xsl:value-of select="tcabortedtimeout|TCABORTEDTIMEOUT"/></xsl:if>
										<xsl:if test="not(number(tcabortedtimeout|TCABORTEDTIMEOUT))">0</xsl:if>
									</span>
									<span>
										<xsl:if test="number($abortedTimeoutHealedCount)">
											(<xsl:value-of select="$abortedTimeoutHealedCount" /> HEALED)
										</xsl:if>
									</span>
								</span>
							</div>

							<div class='suite-detail-group'>
								<span class='suite-detail-item-title'>Not Supported: </span>
								<span class='suite-detail-item-value'>
									<span>
										<xsl:if test="number($tcNotSupportedCount)">
											<xsl:value-of select="tcnotsupported|TCNOTSUPPORTED"/>
										</xsl:if>
										<xsl:if test="not(number($tcNotSupportedCount))">0</xsl:if>
									</span>
									<span></span>
								</span>
							</div>

							<div class='suite-detail-group'>
								<span class='suite-detail-item-title'>Total: </span>
								<span class='suite-detail-item-value'>
									<span>
										<xsl:if test="number(tccount|TCCOUNT)"><xsl:value-of select="tccount|TCCOUNT"/></xsl:if>
										<xsl:if test="not(number(tccount|TCCOUNT))">0</xsl:if>
									</span>
									<span></span>
								</span>
							</div>

							<div class='suite-detail-group'>
								<span class='suite-detail-item-title' style="flex-basis: 0;">Status: </span>
								<span class='suite-detail-item-value suite-status' style="margin: 0; display: inline-flex; white-space: nowrap;">
									<span id='status' class="status-icon flex-row {$className}">
										<xsl:value-of select="translate(suitestatus|SUITESTATUS, $uppercase, $lowercase)" />
									</span>
								</span>
							</div>
						</div>
					</div>
				</div>
			</div>
			<div class='suite-info'>
				<span>
					<a id="suiteInfoLink" class="flex-row arrow-bg-before" href="#" onclick="showHide('suiteInfo', this);return false;">Suite Info</a>
				</span>
				<div id="suiteInfo" style="display:none;">
					<pre>
					<xsl:value-of select="suiteInfo|SUITEINFO" />
					</pre>
				</div>
			</div>
			<div class='nodes-info'>
				<span>
					<a id="nodesInfoLink" class="flex-row arrow-bg-before" href="#" onclick="showHide('nodesInfo', this);return false;">Nodes Info</a>
				</span>
				<div id='nodesInfo' style='display:none;'>
					<table class='nodes-info'>
						<thead>
							<tr class='table-header'>
								<th>Host</th>
								<th>Port</th>
								<th>Tests executed</th>
							</tr>
						</thead>
						<tbody>
							<xsl:for-each select="(nodes/node)|(NODES/NODE)">
								<tr class='table-data'>
									<td>
										<xsl:value-of select="hostname|HOSTNAME" />
									</td>
									<td>
										<xsl:value-of select="port|PORT" />
									</td>
									<td>
										<xsl:value-of select="scriptCount|SCRIPTCOUNT" />
									</td>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</div>
			</div>
		</div>

		<script>
			var useDBURL = '<xsl:value-of select="($useDBURL)"/>';
			var suiteReportID = '<xsl:value-of select="$suiteId"/>'
			var suiteName = '<xsl:value-of select="$suiteName" />';
			var timer = 1;
			var cookieHashMap = {};
			var nodeHashMap = {};
			<![CDATA[
			function readCookie(name){
				var nameEQ = name + "=";
				var ca = document.cookie.split(';');
				for(var i=0;i<ca.length;i++){
					var c = ca[i];
					c = c.replace(/[,][}]$/,'}');
					while (c.charAt(0)==' ') c = c.substring(1,c.length);
					if (c.indexOf(nameEQ) == 0) return c.substring(nameEQ.length,c.length);
				}
				return null;
			}
			
			var nonSelectedStatusValues = [], selectedStatusValues = [], allStatuses = [];
			var expandedNodesForFilter;
			var associativeStatuses = {FAILURE_RETRY: [ "ABORTED_RETRY"]};
			function applyFilters2() {	
				var scriptSummaryTable = document.getElementById("testCaseSummaries");
				
				if(scriptSummaryTable){
					
					var scriptRows = scriptSummaryTable.getElementsByTagName("TR");
					var rootNode, rootTrNode;
					// rootNode = this;
					nonSelectedStatusValues = [];
					selectedStatusValues = [];
					allStatuses = [];
					var selectedValues = jQuery('#statusCombo').combo('getValues');
					var selectedIntStatuses = jQuery('#intermediateStatusCombo').combo('getValues');
					var nonSelectedIntStatuses = [];
					for (var i=0; i<statusData.length; i++) {
						var statusValue = statusData[i].id;
						if($.inArray(statusValue, selectedValues) == -1){
							nonSelectedStatusValues.push(statusValue);
							if (statusValue in associativeStatuses) {
								for (var j=0; j<associativeStatuses[statusValue].length; j++) {
									nonSelectedStatusValues.push(associativeStatuses[statusValue][j]);
								}
							}
						} else {
							selectedStatusValues.push(statusValue);
						}
						allStatuses.push(statusValue);
					}
					for (var i=0; i<intermediateStatusData.length; i++) {
						var intermediateStatusValue = intermediateStatusData[i].id;
						if($.inArray(intermediateStatusValue, selectedIntStatuses) == -1){
							nonSelectedIntStatuses.push(intermediateStatusValue);
						}
					}
					if (scriptRows && (nonSelectedStatusValues.length >= 0 || nonSelectedIntStatuses.length >= 0)) {
						if (!rootNode || !rootNode.id) {
							for (var i = 0; i < scriptRows.length; i++) {
								if ((scriptRows[i].getAttribute("rowType") === "suite" 
										&& scriptRows[i].getAttribute("data-tt-parent-id") === "null")) {
									rootTrNode = scriptRows[i];
									try {
										rootNode = $("#testCaseSummaries")
											.treetable("node", rootTrNode.getAttribute("data-tt-id"));
									} catch(e) {
										rootNode = null;
									}
									break;
								}
							}
						}

						var processRows = function () {
							var statusesToHide = new Array();
							var rowsToHide = [];
							statusesToHide = statusesToHide.concat(nonSelectedStatusValues);
							statusesToHide = statusesToHide.concat(nonSelectedIntStatuses);
							for (var i = 0; i < scriptRows.length; i++) {
								if (statusesToHide.length > 0 && !scriptRows[i].getAttribute("rowType") === "suite") {
								} else if (scriptRows[i].style.display == 'none') {
									scriptRows[i].style.display = "table-row";
								}
								for (var j = 0; j < statusesToHide.length; j++) {
									if(_classList.contains(scriptRows[i],statusesToHide[j]) 
										|| statusesToHide.indexOf(scriptRows[i].getAttribute("intermediatestatus")) != -1) {
										scriptRows[i].style.display = "none";
									}
								}
							}
						};
						
						if (!rootNode) {
							processRows();
							var scriptLocators = document.getElementsByClassName("script-locator");
							if(scriptLocators.length == 1) scriptLocators[0].style.display = "none";
							rootTrNode.style.display = "none";
							return;
						}
						
						var checkIfNodesAreVisible = function (root) {
							var children = root.children;
							var result = true;
							for (var i = 0; i < children.length; i++) {
								result = result && checkIfNodesAreVisible(children[i]);
							}
							if (!_classList.contains(root.row.context, "leaf")) {
								return result;
							}
							for (var j = 0; j < nonSelectedStatusValues.length; j++) {
								// returns true if the current node is going to be hidden
								if(_classList.contains(root.row.context, nonSelectedStatusValues[j])) {
									return true;
								}
							}
							return false;
						};
						
						var processNode = function (node) {
							var ifBranchAndInvisible = false;
							if (_classList.contains(node.row.context, "branch")) {
								node.row.context.style.display = "table-row";
								// check for children those are visible
								// if not, then hide this node
								ifBranchAndInvisible = checkIfNodesAreVisible(node);
								if (ifBranchAndInvisible && _classList.contains(node.row.context, "collapsed")) {
									node.row.context.style.display = "none";
									return;
								}
							}
						
							// check if a node is branch (suite row) and is collapsed
							// then dont display the children
							if (_classList.contains(node.row.context, "branch")
								&& _classList.contains(node.row.context, "collapsed")
							) {
								return;
							}
							var uncheckedMatch = false;
							for (var j = 0; j < nonSelectedStatusValues.length; j++) {
								if (_classList.contains(node.row.context, nonSelectedStatusValues[j])) {
									uncheckedMatch = true;
									break;
								}
							}
							var intermediateStatusCell = node.row[0].getElementsByClassName("intermediateStatusCell")[0];
							if(intermediateStatusCell){
								intermediateStatuses = intermediateStatusCell.innerHTML;
								if(!shouldShowIntStatsRow(jQuery("#intermediateStatusCombo").combo('getValues'), intermediateStatuses)){
									uncheckedMatch = true;
								}
							}
							
							// hide only if there is a filter and the node is not a branch (suite row)
							if (uncheckedMatch 
								&& node.row.context.getAttribute("rowType") !== "suite" 
								&& !_classList.contains(node.row.context, "branch")) {
								node.row.context.style.display = "none";
							// show a leaf only if it is not collapsed
							} else if (node && !_classList.contains(node.row.context, "collapsed")) {
								node.row.context.style.display = "table-row";
							}
							if (ifBranchAndInvisible) {
								node.row.context.style.display = "none";
							}
							var children = node.children;
							for (var i = 0; i < children.length; i++) {
								processNode(children[i]);
							}
						};
						processNode(rootNode);
					}
				}
			}
			
			var queryStringObject = function () { //returns URL QueryString parameters as a JSON object
			  var query_string = {};
			  var query = window.location.search.substring(1);
			  var vars = query.split("&");
			  for (var i=0;i<vars.length;i++) {
			    var pair = vars[i].split("=");
			        query_string[pair[0]] = pair[1];
			  } 
			    return query_string;
			}();

			if(queryStringObject && queryStringObject["mainSuiteId"]){
				document.getElementById("jsCodeCoverage").style.display = "none";
				document.getElementById("sahiCodeCoverage").style.display = "none";
				document.getElementById("nodeAnalysis").style.display = "none";
				document.getElementById("parentSuite").style.display = "inline";
				document.getElementById("suiteInfoLink").style.display="none";
				document.getElementById("nodesInfoLink").style.display="none";
				document.getElementById("parentSuiteLink").href += ("?id="+queryStringObject["mainSuiteId"]);
				var navLinks = document.getElementsByClassName("navLink");
				for(var i=0; i<navLinks.length; i++){
					navLinks[i].href += ("&mainSuiteId="+queryStringObject["mainSuiteId"]);
				}
			}

			function setLeafPadding() {
				const rows = document.querySelectorAll('table.testCaseSummaries td.script-name-cell');
				rows.forEach(row => {
					const indenter = row.querySelector('span.indenter');
					const paddingLeft = indenter.style.paddingLeft;
					row.setAttribute('style', `padding-left: ${parseInt(paddingLeft) + 15}px !important;`);
				})
			}
			
			function readCookieAndExpandNodes() {
				document.getElementsByClassName('scriptargs')[0].style.display = 'none';
				$("#testCaseSummaries tbody tr").each(function(){
					var rowtype = $(this).attr("rowtype");
					var pLeft = $(this).find(".indenter").css('padding-left');
					$(this).find(".scriptargs").css('padding-left',(parseInt(pLeft)+19)+"px");
					
					//hide scriptargs if test is succeed
					if ($(this).hasClass("SUCCESS")) {
						$(this).find(".scriptargs").css("display","none");
					}
				});
				
				$("#testCaseSummaries").data("treetable").collapseAll();
				var cookieValue = readCookie("expandedNodes");
				if(cookieValue){
					nodeHashMap = eval("("+cookieValue+")");
					var expandedNodes = nodeHashMap[suiteReportID];
					if (expandedNodes != undefined && expandedNodes.length > 0){
						for(var i=0; i<expandedNodes.length; i++) {
							$("#testCaseSummaries").treetable("expandNode", expandedNodes[i]);
						}
						expandedNodesForFilter = nodeHashMap[suiteReportID];
						delete nodeHashMap[suiteReportID];
					} else {
						$("#testCaseSummaries").treetable("expandNode", suiteReportID);
					}
				} else {
					$("#testCaseSummaries").treetable("expandNode", suiteReportID);
				}

				setLeafPadding();
			}
			
			function expandCollapseAll(expand) {
				if(!$("#testCaseSummaries").data().treetable) return;
				if (expand) {
					$("#testCaseSummaries").data("treetable").expandAll();
				} else {
					$("#testCaseSummaries").data("treetable").collapseAll();
				}
				showHideFailure()
			}
			
			function showHideRows() {
				expandCollapseAll(true);
				applyFilters2();
			}
			
			function shouldShowIntStatsRow(selectedValues, intermediateStatuses){
				var intermediateStatusesArr = intermediateStatuses.split(",");
				for(var i = 0; i<intermediateStatusesArr.length; i++){
					if(selectedValues.indexOf(intermediateStatusesArr[i].trim()) != -1){
						return true;
					}
				}
				return false;
			}
			
			function deSelectFromPersistData() {
				var selectedValues = jQuery('#statusCombo').combo('getValues');
				for (var i = 0; i < nonSelectedStatusValues.length; i++) {
					var nonSelectedStatus = nonSelectedStatusValues[i];
					var nonSelectedStatusIx = $.inArray(nonSelectedStatus, selectedValues);
					if(nonSelectedStatusIx != -1){
						selectedValues.splice(nonSelectedStatusIx, 1);
					}
				}
				jQuery('#statusCombo').combobox('setValues', selectedValues);
			}
			
			function createCookie(name,value,days){
				if (days) {
					var date = new Date();
					date.setTime(date.getTime()+(days*24*60*60*1000));
					var expires = "; expires="+date.toGMTString();
				}
				else var expires = "";
				document.cookie = name+"="+value+expires+"; path=/";
			}
			
			function showHideFailure(showFailOnly){
				if (typeof showFailOnly === 'undefined') {
					showFailOnly = document.getElementById('showHideFailButton').checked;
				}
				if(!isSuite(suiteName)) {
					var testCaseSummaryTable = document.getElementById("testCaseSummaries");
					var testCaseRows = testCaseSummaryTable.querySelectorAll("[rowtype='script']");
					for(var i=1; i<testCaseRows.length; i++){
						if(showFailOnly){
							if(_classList.contains(testCaseRows[i], "SUCCESS")){
								testCaseRows[i].style.display = "none";
							}
						} else {
							testCaseRows[i].style.display = "table-row";
						}
					}
					return;
				}
				var testCaseSummaryTable = document.getElementById("testCaseSummaries");
				var testCaseRows = testCaseSummaryTable.getElementsByTagName("TR");
				if(showFailOnly){
					//setCookie();
					for(var i=1; i<testCaseRows.length; i++){
						if((_classList.contains(testCaseRows[i], "expanded") || testCaseRows[i].style.display != "none") && _classList.contains(testCaseRows[i], "SUCCESS")){
							testCaseRows[i].style.display = "none";
						}
					}
					hideSuiteRowIfNoFailureChild();
				}
				else{
					//resetCookie();
					for(var i=0; i<testCaseRows.length; i++){
						var parentId = testCaseRows[i].getAttribute("data-tt-parent-id");
						if(isAllParentsExpanded(parentId) || i==1) {
							testCaseRows[i].style.display = "table-row";
						}
					}
				}
			}
			
			function isAllParentsExpanded(parentId) {
				var testCaseSummaryTable = document.getElementById("testCaseSummaries");
				var parentSuiteRows=testCaseSummaryTable.querySelectorAll("[data-tt-id='"+parentId+"'][rowtype='suite']");
				if(parentSuiteRows.length > 0) {
					if (_classList.contains(parentSuiteRows[0], "expanded")) {
						var newParent = parentSuiteRows[0].getAttribute("data-tt-parent-id");
						if (newParent == null || newParent == "null") return true;
						return isAllParentsExpanded(newParent);
					}
				} else {
					var parentRows=testCaseSummaryTable.querySelectorAll("[data-tt-id='"+parentId+"'][rowtype='script']");
					if(parentRows.length > 0) {
						if (_classList.contains(parentRows[0], "expanded")) {
							var newParent = parentRows[0].getAttribute("data-tt-parent-id");
							if (newParent == null || newParent == "null") return true;
							return isAllParentsExpanded(newParent);
						}
					}
				}
				return false;
			}
			
			function enableDisableAutoRefresh(autoRefresh){
				var isAutoRefreshEnable = autoRefresh.checked;
				if(isAutoRefreshEnable){
					createCookie("auto_refresh","true",1);
					refreshPage();
					autoRefresh.title = "Disable Auto Refresh";
					autoRefresh.parentNode.classList.add('checked');
				} else{
					createCookie("auto_refresh","false",1);
					autoRefresh.title = "Enable Auto Refresh";
					if(timer) clearTimeout(timer);
					autoRefresh.parentNode.classList.remove('checked');
				}
			}
			
			function refreshPage(){
				if(useDBURL == "false") return;
				var el = document.getElementById("status");
				if (el && (
					el.classList.contains("SUCCESS") || 
					el.classList.contains("FAILURE") || 
					el.classList.contains("ERROR") || 
					el.classList.contains("USER_ABORTED") || 
					el.classList.contains("ABORTED_TIMEOUT")
				)) {
					return;
				}
				var isAutoRefreshCookieEnable = (readCookie("auto_refresh") == "true");
				if(isAutoRefreshCookieEnable) timer = window.setTimeout("window.location.reload();", 2000);
			}
			refreshPage();
			function showHide(s, thisEl) { 
				var el=document.getElementById(s);
				el.style.display = (el.style.display == 'block') ? 'none' : 'block';
				thisEl.classList.toggle('expanded'); 
			}; 
			
			function onLoad(){
				if(useDBURL == "true"){
					var autoRefreshCheckbox = document.getElementById('auto_refresh'); 
			        var cookieValueForAutoReferesh = readCookie("auto_refresh");
			        if(cookieValueForAutoReferesh == "true"){
			        	autoRefreshCheckbox.checked = true;
			        	autoRefreshCheckbox.title = "Disable Auto Refresh";
						enableDisableAutoRefresh(autoRefreshCheckbox);
			        } else{
			        	autoRefreshCheckbox.checked = false;
			        	autoRefreshCheckbox.title = "Enable Auto Refresh";
						enableDisableAutoRefresh(autoRefreshCheckbox);
			        }
		        	showLogoutIfUserLoggedIn();
		        }

				splitStartAndEndTimeColumns();
				formatTimeTakenColumn();

		        var scriptSummaryTable = document.getElementById("testCaseSummaries");
		        if(scriptSummaryTable){
		        	if(!isSuite(suiteName)) {
						<!-- sortTable(); -->
						var suiteRows = scriptSummaryTable.querySelectorAll("[rowtype='suite']");
						for(var i=0; i<suiteRows.length;i++){
							if(!isSuite(suiteRows[i].getElementsByTagName('a')[0].innerHTML)) suiteRows[i].style.display='none';//remove();
						}
						var scriptRows = scriptSummaryTable.querySelectorAll("[rowtype='script']");
						if(scriptRows && scriptRows[0]) scriptRows[0].style.display='none';//remove();
						if (scriptRows) {
							scriptRows.forEach(row => row.classList.remove('bg-gray'));
						}
						scriptSummaryTable.style.marginTop=9;
					} else {
						$("#testCaseSummaries").treetable({expandable: true, onNodeExpand: applyFilters2, onNodeCollapse: function () {} });
						$("#testCaseSummaries").data("treetable").expandAll();
						readCookieAndExpandNodes();
						removeSuiteRowIfNoChild();
					}
					var cookieValue = readCookie("nonSelectedStatuses");
					nonSelectedStatusValues = ["FAILURE_RETRY"];
					if(cookieValue){
						var cookieHashMap = eval("("+cookieValue+")");
						var showHideNonSelected = cookieHashMap[suiteReportID];
						if(showHideNonSelected){
							nonSelectedStatusValues = showHideNonSelected;
							delete cookieHashMap[suiteReportID];
						}
					}
					deSelectFromPersistData();
					applyFilters2(true);
		        }
			}
			
			function isSuite(name) {
				if (endsWith(name, ".suite") || endsWith(name, ".dd.csv")) {
					return true;
				}
				return false;
			}
			
			function endsWith(str, suffix) {
				return str.indexOf(suffix, str.length - suffix.length) !== -1;
			}
			
			function onUnload(){
				var count = 0;
				var firstElement;
				for(firstElement in cookieHashMap){
					break;
				}
				for(var j in cookieHashMap){
					count++;
				}
				if(count == 10){
					delete cookieHashMap[firstElement];
				}
				
				var cookieValue = getJSON(cookieHashMap);
				if(nonSelectedStatusValues.length > 0 || selectedStatusValues.indexOf("FAILURE_RETRY") != -1) {
					cookieHashMap[suiteReportID] = getArrayJson(nonSelectedStatusValues);
					cookieValue = getJSON(cookieHashMap);
					createCookie("nonSelectedStatuses", cookieValue, 1);
				}
				
				var expandedRows = document.getElementsByClassName('expanded branch');
				var expandedNodes = [];
				for(var i=0; i<expandedRows.length; i++) {
					var dataId = expandedRows[i].getAttribute("data-tt-id");
					expandedNodes.push(dataId);
				}
				nodeHashMap[suiteReportID] = expandedNodes;
				createCookie("expandedNodes", JSON.stringify(nodeHashMap), 1);
			}
			
			function getJSON(o) {
				var s = "{";
				for (var i in o) {
					s += "'" + i + "':" + o[i] + ","
				}
				s += "}";
				return s;
			}
			
			function getArrayJson(arr) {
				var strbuf = [];
				strbuf.push("[");
				strbuf.push(" ");
				for (var i = 0; i < arr.length; i++) {
					strbuf.push(' "');
					strbuf.push(arr[i]);
					strbuf.push('"');
					strbuf.push(',');
				}
				strbuf.pop();
				strbuf.push("]");
				return strbuf.join('');
			}
						
			function createCookie(name,value,days){
				if (days) {
					var date = new Date();
					date.setTime(date.getTime()+(days*24*60*60*1000));
					var expires = "; expires="+date.toGMTString();
				}
				else var expires = "";
				document.cookie = name+"="+value+expires+"; path=/";
			}
							
			function expandAll(e) {
				$("#testCaseSummaries").data("treetable").expandAll();
			}
			
			function collapseAll(e) {
				$("#testCaseSummaries").data("treetable").collapseAll();
			}
			
			function countChildScripts(suiteId,count)
			{   var countScript=count;
				 var scriptSummaryTable = document.getElementById("testCaseSummaries");
				 var childSuiteRows=scriptSummaryTable.querySelectorAll("[data-tt-parent-id='"+suiteId+"'][rowtype='suite']");
				 var childRows=scriptSummaryTable.querySelectorAll("[data-tt-parent-id='"+suiteId+"'][rowtype='script']");
				 countScript+=childRows.length;
				 for(var k=0; k<childSuiteRows.length;k++){
				   	    var innerSuiteId=childSuiteRows[k].getAttribute("data-tt-id");
				 		return countChildScripts(innerSuiteId,countScript);
					}
				return countScript;
			}
			
			function removeSuiteRowIfNoChild() {
				var scriptSummaryTable = document.getElementById("testCaseSummaries");
				var suiteRows = scriptSummaryTable.querySelectorAll("[rowtype='suite']");
				for(var i=suiteRows.length-1; i>=0;i--){
				    var count=0;
					if(_classList.contains(suiteRows[i], "leaf")) suiteRows[i].parentNode.removeChild(suiteRows[i]);
					var suiteId=suiteRows[i].getAttribute("data-tt-id");
					//console.log("before calling main"+suiteRows[i].textContent);
				
					var count=countChildScripts(suiteId,0);
					if(count==0 && suiteRows[i].parentNode) suiteRows[i].parentNode.removeChild(suiteRows[i]);
				}
			}
			
			function countFailureChildScripts(suiteId,count)
			{   var countScript=count;
				var scriptSummaryTable = document.getElementById("testCaseSummaries");
				var childSuiteRows=scriptSummaryTable.querySelectorAll("[data-tt-parent-id='"+suiteId+"'][rowtype='suite']");
				var childRows=scriptSummaryTable.querySelectorAll("[data-tt-parent-id='"+suiteId+"'][rowtype='script']");
				for(var k=0; k<childRows.length;k++) {
					if (_classList.contains(childRows[k], "FAILURE") || _classList.contains(childRows[k], "ABORTED")) {
						countScript += 1;
					}
				}
				for(var k=0; k<childSuiteRows.length;k++){
					if (_classList.contains(childSuiteRows[k], "FAILURE") || _classList.contains(childSuiteRows[k], "ABORTED")) {
						countScript += 1;
					}
					var innerSuiteId=childSuiteRows[k].getAttribute("data-tt-id");
				 	return countFailureChildScripts(innerSuiteId,countScript);
				}
				return countScript;
			}
			
			function hideSuiteRowIfNoFailureChild() {
				var scriptSummaryTable = document.getElementById("testCaseSummaries");
				var suiteRows = scriptSummaryTable.querySelectorAll("[rowtype='suite']");
				for(var i=suiteRows.length-1; i>=0;i--){
					var suiteId=suiteRows[i].getAttribute("data-tt-id");
					var count=countFailureChildScripts(suiteId,0);
					if(count==0) suiteRows[i].style.display = "none";
				}
			}
	
			var linkSuiteReports = document.getElementById("linksuitereports");
			if(linkSuiteReports != null){
				linkSuiteReports.addEventListener("click",function(evt) {
					if(evt.target.baseURI!=null && evt.target.baseURI.search("/retry/")>-1) {
						evt.target.href="../index.html"
						return false;
					}
				});
			}
					
			var linkShowRetryLogs = document.getElementById("linkshowretrylogs");
			if(linkShowRetryLogs != null){
				linkShowRetryLogs.addEventListener("click",function(evt) {
					if(evt.target.baseURI!=null && evt.target.baseURI.search("/retry/")>-1) {
						evt.target.href="index.html"
						return false;
					}
				});
			}
			]]>
			</script>
	</xsl:template>

	<xsl:template match="suite">
		<xsl:param name="suiteId"
			select="suiteSummary/SUITEREPORTID" />
		<xsl:param name="suiteName" select="suiteSummary/SUITENAME" />
		<xsl:param name="suiteInfo" select="suiteSummary/SUITEINFO" />
		<xsl:param name="parentSuiteId"
			select="suiteSummary/PARENTSUITEID" />
		<xsl:param name="className"
			select="suiteSummary/SUITESTATUS" />

		<tr data-tt-id="{$suiteId}" class="{$className} table-data"
			data-tt-parent-id="{$parentSuiteId}" rowtype="suite">
			<td id="{$suiteId}">
				<xsl:choose>
					<xsl:when test="$useDBURL = 'true'">
					</xsl:when>
				</xsl:choose>
				<span class='flex-row'>
					<a class="no-link" title="{$suiteInfo}">
						<xsl:value-of select="$suiteName" />
					</a>
					<!-- <span class='connector flex-row'>
						<span></span>
					</span> -->
					<br />
					<div class="scriptargs" style="display:none">
						<xsl:copy-of select="$suiteInfo" />
					</div>
				</span>
			</td>
			<td class='status' style="text-align: left !important;">
				<span class="status-icon {$className} flex-row" style="margin: 0;">
					<xsl:value-of select="translate($className, $uppercase, $lowercase)"/>
				</span>
			</td>
			<td colspan="3"></td>
		</tr>
		<xsl:apply-templates
			select="scriptSummaries/scriptSummary">
		</xsl:apply-templates>
		<xsl:apply-templates select="suite" />
	</xsl:template>

	<xsl:template match="scriptSummaries/scriptSummary">
		<xsl:param name="scriptId" select="summary/SCRIPTREPORTID" />
		<xsl:param name="pId" select="summary/SUITEID" />
		<xsl:param name="className" select="summary/SCRIPTSTATUS" />
		<xsl:param name="scriptargs" select="summary/SCRIPTARGS" />
		<xsl:param name="suiteId" select="summary/SUITEREPORTID" />
		<xsl:param name="position" select="util:position()" />

		<xsl:variable name="parentSuiteId">
			<xsl:choose>
				<xsl:when test="not(summary/SUITEID)">
					<xsl:value-of select="$suiteId" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$pId" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="args">
			<xsl:choose>
				<xsl:when test="$scriptargs != '' and $scriptargs != 'null'">
					<xsl:value-of select="$scriptargs" />
				</xsl:when>
				<xsl:otherwise></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<tr id='status-{$position}' class="{$className} script-locator table-data" data-tt-id="{$scriptId}" data-tt-parent-id="{$parentSuiteId}" rowtype="script">
			<td id="{$suiteId}" style="white-space: nowrap;">
				<span class='flex-row'>
					<xsl:choose>
						<xsl:when test="$useDBURL = 'true'">
							<a id="script-{$position}" title="{$args}" class="SCRIPT script-name" href="/_s_/dyn/pro/DBReports_scriptReport?id={$scriptId}">
								<span>
									<xsl:attribute name="title">
										<xsl:value-of select="summary/SCRIPTNAME" />
									</xsl:attribute>
									<xsl:text>
										<xsl:value-of select="summary/SCRIPTNAME" />
									</xsl:text>
								</span>
							</a>
						</xsl:when>
						<xsl:otherwise>
							<a id="script-{$position}" title="{$args}" class="SCRIPT script-name" href="{$scriptId}.html">
								<span>
									<xsl:attribute name="title">
										<xsl:value-of select="summary/SCRIPTNAME" />
									</xsl:attribute>
									<xsl:text>
										<xsl:value-of select="summary/SCRIPTNAME" />
									</xsl:text>
								</span>
							</a>
						</xsl:otherwise>
					</xsl:choose>
					<!-- <span class='connector flex-row'>
						<span></span>
					</span> -->
				</span>
			</td>
			<td class='status' style="text-align: left !important;">
				<span class="status-icon {$className} flex-row" style="margin: 0;">
					<xsl:value-of select="translate($className, $uppercase, $lowercase)"/>
				</span>
			</td>
			<td colspan="3"></td>
		</tr>
		<xsl:apply-templates select="testCaseSummaries/testCaseSummary" />
		<script type="text/javascript">;
			var allStatusData = {"SUCCESS":{"id":"SUCCESS", "text":"Success"}, "FAILURE":{"id":"FAILURE", "text":"Failure"}, 
										  	 "ERROR": {"id":"ERROR", "text":"Error"}, "ABORTED": {"id":"ABORTED", "text":"Aborted"},
											 "ABORTED_TIMEOUT": {"id":"ABORTED_TIMEOUT", "text":"Aborted Timeout"}, "USER_ABORTED": {"id":"USER_ABORTED", "text":"User Aborted"}, 
											 "SKIPPED":{"id":"SKIPPED", "text":"Skipped"}, "NOT_SUPPORTED": {"id":"NOT_SUPPORTED", "text":"Not Supported"},
											 "FAILURE_RETRY": {"id":"FAILURE_RETRY", "text":"Retried"}, "INTERNAL_ABORTED": {"id":"INTERNAL_ABORTED", "text":"Internal Aborted"}}; 
			
			var allIntermediateStatusData = {"HEALED":{"id":"HEALED", "text":"Healed"}, 
											"FAILURE":{"id":"FAILURE", "text":"Failure"}, 
											"ERROR": {"id":"ERROR", "text":"Error"}, 
											"NA": {"id":"NA", "text":"NA"}};
			<![CDATA[
			var scriptStatuses = [];
			var scriptIntermediateStatuses = []
			function setScriptStatuses(){
				var scriptRows = document.querySelectorAll("tr[rowtype='script']");
				for(var i = 0; i<scriptRows.length; i++){
					var status = scriptRows[i].getAttribute('status');
					if(status == "ABORTED_RETRY") status = "FAILURE_RETRY";
					if(status){
						if (status != 'null' && scriptStatuses.indexOf(status) == -1) {
							scriptStatuses.push(status);
						}
					}
					var intermediatestatus = scriptRows[i].getAttribute('intermediatestatus');
					if(intermediatestatus){
						var splittedStatus = intermediatestatus.split(",");
						for(var j=0; j<splittedStatus.length; j++){
							if(scriptIntermediateStatuses.indexOf(splittedStatus[j].trim()) == -1){
								scriptIntermediateStatuses.push(splittedStatus[j].trim());
							}
						}
					}
				}
			}
			setScriptStatuses();
			var statusData = [];
			for(var i = 0; i<scriptStatuses.length; i++){
				statusData.push(allStatusData[scriptStatuses[i]]);
			}
			var intermediateStatusData = [];
			for(var i = 0; i<scriptIntermediateStatuses.length; i++){
				intermediateStatusData.push(allIntermediateStatusData[scriptIntermediateStatuses[i]]);
			}]]>
		</script>
	</xsl:template>

	<xsl:template match="testCaseSummaries/testCaseSummary">
		<xsl:param name="reportId" select="reportId|SCRIPTREPORTID" />
		<xsl:param name="className" select="tcstatus|TCSTATUS" />
		<xsl:param name="testcaseId" select="testCaseReportId|TESTCASEREPORTID" />
		<xsl:param name="intermediateStatus" select="tcintermediatestatuses|TCINTERMEDIATESTATUSES" />
		
		<xsl:variable name="scriptIntermediateStatus">
			<xsl:choose>
				<xsl:when test="$intermediateStatus != '' and $intermediateStatus != 'null'">
		           	<xsl:value-of select="tcintermediatestatuses|TCINTERMEDIATESTATUSES" />
		      	</xsl:when>
				<xsl:otherwise>
		           	<xsl:value-of select="'NA'" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<tr class="{$className} table-data bg-gray"
			status="{$className}" intermediatestatus="{$scriptIntermediateStatus}"
			data-tt-id="{$reportId}-{$testcaseId}" data-tt-parent-id="{$reportId}" rowtype="script">
			<td class="script-name-cell" style="border: 0.5px solid #ccc !important;">
				<xsl:choose>
					<xsl:when test="$useDBURL = 'true'">
						<a class="SCRIPT script-name" href="/_s_/dyn/pro/DBReports_scriptReport?id={$reportId}">
							<span style="max-width: 30ch; white-space: normal; word-break: break-word; overflow-wrap: anywhere;">
								<xsl:attribute name="title">
									<xsl:value-of select="testCaseReportId|TESTCASEREPORTID" />
								</xsl:attribute>
								<xsl:text>
									<xsl:value-of select="testCaseReportId|TESTCASEREPORTID" />
								</xsl:text>
							</span>
						</a>
					</xsl:when>
					<xsl:otherwise>
						<a class="SCRIPT script-name" href="{$reportId}.html">
							<span style="max-width: 30ch; white-space: normal; word-break: break-word; overflow-wrap: anywhere;">
								<xsl:attribute name="title">
									<xsl:value-of select="testCaseReportId|TESTCASEREPORTID" />
								</xsl:attribute>
								<xsl:text>
									<xsl:value-of select="testCaseReportId|TESTCASEREPORTID" />
								</xsl:text>
							</span>
						</a>
					</xsl:otherwise>
				</xsl:choose>
			</td>
			<td class='status' style="text-align: left;">
				<span class="{$className} status-icon flex-row" style="margin: 0;">
					<xsl:value-of disable-output-escaping="yes" select="translate(tcstatus|TCSTATUS, $uppercase, $lowercase)" />
				</span>
			</td>
			<td class='tc-description'>
				<span><xsl:value-of disable-output-escaping="no" select="description|DESCRIPTION" /></span>
			</td>
			<td class="time-taken right-align">
				<xsl:attribute name="data-text">
					<xsl:value-of disable-output-escaping="yes" select="util:prettyTimeMoreThan24Hours(timeTaken|TIMETAKEN)"/>
				</xsl:attribute>
			</td>
			<td class="intermediateStatusCell" style="text-align: center !important;">
				<xsl:value-of select="$scriptIntermediateStatus" />
			</td>
		</tr>
	</xsl:template>

</xsl:stylesheet>